/********************************************************************************
** Form generated from reading UI file 'searchbarpower.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SEARCHBARPOWER_H
#define UI_SEARCHBARPOWER_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_PowerSearchBar
{
public:
    QHBoxLayout *horizontalLayout_2;
    QGridLayout *gridLayout;
    QLabel *label;
    QLabel *label_3;
    QLabel *label_2;
    QHBoxLayout *horizontalLayout;
    QComboBox *searchMode;
    QToolButton *matchCase;
    QToolButton *selectionOnly;
    QSpacerItem *horizontalSpacer;
    QToolButton *findNext;
    QToolButton *findPrev;
    QPushButton *replaceNext;
    QStackedWidget *searchCancelStacked;
    QWidget *searchPage;
    QHBoxLayout *horizontalLayout_3;
    QPushButton *replaceAll;
    QPushButton *findAll;
    QWidget *cancelPage;
    QHBoxLayout *horizontalLayout_4;
    QPushButton *cancel;
    QToolButton *mutate;
    QComboBox *pattern;
    QComboBox *replacement;

    void setupUi(QWidget *PowerSearchBar)
    {
        if (PowerSearchBar->objectName().isEmpty())
            PowerSearchBar->setObjectName("PowerSearchBar");
        PowerSearchBar->resize(1037, 144);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(PowerSearchBar->sizePolicy().hasHeightForWidth());
        PowerSearchBar->setSizePolicy(sizePolicy);
        horizontalLayout_2 = new QHBoxLayout(PowerSearchBar);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalLayout_2->setContentsMargins(0, 0, 0, 0);
        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        label = new QLabel(PowerSearchBar);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label, 0, 0, 1, 1);

        label_3 = new QLabel(PowerSearchBar);
        label_3->setObjectName("label_3");
        label_3->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_3, 1, 0, 1, 1);

        label_2 = new QLabel(PowerSearchBar);
        label_2->setObjectName("label_2");
        label_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_2, 2, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(6);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(-1, -1, 0, -1);
        searchMode = new QComboBox(PowerSearchBar);
        searchMode->addItem(QString());
        searchMode->addItem(QString());
        searchMode->addItem(QString());
        searchMode->addItem(QString());
        searchMode->setObjectName("searchMode");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(searchMode->sizePolicy().hasHeightForWidth());
        searchMode->setSizePolicy(sizePolicy1);
        searchMode->setMaxVisibleItems(4);
        searchMode->setFrame(true);

        horizontalLayout->addWidget(searchMode);

        matchCase = new QToolButton(PowerSearchBar);
        matchCase->setObjectName("matchCase");
        matchCase->setCheckable(true);
        matchCase->setAutoRaise(true);

        horizontalLayout->addWidget(matchCase);

        selectionOnly = new QToolButton(PowerSearchBar);
        selectionOnly->setObjectName("selectionOnly");
        selectionOnly->setCheckable(true);
        selectionOnly->setAutoRaise(true);

        horizontalLayout->addWidget(selectionOnly);

        horizontalSpacer = new QSpacerItem(0, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        findNext = new QToolButton(PowerSearchBar);
        findNext->setObjectName("findNext");
        findNext->setAutoRaise(true);

        horizontalLayout->addWidget(findNext);

        findPrev = new QToolButton(PowerSearchBar);
        findPrev->setObjectName("findPrev");
        findPrev->setAutoRaise(true);

        horizontalLayout->addWidget(findPrev);

        replaceNext = new QPushButton(PowerSearchBar);
        replaceNext->setObjectName("replaceNext");

        horizontalLayout->addWidget(replaceNext);

        searchCancelStacked = new QStackedWidget(PowerSearchBar);
        searchCancelStacked->setObjectName("searchCancelStacked");
        searchPage = new QWidget();
        searchPage->setObjectName("searchPage");
        horizontalLayout_3 = new QHBoxLayout(searchPage);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        horizontalLayout_3->setContentsMargins(0, 0, 0, 0);
        replaceAll = new QPushButton(searchPage);
        replaceAll->setObjectName("replaceAll");

        horizontalLayout_3->addWidget(replaceAll);

        findAll = new QPushButton(searchPage);
        findAll->setObjectName("findAll");

        horizontalLayout_3->addWidget(findAll);

        searchCancelStacked->addWidget(searchPage);
        cancelPage = new QWidget();
        cancelPage->setObjectName("cancelPage");
        horizontalLayout_4 = new QHBoxLayout(cancelPage);
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        horizontalLayout_4->setContentsMargins(0, 0, 0, 0);
        cancel = new QPushButton(cancelPage);
        cancel->setObjectName("cancel");

        horizontalLayout_4->addWidget(cancel);

        searchCancelStacked->addWidget(cancelPage);

        horizontalLayout->addWidget(searchCancelStacked);

        mutate = new QToolButton(PowerSearchBar);
        mutate->setObjectName("mutate");
        mutate->setCheckable(true);
        mutate->setAutoRaise(true);

        horizontalLayout->addWidget(mutate);

        horizontalLayout->setStretch(3, 1);

        gridLayout->addLayout(horizontalLayout, 2, 1, 1, 1);

        pattern = new QComboBox(PowerSearchBar);
        pattern->setObjectName("pattern");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(9);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(pattern->sizePolicy().hasHeightForWidth());
        pattern->setSizePolicy(sizePolicy2);
        pattern->setFocusPolicy(Qt::StrongFocus);
        pattern->setEditable(true);
        pattern->setSizeAdjustPolicy(QComboBox::AdjustToMinimumContentsLengthWithIcon);

        gridLayout->addWidget(pattern, 0, 1, 1, 1);

        replacement = new QComboBox(PowerSearchBar);
        replacement->setObjectName("replacement");
        sizePolicy2.setHeightForWidth(replacement->sizePolicy().hasHeightForWidth());
        replacement->setSizePolicy(sizePolicy2);
        replacement->setEditable(true);
        replacement->setSizeAdjustPolicy(QComboBox::AdjustToMinimumContentsLengthWithIcon);

        gridLayout->addWidget(replacement, 1, 1, 1, 1);


        horizontalLayout_2->addLayout(gridLayout);

#if QT_CONFIG(shortcut)
        label->setBuddy(pattern);
        label_3->setBuddy(replacement);
        label_2->setBuddy(searchMode);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(pattern, replacement);
        QWidget::setTabOrder(replacement, searchMode);
        QWidget::setTabOrder(searchMode, matchCase);
        QWidget::setTabOrder(matchCase, selectionOnly);
        QWidget::setTabOrder(selectionOnly, findNext);
        QWidget::setTabOrder(findNext, findPrev);
        QWidget::setTabOrder(findPrev, replaceNext);
        QWidget::setTabOrder(replaceNext, replaceAll);
        QWidget::setTabOrder(replaceAll, findAll);
        QWidget::setTabOrder(findAll, mutate);
        QWidget::setTabOrder(mutate, cancel);

        retranslateUi(PowerSearchBar);

        searchCancelStacked->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(PowerSearchBar);
    } // setupUi

    void retranslateUi(QWidget *PowerSearchBar)
    {
        label->setText(tr2i18n("Fin&d:", nullptr));
        label_3->setText(tr2i18n("Rep&lace:", nullptr));
        label_2->setText(tr2i18n("&Mode:", nullptr));
        searchMode->setItemText(0, tr2i18n("Plain text", nullptr));
        searchMode->setItemText(1, tr2i18n("Whole words", nullptr));
        searchMode->setItemText(2, tr2i18n("Escape sequences", nullptr));
        searchMode->setItemText(3, tr2i18n("Regular expression", nullptr));

#if QT_CONFIG(tooltip)
        searchMode->setToolTip(tr2i18n("Search mode", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        matchCase->setToolTip(tr2i18n("Match case sensitive", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        selectionOnly->setToolTip(tr2i18n("Search in the selection only", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        findNext->setToolTip(tr2i18n("Jump to next match", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        findPrev->setToolTip(tr2i18n("Jump to previous match", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        replaceNext->setToolTip(tr2i18n("Replace next match", nullptr));
#endif // QT_CONFIG(tooltip)
        replaceNext->setText(tr2i18n("&Replace", nullptr));
#if QT_CONFIG(tooltip)
        replaceAll->setToolTip(tr2i18n("Replace all matches", nullptr));
#endif // QT_CONFIG(tooltip)
        replaceAll->setText(tr2i18n("Replace &All", nullptr));
        findAll->setText(tr2i18n("&Find All", nullptr));
        cancel->setText(tr2i18n("Cancel", nullptr));
#if QT_CONFIG(tooltip)
        mutate->setToolTip(tr2i18n("Switch to incremental search bar", nullptr));
#endif // QT_CONFIG(tooltip)
        mutate->setText(QString());
#if QT_CONFIG(tooltip)
        pattern->setToolTip(tr2i18n("Text to search for", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        replacement->setToolTip(tr2i18n("Text to replace with", nullptr));
#endif // QT_CONFIG(tooltip)
        (void)PowerSearchBar;
    } // retranslateUi

};

namespace Ui {
    class PowerSearchBar: public Ui_PowerSearchBar {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SEARCHBARPOWER_H

