/********************************************************************************
** Form generated from reading UI file 'opensaveconfigwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPENSAVECONFIGWIDGET_H
#define UI_OPENSAVECONFIGWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_OpenSaveConfigWidget
{
public:
    QVBoxLayout *vboxLayout;
    QGroupBox *gbFileFormat;
    QFormLayout *formLayout_2;
    QFormLayout *formLayout;
    QLabel *lblEncoding;
    QComboBox *cmbEncoding;
    QLabel *lblEncodingDetection;
    QComboBox *cmbEncodingDetection;
    QLabel *lblEncodingDetection2;
    QComboBox *cmbEncodingFallback;
    QLabel *lblEOL;
    QComboBox *cmbEOL;
    QCheckBox *chkDetectEOL;
    QCheckBox *chkEnableBOM;
    QLabel *label;
    QSpinBox *lineLengthLimit;
    QGroupBox *gbCleanups;
    QVBoxLayout *vboxLayout1;
    QHBoxLayout *horizontalLayout;
    QLabel *lblRemoveTrailingSpaces;
    QComboBox *cbRemoveTrailingSpaces;
    QSpacerItem *horizontalSpacer;
    QCheckBox *chkNewLineAtEof;
    QGroupBox *gbAutoSave;
    QVBoxLayout *verticalLayout;
    QCheckBox *cbAutoSaveOnFocus;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_2;
    QSpinBox *spbAutoSaveInterval;
    QSpacerItem *horizontalSpacer_2;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *OpenSaveConfigWidget)
    {
        if (OpenSaveConfigWidget->objectName().isEmpty())
            OpenSaveConfigWidget->setObjectName("OpenSaveConfigWidget");
        OpenSaveConfigWidget->resize(552, 607);
        vboxLayout = new QVBoxLayout(OpenSaveConfigWidget);
        vboxLayout->setObjectName("vboxLayout");
        vboxLayout->setContentsMargins(0, 0, 0, 0);
        gbFileFormat = new QGroupBox(OpenSaveConfigWidget);
        gbFileFormat->setObjectName("gbFileFormat");
        formLayout_2 = new QFormLayout(gbFileFormat);
        formLayout_2->setObjectName("formLayout_2");
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        lblEncoding = new QLabel(gbFileFormat);
        lblEncoding->setObjectName("lblEncoding");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, lblEncoding);

        cmbEncoding = new QComboBox(gbFileFormat);
        cmbEncoding->setObjectName("cmbEncoding");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, cmbEncoding);

        lblEncodingDetection = new QLabel(gbFileFormat);
        lblEncodingDetection->setObjectName("lblEncodingDetection");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, lblEncodingDetection);

        cmbEncodingDetection = new QComboBox(gbFileFormat);
        cmbEncodingDetection->setObjectName("cmbEncodingDetection");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, cmbEncodingDetection);

        lblEncodingDetection2 = new QLabel(gbFileFormat);
        lblEncodingDetection2->setObjectName("lblEncodingDetection2");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, lblEncodingDetection2);

        cmbEncodingFallback = new QComboBox(gbFileFormat);
        cmbEncodingFallback->setObjectName("cmbEncodingFallback");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, cmbEncodingFallback);

        lblEOL = new QLabel(gbFileFormat);
        lblEOL->setObjectName("lblEOL");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, lblEOL);

        cmbEOL = new QComboBox(gbFileFormat);
        cmbEOL->addItem(QString());
        cmbEOL->addItem(QString());
        cmbEOL->addItem(QString());
        cmbEOL->setObjectName("cmbEOL");

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, cmbEOL);


        formLayout_2->setLayout(0, QFormLayout::ItemRole::SpanningRole, formLayout);

        chkDetectEOL = new QCheckBox(gbFileFormat);
        chkDetectEOL->setObjectName("chkDetectEOL");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::SpanningRole, chkDetectEOL);

        chkEnableBOM = new QCheckBox(gbFileFormat);
        chkEnableBOM->setObjectName("chkEnableBOM");

        formLayout_2->setWidget(2, QFormLayout::ItemRole::SpanningRole, chkEnableBOM);

        label = new QLabel(gbFileFormat);
        label->setObjectName("label");

        formLayout_2->setWidget(3, QFormLayout::ItemRole::LabelRole, label);

        lineLengthLimit = new QSpinBox(gbFileFormat);
        lineLengthLimit->setObjectName("lineLengthLimit");
        lineLengthLimit->setMinimum(-1);
        lineLengthLimit->setMaximum(1000000);

        formLayout_2->setWidget(3, QFormLayout::ItemRole::FieldRole, lineLengthLimit);


        vboxLayout->addWidget(gbFileFormat);

        gbCleanups = new QGroupBox(OpenSaveConfigWidget);
        gbCleanups->setObjectName("gbCleanups");
        vboxLayout1 = new QVBoxLayout(gbCleanups);
        vboxLayout1->setObjectName("vboxLayout1");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        lblRemoveTrailingSpaces = new QLabel(gbCleanups);
        lblRemoveTrailingSpaces->setObjectName("lblRemoveTrailingSpaces");

        horizontalLayout->addWidget(lblRemoveTrailingSpaces);

        cbRemoveTrailingSpaces = new QComboBox(gbCleanups);
        cbRemoveTrailingSpaces->addItem(QString());
        cbRemoveTrailingSpaces->addItem(QString());
        cbRemoveTrailingSpaces->addItem(QString());
        cbRemoveTrailingSpaces->setObjectName("cbRemoveTrailingSpaces");

        horizontalLayout->addWidget(cbRemoveTrailingSpaces);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        vboxLayout1->addLayout(horizontalLayout);

        chkNewLineAtEof = new QCheckBox(gbCleanups);
        chkNewLineAtEof->setObjectName("chkNewLineAtEof");

        vboxLayout1->addWidget(chkNewLineAtEof);


        vboxLayout->addWidget(gbCleanups);

        gbAutoSave = new QGroupBox(OpenSaveConfigWidget);
        gbAutoSave->setObjectName("gbAutoSave");
        gbAutoSave->setCheckable(true);
        verticalLayout = new QVBoxLayout(gbAutoSave);
        verticalLayout->setObjectName("verticalLayout");
        cbAutoSaveOnFocus = new QCheckBox(gbAutoSave);
        cbAutoSaveOnFocus->setObjectName("cbAutoSaveOnFocus");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(cbAutoSaveOnFocus->sizePolicy().hasHeightForWidth());
        cbAutoSaveOnFocus->setSizePolicy(sizePolicy);

        verticalLayout->addWidget(cbAutoSaveOnFocus);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        label_2 = new QLabel(gbAutoSave);
        label_2->setObjectName("label_2");

        horizontalLayout_2->addWidget(label_2);

        spbAutoSaveInterval = new QSpinBox(gbAutoSave);
        spbAutoSaveInterval->setObjectName("spbAutoSaveInterval");
        spbAutoSaveInterval->setMaximum(300);

        horizontalLayout_2->addWidget(spbAutoSaveInterval);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);


        verticalLayout->addLayout(horizontalLayout_2);


        vboxLayout->addWidget(gbAutoSave);

        spacerItem = new QSpacerItem(0, 1, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem);

#if QT_CONFIG(shortcut)
        lblEncoding->setBuddy(cmbEncoding);
        lblEncodingDetection->setBuddy(cmbEncodingDetection);
        lblEncodingDetection2->setBuddy(cmbEncodingFallback);
        lblEOL->setBuddy(cmbEOL);
        label->setBuddy(lineLengthLimit);
        lblRemoveTrailingSpaces->setBuddy(cbRemoveTrailingSpaces);
#endif // QT_CONFIG(shortcut)

        retranslateUi(OpenSaveConfigWidget);

        QMetaObject::connectSlotsByName(OpenSaveConfigWidget);
    } // setupUi

    void retranslateUi(QWidget *OpenSaveConfigWidget)
    {
        gbFileFormat->setTitle(tr2i18n("File Format", nullptr));
        lblEncoding->setText(tr2i18n("&Encoding:", nullptr));
#if QT_CONFIG(whatsthis)
        cmbEncoding->setWhatsThis(tr2i18n("This defines the standard encoding to use to open/save files, if not changed in the open/save dialog or by using a command line option.", nullptr));
#endif // QT_CONFIG(whatsthis)
        lblEncodingDetection->setText(tr2i18n("&Encoding detection:", nullptr));
#if QT_CONFIG(whatsthis)
        cmbEncodingDetection->setWhatsThis(tr2i18n("if neither the encoding chosen as standard above, nor the encoding specified in the open/save dialog, nor the encoding specified on command line match the content of the file, this detection will be run.", nullptr));
#endif // QT_CONFIG(whatsthis)
        lblEncodingDetection2->setText(tr2i18n("&Fallback encoding:", nullptr));
#if QT_CONFIG(whatsthis)
        cmbEncodingFallback->setWhatsThis(tr2i18n("This defines the fallback encoding to try for opening files if neither the encoding chosen as standard above, nor the encoding specified in the open/save dialog, nor the encoding specified on command line match the content of the file.  Before this is used, an attempt will be made to determine the encoding to use by looking for a byte order mark at start of file: if one is found, the right Unicode encoding will be chosen; otherwise encoding detection will run, if both fail the fallback encoding will be tried.", nullptr));
#endif // QT_CONFIG(whatsthis)
        lblEOL->setText(tr2i18n("E&nd of line:", nullptr));
        cmbEOL->setItemText(0, tr2i18n("UNIX", nullptr));
        cmbEOL->setItemText(1, tr2i18n("DOS/Windows", nullptr));
        cmbEOL->setItemText(2, tr2i18n("Macintosh", nullptr));

#if QT_CONFIG(whatsthis)
        chkDetectEOL->setWhatsThis(tr2i18n("If this option is enabled the editor will autodetect the end of line type. The first found end of line type will be used for the whole file.", nullptr));
#endif // QT_CONFIG(whatsthis)
        chkDetectEOL->setText(tr2i18n("A&utomatic end of line detection", nullptr));
#if QT_CONFIG(whatsthis)
        chkEnableBOM->setWhatsThis(tr2i18n("The byte order mark is a special sequence at the beginning of Unicode encoded documents. It helps editors to open text documents with the correct Unicode encoding. The byte order mark is not visible in the displayed document.", nullptr));
#endif // QT_CONFIG(whatsthis)
        chkEnableBOM->setText(tr2i18n("Enable byte order mark (BOM)", nullptr));
        label->setText(tr2i18n("Line length limit:", nullptr));
        lineLengthLimit->setSpecialValueText(tr2i18n("Unlimited", nullptr));
        gbCleanups->setTitle(tr2i18n("Automatic Cleanups on Save", nullptr));
#if QT_CONFIG(whatsthis)
        lblRemoveTrailingSpaces->setWhatsThis(tr2i18n("Depending on the choice, trailing spaces are removed when saving a document, either in the entire document or only of modified lines.", nullptr));
#endif // QT_CONFIG(whatsthis)
        lblRemoveTrailingSpaces->setText(tr2i18n("Re&move trailing spaces:", nullptr));
        cbRemoveTrailingSpaces->setItemText(0, tr2i18n("Never", nullptr));
        cbRemoveTrailingSpaces->setItemText(1, tr2i18n("On Modified Lines", nullptr));
        cbRemoveTrailingSpaces->setItemText(2, tr2i18n("In Entire Document", nullptr));

#if QT_CONFIG(whatsthis)
        cbRemoveTrailingSpaces->setWhatsThis(tr2i18n("Depending on the choice, trailing spaces are removed when saving a document, either in the entire document or only of modified lines.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(whatsthis)
        chkNewLineAtEof->setWhatsThis(tr2i18n("On save, a line break is appended to the document if not already present. The line break is visible after reloading the file.", nullptr));
#endif // QT_CONFIG(whatsthis)
        chkNewLineAtEof->setText(tr2i18n("Append newline at end of file on save", nullptr));
        gbAutoSave->setTitle(tr2i18n("Enable Auto Save (local files only)", nullptr));
        cbAutoSaveOnFocus->setText(tr2i18n("Auto save document when the active document is losing focus", nullptr));
        label_2->setText(tr2i18n("Auto save interval:", nullptr));
        spbAutoSaveInterval->setSpecialValueText(tr2i18n("Never", nullptr));
        spbAutoSaveInterval->setSuffix(tr2i18n(" seconds", nullptr));
        (void)OpenSaveConfigWidget;
    } // retranslateUi

};

namespace Ui {
    class OpenSaveConfigWidget: public Ui_OpenSaveConfigWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OPENSAVECONFIGWIDGET_H

