/****************************************************************************
** Meta object code from reading C++ file 'mainwindow.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../ktexteditor-6.25.0/src/include/ktexteditor/mainwindow.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mainwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11KTextEditor10MainWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto KTextEditor::MainWindow::qt_create_metaobjectdata<qt_meta_tag_ZN11KTextEditor10MainWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KTextEditor::MainWindow",
        "unhandledShortcutOverride",
        "",
        "QEvent*",
        "e",
        "viewChanged",
        "KTextEditor::View*",
        "view",
        "viewCreated",
        "pluginViewCreated",
        "name",
        "pluginView",
        "pluginViewDeleted",
        "widgetAdded",
        "QWidget*",
        "widget",
        "widgetRemoved"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'unhandledShortcutOverride'
        QtMocHelpers::SignalData<void(QEvent *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'viewChanged'
        QtMocHelpers::SignalData<void(KTextEditor::View *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'viewCreated'
        QtMocHelpers::SignalData<void(KTextEditor::View *)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'pluginViewCreated'
        QtMocHelpers::SignalData<void(const QString &, QObject *)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 }, { QMetaType::QObjectStar, 11 },
        }}),
        // Signal 'pluginViewDeleted'
        QtMocHelpers::SignalData<void(const QString &, QObject *)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 }, { QMetaType::QObjectStar, 11 },
        }}),
        // Signal 'widgetAdded'
        QtMocHelpers::SignalData<void(QWidget *)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Signal 'widgetRemoved'
        QtMocHelpers::SignalData<void(QWidget *)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MainWindow, qt_meta_tag_ZN11KTextEditor10MainWindowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KTextEditor::MainWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11KTextEditor10MainWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11KTextEditor10MainWindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11KTextEditor10MainWindowE_t>.metaTypes,
    nullptr
} };

void KTextEditor::MainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MainWindow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->unhandledShortcutOverride((*reinterpret_cast<std::add_pointer_t<QEvent*>>(_a[1]))); break;
        case 1: _t->viewChanged((*reinterpret_cast<std::add_pointer_t<KTextEditor::View*>>(_a[1]))); break;
        case 2: _t->viewCreated((*reinterpret_cast<std::add_pointer_t<KTextEditor::View*>>(_a[1]))); break;
        case 3: _t->pluginViewCreated((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[2]))); break;
        case 4: _t->pluginViewDeleted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[2]))); break;
        case 5: _t->widgetAdded((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1]))); break;
        case 6: _t->widgetRemoved((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)(QEvent * )>(_a, &MainWindow::unhandledShortcutOverride, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)(KTextEditor::View * )>(_a, &MainWindow::viewChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)(KTextEditor::View * )>(_a, &MainWindow::viewCreated, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)(const QString & , QObject * )>(_a, &MainWindow::pluginViewCreated, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)(const QString & , QObject * )>(_a, &MainWindow::pluginViewDeleted, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)(QWidget * )>(_a, &MainWindow::widgetAdded, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)(QWidget * )>(_a, &MainWindow::widgetRemoved, 6))
            return;
    }
}

const QMetaObject *KTextEditor::MainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KTextEditor::MainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11KTextEditor10MainWindowE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KTextEditor::MainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void KTextEditor::MainWindow::unhandledShortcutOverride(QEvent * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KTextEditor::MainWindow::viewChanged(KTextEditor::View * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void KTextEditor::MainWindow::viewCreated(KTextEditor::View * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void KTextEditor::MainWindow::pluginViewCreated(const QString & _t1, QObject * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void KTextEditor::MainWindow::pluginViewDeleted(const QString & _t1, QObject * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void KTextEditor::MainWindow::widgetAdded(QWidget * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void KTextEditor::MainWindow::widgetRemoved(QWidget * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}
QT_WARNING_POP
