/****************************************************************************
** Meta object code from reading C++ file 'kateview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../ktexteditor-6.25.0/src/view/kateview.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kateview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11KTextEditor11ViewPrivateE_t {};
} // unnamed namespace

template <> constexpr inline auto KTextEditor::ViewPrivate::qt_create_metaobjectdata<qt_meta_tag_ZN11KTextEditor11ViewPrivateE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KTextEditor::ViewPrivate",
        "completionExecuted",
        "",
        "KTextEditor::View*",
        "view",
        "KTextEditor::Cursor",
        "position",
        "KTextEditor::CodeCompletionModel*",
        "model",
        "QModelIndex",
        "completionAborted",
        "navigateLeft",
        "navigateRight",
        "navigateUp",
        "navigateDown",
        "navigateAccept",
        "navigateBack",
        "dropEventPass",
        "QDropEvent*",
        "delayedUpdateOfView",
        "caretChangedRange",
        "paste",
        "const QString*",
        "textToPaste",
        "cut",
        "copy",
        "screenshot",
        "pasteSelection",
        "pasteFromFile",
        "swapWithClipboard",
        "applyWordWrap",
        "copyFileLocation",
        "aboutToShowContextMenu",
        "aboutToHideContextMenu",
        "userInvokedCompletion",
        "inlineNotesReset",
        "inlineNotesLineChanged",
        "line",
        "setSelection",
        "KTextEditor::Range",
        "selection",
        "removeSelection",
        "removeSelectionText",
        "setBlockSelection",
        "on",
        "toggleBlockSelection",
        "clearSelection",
        "redraw",
        "finishedChangingSelection",
        "removeSelectedText",
        "selectAll",
        "indent",
        "unIndent",
        "cleanIndent",
        "formatIndent",
        "align",
        "alignOn",
        "comment",
        "uncomment",
        "toggleComment",
        "killLine",
        "goToPreviousEditingPosition",
        "goToNextEditingPosition",
        "uppercase",
        "lowercase",
        "capitalize",
        "joinLines",
        "keyReturn",
        "smartNewline",
        "noIndentNewline",
        "newLineAbove",
        "newLineBelow",
        "backspace",
        "deleteWordLeft",
        "subword",
        "keyDelete",
        "deleteWordRight",
        "transpose",
        "transposeWord",
        "cursorLeft",
        "shiftCursorLeft",
        "cursorRight",
        "shiftCursorRight",
        "wordLeft",
        "shiftWordLeft",
        "wordRight",
        "shiftWordRight",
        "markSelection",
        "home",
        "shiftHome",
        "end",
        "shiftEnd",
        "up",
        "shiftUp",
        "down",
        "shiftDown",
        "scrollUp",
        "scrollDown",
        "topOfView",
        "shiftTopOfView",
        "bottomOfView",
        "shiftBottomOfView",
        "pageUp",
        "shiftPageUp",
        "pageDown",
        "shiftPageDown",
        "top",
        "shiftTop",
        "bottom",
        "shiftBottom",
        "toMatchingBracket",
        "shiftToMatchingBracket",
        "toPrevModifiedLine",
        "toNextModifiedLine",
        "insertTab",
        "gotoLine",
        "setEol",
        "eol",
        "setAddBom",
        "enabled",
        "find",
        "findSelectedForwards",
        "findSelectedBackwards",
        "findNextOccurunceAndSelect",
        "findAllOccuruncesAndSelect",
        "skipCurrentOccurunceSelection",
        "replace",
        "findNext",
        "findPrevious",
        "showSearchWrappedHint",
        "isReverseSearch",
        "createMultiCursorsFromSelection",
        "removeCursorsFromEmptyLines",
        "setFoldingMarkersOn",
        "enable",
        "setIconBorder",
        "setLineNumbersOn",
        "setScrollBarMarks",
        "setScrollBarMiniMap",
        "setScrollBarMiniMapAll",
        "setScrollBarMiniMapWidth",
        "width",
        "toggleFoldingMarkers",
        "toggleIconBorder",
        "toggleLineNumbersOn",
        "toggleScrollBarMarks",
        "toggleScrollBarMiniMap",
        "toggleScrollBarMiniMapAll",
        "toggleShowSpaces",
        "toggleDynWordWrap",
        "setDynWrapIndicators",
        "mode",
        "slotSelectionChanged",
        "toggleInputMode",
        "cycleInputMode",
        "slotUpdateUndo",
        "toggleInsert",
        "reloadFile",
        "toggleWWMarker",
        "toggleNPSpaces",
        "toggleWordCount",
        "toggleWriteLock",
        "switchToCmdLine",
        "slotReadWriteChanged",
        "toggleCamelCaseCursor",
        "slotDocumentReloaded",
        "slotDocumentAboutToReload",
        "slotGotFocus",
        "slotLostFocus",
        "slotSaveCanceled",
        "error",
        "slotConfigDialog",
        "exportHtmlToClipboard",
        "exportHtmlToFile",
        "slotFoldToplevelNodes",
        "slotExpandToplevelNodes",
        "slotToggleFolding",
        "slotToggleFoldingsInRange",
        "slotHlChanged",
        "updateFoldingConfig",
        "toggleOnTheFlySpellCheck",
        "b",
        "changeDictionary",
        "reflectOnTheFlySpellCheckStatus",
        "saveFoldingState",
        "applyFoldingState",
        "slotDelayedUpdateOfView",
        "print",
        "printPreview"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'completionExecuted'
        QtMocHelpers::SignalData<void(KTextEditor::View *, KTextEditor::Cursor, KTextEditor::CodeCompletionModel *, const QModelIndex &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 }, { 0x80000000 | 7, 8 }, { 0x80000000 | 9, 2 },
        }}),
        // Signal 'completionAborted'
        QtMocHelpers::SignalData<void(KTextEditor::View *)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'navigateLeft'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'navigateRight'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'navigateUp'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'navigateDown'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'navigateAccept'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'navigateBack'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dropEventPass'
        QtMocHelpers::SignalData<void(QDropEvent *)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 2 },
        }}),
        // Signal 'delayedUpdateOfView'
        QtMocHelpers::SignalData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'caretChangedRange'
        QtMocHelpers::SignalData<void(KTextEditor::View *)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Slot 'paste'
        QtMocHelpers::SlotData<void(const QString *)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Slot 'paste'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'cut'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'copy'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'screenshot'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'pasteSelection'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'pasteFromFile'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'swapWithClipboard'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'applyWordWrap'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'copyFileLocation'
        QtMocHelpers::SlotData<void() const>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'aboutToShowContextMenu'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'aboutToHideContextMenu'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'userInvokedCompletion'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'inlineNotesReset'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'inlineNotesLineChanged'
        QtMocHelpers::SlotData<void(int)>(36, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 37 },
        }}),
        // Slot 'setSelection'
        QtMocHelpers::SlotData<bool(KTextEditor::Range)>(38, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 39, 40 },
        }}),
        // Slot 'removeSelection'
        QtMocHelpers::SlotData<bool()>(41, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'removeSelectionText'
        QtMocHelpers::SlotData<bool()>(42, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'setBlockSelection'
        QtMocHelpers::SlotData<bool(bool)>(43, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Bool, 44 },
        }}),
        // Slot 'toggleBlockSelection'
        QtMocHelpers::SlotData<bool()>(45, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'clearSelection'
        QtMocHelpers::SlotData<bool()>(46, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'clearSelection'
        QtMocHelpers::SlotData<bool(bool, bool)>(46, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Bool, 47 }, { QMetaType::Bool, 48 },
        }}),
        // Slot 'clearSelection'
        QtMocHelpers::SlotData<bool(bool)>(46, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::Bool, 47 },
        }}),
        // Slot 'removeSelectedText'
        QtMocHelpers::SlotData<bool()>(49, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'selectAll'
        QtMocHelpers::SlotData<bool()>(50, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'indent'
        QtMocHelpers::SlotData<void()>(51, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'unIndent'
        QtMocHelpers::SlotData<void()>(52, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'cleanIndent'
        QtMocHelpers::SlotData<void()>(53, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'formatIndent'
        QtMocHelpers::SlotData<void()>(54, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'align'
        QtMocHelpers::SlotData<void()>(55, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'alignOn'
        QtMocHelpers::SlotData<void()>(56, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'comment'
        QtMocHelpers::SlotData<void()>(57, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'uncomment'
        QtMocHelpers::SlotData<void()>(58, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleComment'
        QtMocHelpers::SlotData<void()>(59, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'killLine'
        QtMocHelpers::SlotData<void()>(60, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'goToPreviousEditingPosition'
        QtMocHelpers::SlotData<void()>(61, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'goToNextEditingPosition'
        QtMocHelpers::SlotData<void()>(62, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'uppercase'
        QtMocHelpers::SlotData<void()>(63, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'lowercase'
        QtMocHelpers::SlotData<void()>(64, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'capitalize'
        QtMocHelpers::SlotData<void()>(65, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'joinLines'
        QtMocHelpers::SlotData<void()>(66, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'keyReturn'
        QtMocHelpers::SlotData<void()>(67, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'smartNewline'
        QtMocHelpers::SlotData<void()>(68, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'noIndentNewline'
        QtMocHelpers::SlotData<void()>(69, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'newLineAbove'
        QtMocHelpers::SlotData<void()>(70, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'newLineBelow'
        QtMocHelpers::SlotData<void()>(71, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'backspace'
        QtMocHelpers::SlotData<void()>(72, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'deleteWordLeft'
        QtMocHelpers::SlotData<void(bool)>(73, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 74 },
        }}),
        // Slot 'deleteWordLeft'
        QtMocHelpers::SlotData<void()>(73, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'keyDelete'
        QtMocHelpers::SlotData<void()>(75, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'deleteWordRight'
        QtMocHelpers::SlotData<void(bool)>(76, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 74 },
        }}),
        // Slot 'deleteWordRight'
        QtMocHelpers::SlotData<void()>(76, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'transpose'
        QtMocHelpers::SlotData<void()>(77, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'transposeWord'
        QtMocHelpers::SlotData<void()>(78, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'cursorLeft'
        QtMocHelpers::SlotData<void()>(79, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'shiftCursorLeft'
        QtMocHelpers::SlotData<void()>(80, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'cursorRight'
        QtMocHelpers::SlotData<void()>(81, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'shiftCursorRight'
        QtMocHelpers::SlotData<void()>(82, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'wordLeft'
        QtMocHelpers::SlotData<void(bool)>(83, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 74 },
        }}),
        // Slot 'wordLeft'
        QtMocHelpers::SlotData<void()>(83, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'shiftWordLeft'
        QtMocHelpers::SlotData<void(bool)>(84, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 74 },
        }}),
        // Slot 'shiftWordLeft'
        QtMocHelpers::SlotData<void()>(84, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'wordRight'
        QtMocHelpers::SlotData<void(bool)>(85, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 74 },
        }}),
        // Slot 'wordRight'
        QtMocHelpers::SlotData<void()>(85, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'shiftWordRight'
        QtMocHelpers::SlotData<void(bool)>(86, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 74 },
        }}),
        // Slot 'shiftWordRight'
        QtMocHelpers::SlotData<void()>(86, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'markSelection'
        QtMocHelpers::SlotData<void()>(87, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'home'
        QtMocHelpers::SlotData<void()>(88, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'shiftHome'
        QtMocHelpers::SlotData<void()>(89, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'end'
        QtMocHelpers::SlotData<void()>(90, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'shiftEnd'
        QtMocHelpers::SlotData<void()>(91, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'up'
        QtMocHelpers::SlotData<void()>(92, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'shiftUp'
        QtMocHelpers::SlotData<void()>(93, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'down'
        QtMocHelpers::SlotData<void()>(94, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'shiftDown'
        QtMocHelpers::SlotData<void()>(95, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'scrollUp'
        QtMocHelpers::SlotData<void()>(96, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'scrollDown'
        QtMocHelpers::SlotData<void()>(97, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'topOfView'
        QtMocHelpers::SlotData<void()>(98, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'shiftTopOfView'
        QtMocHelpers::SlotData<void()>(99, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'bottomOfView'
        QtMocHelpers::SlotData<void()>(100, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'shiftBottomOfView'
        QtMocHelpers::SlotData<void()>(101, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'pageUp'
        QtMocHelpers::SlotData<void()>(102, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'shiftPageUp'
        QtMocHelpers::SlotData<void()>(103, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'pageDown'
        QtMocHelpers::SlotData<void()>(104, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'shiftPageDown'
        QtMocHelpers::SlotData<void()>(105, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'top'
        QtMocHelpers::SlotData<void()>(106, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'shiftTop'
        QtMocHelpers::SlotData<void()>(107, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'bottom'
        QtMocHelpers::SlotData<void()>(108, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'shiftBottom'
        QtMocHelpers::SlotData<void()>(109, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toMatchingBracket'
        QtMocHelpers::SlotData<void()>(110, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'shiftToMatchingBracket'
        QtMocHelpers::SlotData<void()>(111, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toPrevModifiedLine'
        QtMocHelpers::SlotData<void()>(112, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toNextModifiedLine'
        QtMocHelpers::SlotData<void()>(113, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'insertTab'
        QtMocHelpers::SlotData<void()>(114, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'gotoLine'
        QtMocHelpers::SlotData<void()>(115, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setEol'
        QtMocHelpers::SlotData<void(int)>(116, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 117 },
        }}),
        // Slot 'setAddBom'
        QtMocHelpers::SlotData<void(bool)>(118, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 119 },
        }}),
        // Slot 'find'
        QtMocHelpers::SlotData<void()>(120, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'findSelectedForwards'
        QtMocHelpers::SlotData<void()>(121, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'findSelectedBackwards'
        QtMocHelpers::SlotData<void()>(122, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'findNextOccurunceAndSelect'
        QtMocHelpers::SlotData<void()>(123, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'findAllOccuruncesAndSelect'
        QtMocHelpers::SlotData<void()>(124, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'skipCurrentOccurunceSelection'
        QtMocHelpers::SlotData<void()>(125, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'replace'
        QtMocHelpers::SlotData<void()>(126, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'findNext'
        QtMocHelpers::SlotData<void()>(127, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'findPrevious'
        QtMocHelpers::SlotData<void()>(128, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showSearchWrappedHint'
        QtMocHelpers::SlotData<void(bool)>(129, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 130 },
        }}),
        // Slot 'createMultiCursorsFromSelection'
        QtMocHelpers::SlotData<void()>(131, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'removeCursorsFromEmptyLines'
        QtMocHelpers::SlotData<void()>(132, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setFoldingMarkersOn'
        QtMocHelpers::SlotData<void(bool)>(133, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 134 },
        }}),
        // Slot 'setIconBorder'
        QtMocHelpers::SlotData<void(bool)>(135, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 134 },
        }}),
        // Slot 'setLineNumbersOn'
        QtMocHelpers::SlotData<void(bool)>(136, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 134 },
        }}),
        // Slot 'setScrollBarMarks'
        QtMocHelpers::SlotData<void(bool)>(137, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 134 },
        }}),
        // Slot 'setScrollBarMiniMap'
        QtMocHelpers::SlotData<void(bool)>(138, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 134 },
        }}),
        // Slot 'setScrollBarMiniMapAll'
        QtMocHelpers::SlotData<void(bool)>(139, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 134 },
        }}),
        // Slot 'setScrollBarMiniMapWidth'
        QtMocHelpers::SlotData<void(int)>(140, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 141 },
        }}),
        // Slot 'toggleFoldingMarkers'
        QtMocHelpers::SlotData<void()>(142, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleIconBorder'
        QtMocHelpers::SlotData<void()>(143, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleLineNumbersOn'
        QtMocHelpers::SlotData<void()>(144, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleScrollBarMarks'
        QtMocHelpers::SlotData<void()>(145, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleScrollBarMiniMap'
        QtMocHelpers::SlotData<void()>(146, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleScrollBarMiniMapAll'
        QtMocHelpers::SlotData<void()>(147, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleShowSpaces'
        QtMocHelpers::SlotData<void()>(148, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleDynWordWrap'
        QtMocHelpers::SlotData<void()>(149, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setDynWrapIndicators'
        QtMocHelpers::SlotData<void(int)>(150, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 151 },
        }}),
        // Slot 'slotSelectionChanged'
        QtMocHelpers::SlotData<void()>(152, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toggleInputMode'
        QtMocHelpers::SlotData<void()>(153, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'cycleInputMode'
        QtMocHelpers::SlotData<void()>(154, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotUpdateUndo'
        QtMocHelpers::SlotData<void()>(155, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleInsert'
        QtMocHelpers::SlotData<void()>(156, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'reloadFile'
        QtMocHelpers::SlotData<void()>(157, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleWWMarker'
        QtMocHelpers::SlotData<void()>(158, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleNPSpaces'
        QtMocHelpers::SlotData<void()>(159, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleWordCount'
        QtMocHelpers::SlotData<void(bool)>(160, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 44 },
        }}),
        // Slot 'toggleWriteLock'
        QtMocHelpers::SlotData<void()>(161, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'switchToCmdLine'
        QtMocHelpers::SlotData<void()>(162, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotReadWriteChanged'
        QtMocHelpers::SlotData<void()>(163, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleCamelCaseCursor'
        QtMocHelpers::SlotData<void()>(164, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotDocumentReloaded'
        QtMocHelpers::SlotData<void()>(165, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDocumentAboutToReload'
        QtMocHelpers::SlotData<void()>(166, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotGotFocus'
        QtMocHelpers::SlotData<void()>(167, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotLostFocus'
        QtMocHelpers::SlotData<void()>(168, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSaveCanceled'
        QtMocHelpers::SlotData<void(const QString &)>(169, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 170 },
        }}),
        // Slot 'slotConfigDialog'
        QtMocHelpers::SlotData<void()>(171, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'exportHtmlToClipboard'
        QtMocHelpers::SlotData<void()>(172, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'exportHtmlToFile'
        QtMocHelpers::SlotData<void()>(173, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotFoldToplevelNodes'
        QtMocHelpers::SlotData<void()>(174, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotExpandToplevelNodes'
        QtMocHelpers::SlotData<void()>(175, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotToggleFolding'
        QtMocHelpers::SlotData<void()>(176, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotToggleFoldingsInRange'
        QtMocHelpers::SlotData<void()>(177, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotHlChanged'
        QtMocHelpers::SlotData<void()>(178, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateFoldingConfig'
        QtMocHelpers::SlotData<void()>(179, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toggleOnTheFlySpellCheck'
        QtMocHelpers::SlotData<void(bool)>(180, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 181 },
        }}),
        // Slot 'changeDictionary'
        QtMocHelpers::SlotData<void()>(182, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'reflectOnTheFlySpellCheckStatus'
        QtMocHelpers::SlotData<void(bool)>(183, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 119 },
        }}),
        // Slot 'saveFoldingState'
        QtMocHelpers::SlotData<void()>(184, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'applyFoldingState'
        QtMocHelpers::SlotData<void()>(185, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDelayedUpdateOfView'
        QtMocHelpers::SlotData<void()>(186, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'print'
        QtMocHelpers::SlotData<bool()>(187, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'printPreview'
        QtMocHelpers::SlotData<void()>(188, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ViewPrivate, qt_meta_tag_ZN11KTextEditor11ViewPrivateE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KTextEditor::ViewPrivate::staticMetaObject = { {
    QMetaObject::SuperData::link<KTextEditor::View::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11KTextEditor11ViewPrivateE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11KTextEditor11ViewPrivateE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11KTextEditor11ViewPrivateE_t>.metaTypes,
    nullptr
} };

void KTextEditor::ViewPrivate::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ViewPrivate *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->completionExecuted((*reinterpret_cast<std::add_pointer_t<KTextEditor::View*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KTextEditor::Cursor>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<KTextEditor::CodeCompletionModel*>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[4]))); break;
        case 1: _t->completionAborted((*reinterpret_cast<std::add_pointer_t<KTextEditor::View*>>(_a[1]))); break;
        case 2: _t->navigateLeft(); break;
        case 3: _t->navigateRight(); break;
        case 4: _t->navigateUp(); break;
        case 5: _t->navigateDown(); break;
        case 6: _t->navigateAccept(); break;
        case 7: _t->navigateBack(); break;
        case 8: _t->dropEventPass((*reinterpret_cast<std::add_pointer_t<QDropEvent*>>(_a[1]))); break;
        case 9: _t->delayedUpdateOfView(); break;
        case 10: _t->caretChangedRange((*reinterpret_cast<std::add_pointer_t<KTextEditor::View*>>(_a[1]))); break;
        case 11: _t->paste((*reinterpret_cast<std::add_pointer_t<const QString*>>(_a[1]))); break;
        case 12: _t->paste(); break;
        case 13: _t->cut(); break;
        case 14: _t->copy(); break;
        case 15: _t->screenshot(); break;
        case 16: _t->pasteSelection(); break;
        case 17: _t->pasteFromFile(); break;
        case 18: _t->swapWithClipboard(); break;
        case 19: _t->applyWordWrap(); break;
        case 20: _t->copyFileLocation(); break;
        case 21: _t->aboutToShowContextMenu(); break;
        case 22: _t->aboutToHideContextMenu(); break;
        case 23: _t->userInvokedCompletion(); break;
        case 24: _t->inlineNotesReset(); break;
        case 25: _t->inlineNotesLineChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 26: { bool _r = _t->setSelection((*reinterpret_cast<std::add_pointer_t<KTextEditor::Range>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 27: { bool _r = _t->removeSelection();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 28: { bool _r = _t->removeSelectionText();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 29: { bool _r = _t->setBlockSelection((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 30: { bool _r = _t->toggleBlockSelection();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 31: { bool _r = _t->clearSelection();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 32: { bool _r = _t->clearSelection((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 33: { bool _r = _t->clearSelection((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 34: { bool _r = _t->removeSelectedText();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 35: { bool _r = _t->selectAll();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 36: _t->indent(); break;
        case 37: _t->unIndent(); break;
        case 38: _t->cleanIndent(); break;
        case 39: _t->formatIndent(); break;
        case 40: _t->align(); break;
        case 41: _t->alignOn(); break;
        case 42: _t->comment(); break;
        case 43: _t->uncomment(); break;
        case 44: _t->toggleComment(); break;
        case 45: _t->killLine(); break;
        case 46: _t->goToPreviousEditingPosition(); break;
        case 47: _t->goToNextEditingPosition(); break;
        case 48: _t->uppercase(); break;
        case 49: _t->lowercase(); break;
        case 50: _t->capitalize(); break;
        case 51: _t->joinLines(); break;
        case 52: _t->keyReturn(); break;
        case 53: _t->smartNewline(); break;
        case 54: _t->noIndentNewline(); break;
        case 55: _t->newLineAbove(); break;
        case 56: _t->newLineBelow(); break;
        case 57: _t->backspace(); break;
        case 58: _t->deleteWordLeft((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 59: _t->deleteWordLeft(); break;
        case 60: _t->keyDelete(); break;
        case 61: _t->deleteWordRight((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 62: _t->deleteWordRight(); break;
        case 63: _t->transpose(); break;
        case 64: _t->transposeWord(); break;
        case 65: _t->cursorLeft(); break;
        case 66: _t->shiftCursorLeft(); break;
        case 67: _t->cursorRight(); break;
        case 68: _t->shiftCursorRight(); break;
        case 69: _t->wordLeft((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 70: _t->wordLeft(); break;
        case 71: _t->shiftWordLeft((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 72: _t->shiftWordLeft(); break;
        case 73: _t->wordRight((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 74: _t->wordRight(); break;
        case 75: _t->shiftWordRight((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 76: _t->shiftWordRight(); break;
        case 77: _t->markSelection(); break;
        case 78: _t->home(); break;
        case 79: _t->shiftHome(); break;
        case 80: _t->end(); break;
        case 81: _t->shiftEnd(); break;
        case 82: _t->up(); break;
        case 83: _t->shiftUp(); break;
        case 84: _t->down(); break;
        case 85: _t->shiftDown(); break;
        case 86: _t->scrollUp(); break;
        case 87: _t->scrollDown(); break;
        case 88: _t->topOfView(); break;
        case 89: _t->shiftTopOfView(); break;
        case 90: _t->bottomOfView(); break;
        case 91: _t->shiftBottomOfView(); break;
        case 92: _t->pageUp(); break;
        case 93: _t->shiftPageUp(); break;
        case 94: _t->pageDown(); break;
        case 95: _t->shiftPageDown(); break;
        case 96: _t->top(); break;
        case 97: _t->shiftTop(); break;
        case 98: _t->bottom(); break;
        case 99: _t->shiftBottom(); break;
        case 100: _t->toMatchingBracket(); break;
        case 101: _t->shiftToMatchingBracket(); break;
        case 102: _t->toPrevModifiedLine(); break;
        case 103: _t->toNextModifiedLine(); break;
        case 104: _t->insertTab(); break;
        case 105: _t->gotoLine(); break;
        case 106: _t->setEol((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 107: _t->setAddBom((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 108: _t->find(); break;
        case 109: _t->findSelectedForwards(); break;
        case 110: _t->findSelectedBackwards(); break;
        case 111: _t->findNextOccurunceAndSelect(); break;
        case 112: _t->findAllOccuruncesAndSelect(); break;
        case 113: _t->skipCurrentOccurunceSelection(); break;
        case 114: _t->replace(); break;
        case 115: _t->findNext(); break;
        case 116: _t->findPrevious(); break;
        case 117: _t->showSearchWrappedHint((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 118: _t->createMultiCursorsFromSelection(); break;
        case 119: _t->removeCursorsFromEmptyLines(); break;
        case 120: _t->setFoldingMarkersOn((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 121: _t->setIconBorder((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 122: _t->setLineNumbersOn((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 123: _t->setScrollBarMarks((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 124: _t->setScrollBarMiniMap((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 125: _t->setScrollBarMiniMapAll((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 126: _t->setScrollBarMiniMapWidth((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 127: _t->toggleFoldingMarkers(); break;
        case 128: _t->toggleIconBorder(); break;
        case 129: _t->toggleLineNumbersOn(); break;
        case 130: _t->toggleScrollBarMarks(); break;
        case 131: _t->toggleScrollBarMiniMap(); break;
        case 132: _t->toggleScrollBarMiniMapAll(); break;
        case 133: _t->toggleShowSpaces(); break;
        case 134: _t->toggleDynWordWrap(); break;
        case 135: _t->setDynWrapIndicators((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 136: _t->slotSelectionChanged(); break;
        case 137: _t->toggleInputMode(); break;
        case 138: _t->cycleInputMode(); break;
        case 139: _t->slotUpdateUndo(); break;
        case 140: _t->toggleInsert(); break;
        case 141: _t->reloadFile(); break;
        case 142: _t->toggleWWMarker(); break;
        case 143: _t->toggleNPSpaces(); break;
        case 144: _t->toggleWordCount((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 145: _t->toggleWriteLock(); break;
        case 146: _t->switchToCmdLine(); break;
        case 147: _t->slotReadWriteChanged(); break;
        case 148: _t->toggleCamelCaseCursor(); break;
        case 149: _t->slotDocumentReloaded(); break;
        case 150: _t->slotDocumentAboutToReload(); break;
        case 151: _t->slotGotFocus(); break;
        case 152: _t->slotLostFocus(); break;
        case 153: _t->slotSaveCanceled((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 154: _t->slotConfigDialog(); break;
        case 155: _t->exportHtmlToClipboard(); break;
        case 156: _t->exportHtmlToFile(); break;
        case 157: _t->slotFoldToplevelNodes(); break;
        case 158: _t->slotExpandToplevelNodes(); break;
        case 159: _t->slotToggleFolding(); break;
        case 160: _t->slotToggleFoldingsInRange(); break;
        case 161: _t->slotHlChanged(); break;
        case 162: _t->updateFoldingConfig(); break;
        case 163: _t->toggleOnTheFlySpellCheck((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 164: _t->changeDictionary(); break;
        case 165: _t->reflectOnTheFlySpellCheckStatus((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 166: _t->saveFoldingState(); break;
        case 167: _t->applyFoldingState(); break;
        case 168: _t->slotDelayedUpdateOfView(); break;
        case 169: { bool _r = _t->print();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 170: _t->printPreview(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KTextEditor::CodeCompletionModel* >(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KTextEditor::View* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KTextEditor::View* >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KTextEditor::View* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ViewPrivate::*)(KTextEditor::View * , KTextEditor::Cursor , KTextEditor::CodeCompletionModel * , const QModelIndex & )>(_a, &ViewPrivate::completionExecuted, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ViewPrivate::*)(KTextEditor::View * )>(_a, &ViewPrivate::completionAborted, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ViewPrivate::*)()>(_a, &ViewPrivate::navigateLeft, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ViewPrivate::*)()>(_a, &ViewPrivate::navigateRight, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ViewPrivate::*)()>(_a, &ViewPrivate::navigateUp, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ViewPrivate::*)()>(_a, &ViewPrivate::navigateDown, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ViewPrivate::*)()>(_a, &ViewPrivate::navigateAccept, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ViewPrivate::*)()>(_a, &ViewPrivate::navigateBack, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (ViewPrivate::*)(QDropEvent * )>(_a, &ViewPrivate::dropEventPass, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (ViewPrivate::*)()>(_a, &ViewPrivate::delayedUpdateOfView, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (ViewPrivate::*)(KTextEditor::View * )>(_a, &ViewPrivate::caretChangedRange, 10))
            return;
    }
}

const QMetaObject *KTextEditor::ViewPrivate::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KTextEditor::ViewPrivate::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11KTextEditor11ViewPrivateE_t>.strings))
        return static_cast<void*>(this);
    return KTextEditor::View::qt_metacast(_clname);
}

int KTextEditor::ViewPrivate::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KTextEditor::View::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 171)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 171;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 171)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 171;
    }
    return _id;
}

// SIGNAL 0
void KTextEditor::ViewPrivate::completionExecuted(KTextEditor::View * _t1, KTextEditor::Cursor _t2, KTextEditor::CodeCompletionModel * _t3, const QModelIndex & _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 1
void KTextEditor::ViewPrivate::completionAborted(KTextEditor::View * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void KTextEditor::ViewPrivate::navigateLeft()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KTextEditor::ViewPrivate::navigateRight()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KTextEditor::ViewPrivate::navigateUp()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void KTextEditor::ViewPrivate::navigateDown()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void KTextEditor::ViewPrivate::navigateAccept()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void KTextEditor::ViewPrivate::navigateBack()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void KTextEditor::ViewPrivate::dropEventPass(QDropEvent * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void KTextEditor::ViewPrivate::delayedUpdateOfView()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void KTextEditor::ViewPrivate::caretChangedRange(KTextEditor::View * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}
QT_WARNING_POP
