/********************************************************************************
** Form generated from reading UI file 'configwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONFIGWIDGET_H
#define UI_CONFIGWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

namespace KateVi {

class Ui_ConfigWidget
{
public:
    QVBoxLayout *verticalLayout_3;
    QGroupBox *gbViInputMode;
    QVBoxLayout *vboxLayout;
    QCheckBox *chkViCommandsOverride;
    QCheckBox *chkViRelLineNumbers;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout_2;
    QTabWidget *tabMappingModes;
    QWidget *normalTab;
    QVBoxLayout *verticalLayout;
    QTableWidget *tblNormalModeMappings;
    QWidget *insertTab;
    QVBoxLayout *verticalLayout_4;
    QTableWidget *tblInsertModeMappings;
    QWidget *visualTab;
    QVBoxLayout *verticalLayout_5;
    QTableWidget *tblVisualModeMappings;
    QHBoxLayout *horizontalLayout_3;
    QPushButton *btnRemoveSelectedRows;
    QPushButton *btnAddNewRow;
    QPushButton *btnImportNormal;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *KateVi__ConfigWidget)
    {
        if (KateVi__ConfigWidget->objectName().isEmpty())
            KateVi__ConfigWidget->setObjectName("KateVi__ConfigWidget");
        KateVi__ConfigWidget->resize(439, 411);
        verticalLayout_3 = new QVBoxLayout(KateVi__ConfigWidget);
        verticalLayout_3->setObjectName("verticalLayout_3");
        verticalLayout_3->setContentsMargins(0, 0, 0, 0);
        gbViInputMode = new QGroupBox(KateVi__ConfigWidget);
        gbViInputMode->setObjectName("gbViInputMode");
        vboxLayout = new QVBoxLayout(gbViInputMode);
        vboxLayout->setObjectName("vboxLayout");
        chkViCommandsOverride = new QCheckBox(gbViInputMode);
        chkViCommandsOverride->setObjectName("chkViCommandsOverride");

        vboxLayout->addWidget(chkViCommandsOverride);

        chkViRelLineNumbers = new QCheckBox(gbViInputMode);
        chkViRelLineNumbers->setObjectName("chkViRelLineNumbers");

        vboxLayout->addWidget(chkViRelLineNumbers);


        verticalLayout_3->addWidget(gbViInputMode);

        groupBox = new QGroupBox(KateVi__ConfigWidget);
        groupBox->setObjectName("groupBox");
        verticalLayout_2 = new QVBoxLayout(groupBox);
        verticalLayout_2->setObjectName("verticalLayout_2");
        tabMappingModes = new QTabWidget(groupBox);
        tabMappingModes->setObjectName("tabMappingModes");
        normalTab = new QWidget();
        normalTab->setObjectName("normalTab");
        verticalLayout = new QVBoxLayout(normalTab);
        verticalLayout->setObjectName("verticalLayout");
        tblNormalModeMappings = new QTableWidget(normalTab);
        if (tblNormalModeMappings->columnCount() < 3)
            tblNormalModeMappings->setColumnCount(3);
        QTableWidgetItem *__qtablewidgetitem = new QTableWidgetItem();
        tblNormalModeMappings->setHorizontalHeaderItem(0, __qtablewidgetitem);
        QTableWidgetItem *__qtablewidgetitem1 = new QTableWidgetItem();
        tblNormalModeMappings->setHorizontalHeaderItem(1, __qtablewidgetitem1);
        QTableWidgetItem *__qtablewidgetitem2 = new QTableWidgetItem();
        tblNormalModeMappings->setHorizontalHeaderItem(2, __qtablewidgetitem2);
        tblNormalModeMappings->setObjectName("tblNormalModeMappings");
        tblNormalModeMappings->setAlternatingRowColors(true);
        tblNormalModeMappings->setSelectionMode(QAbstractItemView::ContiguousSelection);
        tblNormalModeMappings->setSelectionBehavior(QAbstractItemView::SelectRows);
        tblNormalModeMappings->setColumnCount(3);

        verticalLayout->addWidget(tblNormalModeMappings);

        tabMappingModes->addTab(normalTab, QString());
        insertTab = new QWidget();
        insertTab->setObjectName("insertTab");
        verticalLayout_4 = new QVBoxLayout(insertTab);
        verticalLayout_4->setObjectName("verticalLayout_4");
        tblInsertModeMappings = new QTableWidget(insertTab);
        if (tblInsertModeMappings->columnCount() < 3)
            tblInsertModeMappings->setColumnCount(3);
        QTableWidgetItem *__qtablewidgetitem3 = new QTableWidgetItem();
        tblInsertModeMappings->setHorizontalHeaderItem(0, __qtablewidgetitem3);
        QTableWidgetItem *__qtablewidgetitem4 = new QTableWidgetItem();
        tblInsertModeMappings->setHorizontalHeaderItem(1, __qtablewidgetitem4);
        QTableWidgetItem *__qtablewidgetitem5 = new QTableWidgetItem();
        tblInsertModeMappings->setHorizontalHeaderItem(2, __qtablewidgetitem5);
        tblInsertModeMappings->setObjectName("tblInsertModeMappings");
        tblInsertModeMappings->setAlternatingRowColors(true);
        tblInsertModeMappings->setSelectionMode(QAbstractItemView::ContiguousSelection);
        tblInsertModeMappings->setSelectionBehavior(QAbstractItemView::SelectRows);
        tblInsertModeMappings->setColumnCount(3);

        verticalLayout_4->addWidget(tblInsertModeMappings);

        tabMappingModes->addTab(insertTab, QString());
        visualTab = new QWidget();
        visualTab->setObjectName("visualTab");
        verticalLayout_5 = new QVBoxLayout(visualTab);
        verticalLayout_5->setObjectName("verticalLayout_5");
        tblVisualModeMappings = new QTableWidget(visualTab);
        if (tblVisualModeMappings->columnCount() < 3)
            tblVisualModeMappings->setColumnCount(3);
        QTableWidgetItem *__qtablewidgetitem6 = new QTableWidgetItem();
        tblVisualModeMappings->setHorizontalHeaderItem(0, __qtablewidgetitem6);
        QTableWidgetItem *__qtablewidgetitem7 = new QTableWidgetItem();
        tblVisualModeMappings->setHorizontalHeaderItem(1, __qtablewidgetitem7);
        QTableWidgetItem *__qtablewidgetitem8 = new QTableWidgetItem();
        tblVisualModeMappings->setHorizontalHeaderItem(2, __qtablewidgetitem8);
        tblVisualModeMappings->setObjectName("tblVisualModeMappings");
        tblVisualModeMappings->setAlternatingRowColors(true);
        tblVisualModeMappings->setSelectionMode(QAbstractItemView::ContiguousSelection);
        tblVisualModeMappings->setSelectionBehavior(QAbstractItemView::SelectRows);
        tblVisualModeMappings->setColumnCount(3);

        verticalLayout_5->addWidget(tblVisualModeMappings);

        tabMappingModes->addTab(visualTab, QString());

        verticalLayout_2->addWidget(tabMappingModes);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        btnRemoveSelectedRows = new QPushButton(groupBox);
        btnRemoveSelectedRows->setObjectName("btnRemoveSelectedRows");

        horizontalLayout_3->addWidget(btnRemoveSelectedRows);

        btnAddNewRow = new QPushButton(groupBox);
        btnAddNewRow->setObjectName("btnAddNewRow");

        horizontalLayout_3->addWidget(btnAddNewRow);

        btnImportNormal = new QPushButton(groupBox);
        btnImportNormal->setObjectName("btnImportNormal");

        horizontalLayout_3->addWidget(btnImportNormal);

        horizontalSpacer = new QSpacerItem(1, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer);


        verticalLayout_2->addLayout(horizontalLayout_3);


        verticalLayout_3->addWidget(groupBox);

        spacerItem = new QSpacerItem(0, 1, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_3->addItem(spacerItem);


        retranslateUi(KateVi__ConfigWidget);

        tabMappingModes->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(KateVi__ConfigWidget);
    } // setupUi

    void retranslateUi(QWidget *KateVi__ConfigWidget)
    {
        gbViInputMode->setTitle(tr2i18n("General", nullptr));
#if QT_CONFIG(whatsthis)
        chkViCommandsOverride->setWhatsThis(tr2i18n("When selected, vi commands will override Kate's built-in commands. For example: Ctrl+R will redo, and override the standard action (showing the search and replace dialog).", nullptr));
#endif // QT_CONFIG(whatsthis)
        chkViCommandsOverride->setText(tr2i18n("Let Vi commands override Kate shortcuts", nullptr));
#if QT_CONFIG(whatsthis)
        chkViRelLineNumbers->setWhatsThis(tr2i18n("Show the line number relative to the line with the cursor in front of each line.", nullptr));
#endif // QT_CONFIG(whatsthis)
        chkViRelLineNumbers->setText(tr2i18n("Display relative line numbers", nullptr));
#if QT_CONFIG(whatsthis)
        groupBox->setWhatsThis(tr2i18n("Key mapping is used to change the meaning of typed keys. This allows you to move commands to other keys or make special keypresses for doing a series of commands.\n"
"\n"
"Example:\n"
"\"<F2>\" \342\206\222 \"I-- <esc>\"\n"
"\n"
"This will prepend \"-- \" to a line when pressing F2.", nullptr));
#endif // QT_CONFIG(whatsthis)
        groupBox->setTitle(tr2i18n("Key Mapping", nullptr));
        QTableWidgetItem *___qtablewidgetitem = tblNormalModeMappings->horizontalHeaderItem(0);
        ___qtablewidgetitem->setText(tr2i18n("Command", nullptr));
        QTableWidgetItem *___qtablewidgetitem1 = tblNormalModeMappings->horizontalHeaderItem(1);
        ___qtablewidgetitem1->setText(tr2i18n("Replacement", nullptr));
        QTableWidgetItem *___qtablewidgetitem2 = tblNormalModeMappings->horizontalHeaderItem(2);
        ___qtablewidgetitem2->setText(tr2i18n("Recursive?", nullptr));
        tabMappingModes->setTabText(tabMappingModes->indexOf(normalTab), tr2i18n("Normal mode", nullptr));
        QTableWidgetItem *___qtablewidgetitem3 = tblInsertModeMappings->horizontalHeaderItem(0);
        ___qtablewidgetitem3->setText(tr2i18n("Command", nullptr));
        QTableWidgetItem *___qtablewidgetitem4 = tblInsertModeMappings->horizontalHeaderItem(1);
        ___qtablewidgetitem4->setText(tr2i18n("Replacement", nullptr));
        QTableWidgetItem *___qtablewidgetitem5 = tblInsertModeMappings->horizontalHeaderItem(2);
        ___qtablewidgetitem5->setText(tr2i18n("Recursive?", nullptr));
        tabMappingModes->setTabText(tabMappingModes->indexOf(insertTab), tr2i18n("Insert mode", nullptr));
        QTableWidgetItem *___qtablewidgetitem6 = tblVisualModeMappings->horizontalHeaderItem(0);
        ___qtablewidgetitem6->setText(tr2i18n("Command", nullptr));
        QTableWidgetItem *___qtablewidgetitem7 = tblVisualModeMappings->horizontalHeaderItem(1);
        ___qtablewidgetitem7->setText(tr2i18n("Replacement", nullptr));
        QTableWidgetItem *___qtablewidgetitem8 = tblVisualModeMappings->horizontalHeaderItem(2);
        ___qtablewidgetitem8->setText(tr2i18n("Recursive?", nullptr));
        tabMappingModes->setTabText(tabMappingModes->indexOf(visualTab), tr2i18n("Visual mode", nullptr));
        btnRemoveSelectedRows->setText(tr2i18n("Remove selected", nullptr));
        btnAddNewRow->setText(tr2i18n("Add new mapping", nullptr));
#if QT_CONFIG(tooltip)
        btnImportNormal->setToolTip(tr2i18n("Read a vimrc file and attempt to import mappings specified with the \"[n]noremap\" command.", nullptr));
#endif // QT_CONFIG(tooltip)
        btnImportNormal->setText(tr2i18n("Import from vimrc file", nullptr));
        (void)KateVi__ConfigWidget;
    } // retranslateUi

};

} // namespace KateVi

namespace KateVi {
namespace Ui {
    class ConfigWidget: public Ui_ConfigWidget {};
} // namespace Ui
} // namespace KateVi

#endif // CONFIGWIDGET_H

