/****************************************************************************
** Meta object code from reading C++ file 'kateviewinternal.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../ktexteditor-6.25.0/src/view/kateviewinternal.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kateviewinternal.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16KateViewInternalE_t {};
} // unnamed namespace

template <> constexpr inline auto KateViewInternal::qt_create_metaobjectdata<qt_meta_tag_ZN16KateViewInternalE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KateViewInternal",
        "dropEventPass",
        "",
        "QDropEvent*",
        "updateView",
        "changed",
        "viewLinesScrolled",
        "slotIncFontSizes",
        "step",
        "slotDecFontSizes",
        "slotResetFontSizes",
        "paintCursor",
        "scrollLines",
        "line",
        "scrollViewLines",
        "offset",
        "scrollAction",
        "action",
        "scrollNextPage",
        "scrollPrevPage",
        "scrollPrevLine",
        "scrollNextLine",
        "scrollColumns",
        "x",
        "viewSelectionChanged",
        "tripleClickTimeout",
        "slotRegionVisibilityChanged",
        "slotRegionBeginEndAddedRemoved",
        "doDragScroll",
        "startDragScroll",
        "stopDragScroll",
        "scrollTimeout",
        "cursorTimeout",
        "textHintTimeout",
        "resizeTimeout",
        "documentTextInserted",
        "KTextEditor::Document*",
        "document",
        "KTextEditor::Range",
        "range",
        "documentTextRemoved",
        "oldText"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'dropEventPass'
        QtMocHelpers::SignalData<void(QDropEvent *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Slot 'updateView'
        QtMocHelpers::SlotData<void(bool, int)>(4, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 5 }, { QMetaType::Int, 6 },
        }}),
        // Slot 'updateView'
        QtMocHelpers::SlotData<void(bool)>(4, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Slot 'updateView'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'slotIncFontSizes'
        QtMocHelpers::SlotData<void(qreal)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 8 },
        }}),
        // Slot 'slotIncFontSizes'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'slotDecFontSizes'
        QtMocHelpers::SlotData<void(qreal)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 8 },
        }}),
        // Slot 'slotDecFontSizes'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'slotResetFontSizes'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'paintCursor'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'scrollLines'
        QtMocHelpers::SlotData<void(int)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 13 },
        }}),
        // Slot 'scrollViewLines'
        QtMocHelpers::SlotData<void(int)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 15 },
        }}),
        // Slot 'scrollAction'
        QtMocHelpers::SlotData<void(int)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 17 },
        }}),
        // Slot 'scrollNextPage'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'scrollPrevPage'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'scrollPrevLine'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'scrollNextLine'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'scrollColumns'
        QtMocHelpers::SlotData<void(int)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 23 },
        }}),
        // Slot 'viewSelectionChanged'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'tripleClickTimeout'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotRegionVisibilityChanged'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotRegionBeginEndAddedRemoved'
        QtMocHelpers::SlotData<void(unsigned int)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::UInt, 2 },
        }}),
        // Slot 'doDragScroll'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'startDragScroll'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'stopDragScroll'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'scrollTimeout'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'cursorTimeout'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'textHintTimeout'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'resizeTimeout'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'documentTextInserted'
        QtMocHelpers::SlotData<void(KTextEditor::Document *, KTextEditor::Range)>(35, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 36, 37 }, { 0x80000000 | 38, 39 },
        }}),
        // Slot 'documentTextRemoved'
        QtMocHelpers::SlotData<void(KTextEditor::Document *, KTextEditor::Range, const QString &)>(40, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 36, 37 }, { 0x80000000 | 38, 39 }, { QMetaType::QString, 41 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KateViewInternal, qt_meta_tag_ZN16KateViewInternalE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KateViewInternal::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KateViewInternalE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KateViewInternalE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16KateViewInternalE_t>.metaTypes,
    nullptr
} };

void KateViewInternal::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KateViewInternal *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->dropEventPass((*reinterpret_cast<std::add_pointer_t<QDropEvent*>>(_a[1]))); break;
        case 1: _t->updateView((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 2: _t->updateView((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->updateView(); break;
        case 4: _t->slotIncFontSizes((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 5: _t->slotIncFontSizes(); break;
        case 6: _t->slotDecFontSizes((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 7: _t->slotDecFontSizes(); break;
        case 8: _t->slotResetFontSizes(); break;
        case 9: _t->paintCursor(); break;
        case 10: _t->scrollLines((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->scrollViewLines((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 12: _t->scrollAction((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 13: _t->scrollNextPage(); break;
        case 14: _t->scrollPrevPage(); break;
        case 15: _t->scrollPrevLine(); break;
        case 16: _t->scrollNextLine(); break;
        case 17: _t->scrollColumns((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 18: _t->viewSelectionChanged(); break;
        case 19: _t->tripleClickTimeout(); break;
        case 20: _t->slotRegionVisibilityChanged(); break;
        case 21: _t->slotRegionBeginEndAddedRemoved((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 22: _t->doDragScroll(); break;
        case 23: _t->startDragScroll(); break;
        case 24: _t->stopDragScroll(); break;
        case 25: _t->scrollTimeout(); break;
        case 26: _t->cursorTimeout(); break;
        case 27: _t->textHintTimeout(); break;
        case 28: _t->resizeTimeout(); break;
        case 29: _t->documentTextInserted((*reinterpret_cast<std::add_pointer_t<KTextEditor::Document*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KTextEditor::Range>>(_a[2]))); break;
        case 30: _t->documentTextRemoved((*reinterpret_cast<std::add_pointer_t<KTextEditor::Document*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KTextEditor::Range>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KateViewInternal::*)(QDropEvent * )>(_a, &KateViewInternal::dropEventPass, 0))
            return;
    }
}

const QMetaObject *KateViewInternal::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateViewInternal::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KateViewInternalE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int KateViewInternal::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 31)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 31;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 31)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 31;
    }
    return _id;
}

// SIGNAL 0
void KateViewInternal::dropEventPass(QDropEvent * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
