/****************************************************************************
** Meta object code from reading C++ file 'scripttester_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../ktexteditor-6.25.0/src/scripttester/scripttester_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'scripttester_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11KTextEditor12ScriptTesterE_t {};
} // unnamed namespace

template <> constexpr inline auto KTextEditor::ScriptTester::qt_create_metaobjectdata<qt_meta_tag_ZN11KTextEditor12ScriptTesterE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KTextEditor::ScriptTester",
        "read",
        "",
        "file",
        "require",
        "debug",
        "msg",
        "type",
        "str",
        "enter",
        "paste",
        "testIndentFiles",
        "name",
        "dataDir",
        "nthStack",
        "exitOnError",
        "loadModule",
        "QJSValue",
        "fileName",
        "loadScript",
        "print",
        "startTestCase",
        "setConfig",
        "config",
        "resetConfig",
        "pushConfig",
        "popConfig",
        "evaluate",
        "program",
        "setInput",
        "input",
        "blockSelection",
        "moveExpectedOutputToInput",
        "reuseInput",
        "reuseInputWithBlockSelection",
        "setExpectedOutput",
        "expected",
        "reuseExpectedOutput",
        "copyInputToExpectedOutput",
        "checkOutput",
        "incrementCounter",
        "isSuccessNotAFailure",
        "xcheck",
        "incrementError",
        "incrementBreakOnError",
        "countError",
        "hasTooManyErrors",
        "startTest",
        "endTest",
        "ok",
        "showBlockSelection",
        "writeTestExpression",
        "writeDualModeAborted",
        "writeTestResult",
        "exception",
        "result",
        "expectedResult",
        "options"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'read'
        QtMocHelpers::MethodData<QString(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 3 },
        }}),
        // Method 'require'
        QtMocHelpers::MethodData<void(const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Method 'debug'
        QtMocHelpers::MethodData<void(const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Method 'type'
        QtMocHelpers::MethodData<void(const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Method 'enter'
        QtMocHelpers::MethodData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'paste'
        QtMocHelpers::MethodData<void(const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Method 'testIndentFiles'
        QtMocHelpers::MethodData<bool(const QString &, const QString &, int, bool)>(11, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 12 }, { QMetaType::QString, 13 }, { QMetaType::Int, 14 }, { QMetaType::Bool, 15 },
        }}),
        // Method 'loadModule'
        QtMocHelpers::MethodData<QJSValue(const QString &)>(16, 2, QMC::AccessPublic, 0x80000000 | 17, {{
            { QMetaType::QString, 18 },
        }}),
        // Method 'loadScript'
        QtMocHelpers::MethodData<void(const QString &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 18 },
        }}),
        // Method 'print'
        QtMocHelpers::MethodData<void(const QString &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Method 'startTestCase'
        QtMocHelpers::MethodData<bool(const QString &, int)>(21, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 12 }, { QMetaType::Int, 14 },
        }}),
        // Method 'setConfig'
        QtMocHelpers::MethodData<void(const QJSValue &)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 23 },
        }}),
        // Method 'resetConfig'
        QtMocHelpers::MethodData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'pushConfig'
        QtMocHelpers::MethodData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'popConfig'
        QtMocHelpers::MethodData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'evaluate'
        QtMocHelpers::MethodData<QJSValue(const QString &)>(27, 2, QMC::AccessPublic, 0x80000000 | 17, {{
            { QMetaType::QString, 28 },
        }}),
        // Method 'setInput'
        QtMocHelpers::MethodData<void(const QString &, bool)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 30 }, { QMetaType::Bool, 31 },
        }}),
        // Method 'moveExpectedOutputToInput'
        QtMocHelpers::MethodData<void(bool)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 31 },
        }}),
        // Method 'reuseInput'
        QtMocHelpers::MethodData<void(bool)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 31 },
        }}),
        // Method 'reuseInputWithBlockSelection'
        QtMocHelpers::MethodData<bool()>(34, 2, QMC::AccessPublic, QMetaType::Bool),
        // Method 'setExpectedOutput'
        QtMocHelpers::MethodData<void(const QString &, bool)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 36 }, { QMetaType::Bool, 31 },
        }}),
        // Method 'reuseExpectedOutput'
        QtMocHelpers::MethodData<void(bool)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 31 },
        }}),
        // Method 'copyInputToExpectedOutput'
        QtMocHelpers::MethodData<void(bool)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 31 },
        }}),
        // Method 'checkOutput'
        QtMocHelpers::MethodData<bool()>(39, 2, QMC::AccessPublic, QMetaType::Bool),
        // Method 'incrementCounter'
        QtMocHelpers::MethodData<bool(bool, bool)>(40, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Bool, 41 }, { QMetaType::Bool, 42 },
        }}),
        // Method 'incrementError'
        QtMocHelpers::MethodData<void()>(43, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'incrementBreakOnError'
        QtMocHelpers::MethodData<void()>(44, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'countError'
        QtMocHelpers::MethodData<int() const>(45, 2, QMC::AccessPublic, QMetaType::Int),
        // Method 'hasTooManyErrors'
        QtMocHelpers::MethodData<bool() const>(46, 2, QMC::AccessPublic, QMetaType::Bool),
        // Method 'startTest'
        QtMocHelpers::MethodData<int()>(47, 2, QMC::AccessPublic, QMetaType::Int),
        // Method 'endTest'
        QtMocHelpers::MethodData<void(bool, bool)>(48, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 49 }, { QMetaType::Bool, 50 },
        }}),
        // Method 'endTest'
        QtMocHelpers::MethodData<void(bool)>(48, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Bool, 49 },
        }}),
        // Method 'writeTestExpression'
        QtMocHelpers::MethodData<void(const QString &, const QString &, int, const QString &)>(51, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 }, { QMetaType::QString, 7 }, { QMetaType::Int, 14 }, { QMetaType::QString, 28 },
        }}),
        // Method 'writeDualModeAborted'
        QtMocHelpers::MethodData<void(const QString &, int)>(52, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 }, { QMetaType::Int, 14 },
        }}),
        // Method 'writeTestResult'
        QtMocHelpers::MethodData<void(const QString &, const QString &, int, const QString &, const QString &, const QJSValue &, const QString &, const QString &, int)>(53, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 }, { QMetaType::QString, 7 }, { QMetaType::Int, 14 }, { QMetaType::QString, 28 },
            { QMetaType::QString, 6 }, { 0x80000000 | 17, 54 }, { QMetaType::QString, 55 }, { QMetaType::QString, 56 },
            { QMetaType::Int, 57 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ScriptTester, qt_meta_tag_ZN11KTextEditor12ScriptTesterE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KTextEditor::ScriptTester::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11KTextEditor12ScriptTesterE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11KTextEditor12ScriptTesterE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11KTextEditor12ScriptTesterE_t>.metaTypes,
    nullptr
} };

void KTextEditor::ScriptTester::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ScriptTester *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QString _r = _t->read((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 1: _t->require((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->debug((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->type((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->enter(); break;
        case 5: _t->paste((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: { bool _r = _t->testIndentFiles((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 7: { QJSValue _r = _t->loadModule((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->loadScript((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->print((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: { bool _r = _t->startTestCase((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 11: _t->setConfig((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1]))); break;
        case 12: _t->resetConfig(); break;
        case 13: _t->pushConfig(); break;
        case 14: _t->popConfig(); break;
        case 15: { QJSValue _r = _t->evaluate((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 16: _t->setInput((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 17: _t->moveExpectedOutputToInput((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 18: _t->reuseInput((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 19: { bool _r = _t->reuseInputWithBlockSelection();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 20: _t->setExpectedOutput((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 21: _t->reuseExpectedOutput((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 22: _t->copyInputToExpectedOutput((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 23: { bool _r = _t->checkOutput();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 24: { bool _r = _t->incrementCounter((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 25: _t->incrementError(); break;
        case 26: _t->incrementBreakOnError(); break;
        case 27: { int _r = _t->countError();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 28: { bool _r = _t->hasTooManyErrors();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 29: { int _r = _t->startTest();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 30: _t->endTest((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 31: _t->endTest((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 32: _t->writeTestExpression((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 33: _t->writeDualModeAborted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 34: _t->writeTestResult((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[9]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 34:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 5:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        }
    }
}

const QMetaObject *KTextEditor::ScriptTester::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KTextEditor::ScriptTester::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11KTextEditor12ScriptTesterE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KTextEditor::ScriptTester::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 35)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 35;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 35)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 35;
    }
    return _id;
}
QT_WARNING_POP
