/********************************************************************************
** Form generated from reading UI file 'editconfigwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_EDITCONFIGWIDGET_H
#define UI_EDITCONFIGWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_EditConfigWidget
{
public:
    QVBoxLayout *verticalLayout_2;
    QFormLayout *formLayout;
    QLabel *label;
    QCheckBox *chkStaticWordWrap;
    QCheckBox *chkShowStaticWordWrapMarker;
    QLabel *lblWordWrap;
    QSpinBox *sbWordWrap;
    QSpacerItem *verticalSpacer;
    QLabel *lblInputMode;
    QComboBox *cmbInputMode;
    QSpacerItem *verticalSpacer_2;
    QLabel *label_2;
    QCheckBox *chkAutoBrackets;
    QLabel *lbEncloseSelection;
    QComboBox *cmbEncloseSelection;
    QLabel *label_4;
    QCheckBox *chkTextDragAndDrop;
    QCheckBox *chkSmartCopyCut;
    QCheckBox *chkMousePasteAtCursorPosition;
    QLabel *lblClipboardHistoryEntries;
    QSpinBox *sbClipboardHistoryEntries;
    QLabel *lblBracketHelp;
    QSpacerItem *verticalSpacer_3;
    QCheckBox *chkAccessibility;
    QLabel *label_3;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *EditConfigWidget)
    {
        if (EditConfigWidget->objectName().isEmpty())
            EditConfigWidget->setObjectName("EditConfigWidget");
        EditConfigWidget->resize(723, 710);
        verticalLayout_2 = new QVBoxLayout(EditConfigWidget);
        verticalLayout_2->setObjectName("verticalLayout_2");
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        formLayout->setContentsMargins(-1, 10, -1, -1);
        label = new QLabel(EditConfigWidget);
        label->setObjectName("label");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        chkStaticWordWrap = new QCheckBox(EditConfigWidget);
        chkStaticWordWrap->setObjectName("chkStaticWordWrap");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, chkStaticWordWrap);

        chkShowStaticWordWrapMarker = new QCheckBox(EditConfigWidget);
        chkShowStaticWordWrapMarker->setObjectName("chkShowStaticWordWrapMarker");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, chkShowStaticWordWrapMarker);

        lblWordWrap = new QLabel(EditConfigWidget);
        lblWordWrap->setObjectName("lblWordWrap");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, lblWordWrap);

        sbWordWrap = new QSpinBox(EditConfigWidget);
        sbWordWrap->setObjectName("sbWordWrap");
        sbWordWrap->setMinimum(20);
        sbWordWrap->setMaximum(200);
        sbWordWrap->setValue(76);

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, sbWordWrap);

        verticalSpacer = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        formLayout->setItem(3, QFormLayout::ItemRole::FieldRole, verticalSpacer);

        lblInputMode = new QLabel(EditConfigWidget);
        lblInputMode->setObjectName("lblInputMode");

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, lblInputMode);

        cmbInputMode = new QComboBox(EditConfigWidget);
        cmbInputMode->setObjectName("cmbInputMode");

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, cmbInputMode);

        verticalSpacer_2 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        formLayout->setItem(5, QFormLayout::ItemRole::FieldRole, verticalSpacer_2);

        label_2 = new QLabel(EditConfigWidget);
        label_2->setObjectName("label_2");

        formLayout->setWidget(6, QFormLayout::ItemRole::LabelRole, label_2);

        chkAutoBrackets = new QCheckBox(EditConfigWidget);
        chkAutoBrackets->setObjectName("chkAutoBrackets");

        formLayout->setWidget(6, QFormLayout::ItemRole::FieldRole, chkAutoBrackets);

        lbEncloseSelection = new QLabel(EditConfigWidget);
        lbEncloseSelection->setObjectName("lbEncloseSelection");
        lbEncloseSelection->setCursor(QCursor(Qt::CursorShape::WhatsThisCursor));

        formLayout->setWidget(7, QFormLayout::ItemRole::LabelRole, lbEncloseSelection);

        cmbEncloseSelection = new QComboBox(EditConfigWidget);
        cmbEncloseSelection->setObjectName("cmbEncloseSelection");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(cmbEncloseSelection->sizePolicy().hasHeightForWidth());
        cmbEncloseSelection->setSizePolicy(sizePolicy);
        cmbEncloseSelection->setEditable(true);

        formLayout->setWidget(7, QFormLayout::ItemRole::FieldRole, cmbEncloseSelection);

        label_4 = new QLabel(EditConfigWidget);
        label_4->setObjectName("label_4");

        formLayout->setWidget(10, QFormLayout::ItemRole::LabelRole, label_4);

        chkTextDragAndDrop = new QCheckBox(EditConfigWidget);
        chkTextDragAndDrop->setObjectName("chkTextDragAndDrop");

        formLayout->setWidget(10, QFormLayout::ItemRole::FieldRole, chkTextDragAndDrop);

        chkSmartCopyCut = new QCheckBox(EditConfigWidget);
        chkSmartCopyCut->setObjectName("chkSmartCopyCut");

        formLayout->setWidget(11, QFormLayout::ItemRole::FieldRole, chkSmartCopyCut);

        chkMousePasteAtCursorPosition = new QCheckBox(EditConfigWidget);
        chkMousePasteAtCursorPosition->setObjectName("chkMousePasteAtCursorPosition");

        formLayout->setWidget(12, QFormLayout::ItemRole::FieldRole, chkMousePasteAtCursorPosition);

        lblClipboardHistoryEntries = new QLabel(EditConfigWidget);
        lblClipboardHistoryEntries->setObjectName("lblClipboardHistoryEntries");

        formLayout->setWidget(13, QFormLayout::ItemRole::LabelRole, lblClipboardHistoryEntries);

        sbClipboardHistoryEntries = new QSpinBox(EditConfigWidget);
        sbClipboardHistoryEntries->setObjectName("sbClipboardHistoryEntries");
        sbClipboardHistoryEntries->setMinimum(1);
        sbClipboardHistoryEntries->setMaximum(999);
        sbClipboardHistoryEntries->setValue(20);

        formLayout->setWidget(13, QFormLayout::ItemRole::FieldRole, sbClipboardHistoryEntries);

        lblBracketHelp = new QLabel(EditConfigWidget);
        lblBracketHelp->setObjectName("lblBracketHelp");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(lblBracketHelp->sizePolicy().hasHeightForWidth());
        lblBracketHelp->setSizePolicy(sizePolicy1);
        lblBracketHelp->setWordWrap(true);

        formLayout->setWidget(8, QFormLayout::ItemRole::FieldRole, lblBracketHelp);

        verticalSpacer_3 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        formLayout->setItem(9, QFormLayout::ItemRole::FieldRole, verticalSpacer_3);

        chkAccessibility = new QCheckBox(EditConfigWidget);
        chkAccessibility->setObjectName("chkAccessibility");

        formLayout->setWidget(14, QFormLayout::ItemRole::FieldRole, chkAccessibility);

        label_3 = new QLabel(EditConfigWidget);
        label_3->setObjectName("label_3");

        formLayout->setWidget(14, QFormLayout::ItemRole::LabelRole, label_3);


        verticalLayout_2->addLayout(formLayout);

        spacerItem = new QSpacerItem(8, 1, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(spacerItem);

#if QT_CONFIG(shortcut)
        lblWordWrap->setBuddy(sbWordWrap);
        lblInputMode->setBuddy(cmbInputMode);
        lbEncloseSelection->setBuddy(cmbEncloseSelection);
        lblClipboardHistoryEntries->setBuddy(sbClipboardHistoryEntries);
        label_3->setBuddy(chkAccessibility);
#endif // QT_CONFIG(shortcut)

        retranslateUi(EditConfigWidget);

        QMetaObject::connectSlotsByName(EditConfigWidget);
    } // setupUi

    void retranslateUi(QWidget *EditConfigWidget)
    {
        label->setText(tr2i18n("Word wrap:", nullptr));
#if QT_CONFIG(whatsthis)
        chkStaticWordWrap->setWhatsThis(tr2i18n("<p>Automatically start a new line of text when the current line exceeds the length specified by the <b>Wrap words at:</b> option.</p><p>This option does not wrap existing lines of text - use the <b>Apply Static Word Wrap</b> option in the <b>Tools</b> menu for that purpose.</p><p>If you want lines to be <i>visually wrapped</i> instead, according to the width of the view, enable <b>Dynamic Word Wrap</b> in the <b>Appearance</b> config page.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        chkStaticWordWrap->setText(tr2i18n("Wrap &words at a fixed column", nullptr));
#if QT_CONFIG(whatsthis)
        chkShowStaticWordWrapMarker->setWhatsThis(tr2i18n("<p>If this option is checked, a vertical line will be drawn at the word wrap column as defined in the <strong>Editing</strong> properties.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        chkShowStaticWordWrapMarker->setText(tr2i18n("&Draw vertical line at the word wrap column", nullptr));
        lblWordWrap->setText(tr2i18n("Wra&p words at:", nullptr));
#if QT_CONFIG(whatsthis)
        sbWordWrap->setWhatsThis(tr2i18n("If the Word Wrap option is selected this entry determines the length (in characters) at which the editor will automatically start a new line.", nullptr));
#endif // QT_CONFIG(whatsthis)
        lblInputMode->setText(tr2i18n("Default input mode:", nullptr));
        label_2->setText(tr2i18n("Brackets:", nullptr));
        chkAutoBrackets->setText(tr2i18n("Automatically close brackets when opening bracket is typed", nullptr));
#if QT_CONFIG(tooltip)
        lbEncloseSelection->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        lbEncloseSelection->setWhatsThis(tr2i18n("When some text is selected these chars will be added on both its sides in a way \"Auto Bracket\" do", nullptr));
#endif // QT_CONFIG(whatsthis)
        lbEncloseSelection->setText(tr2i18n("Enclosing characters:", nullptr));
        label_4->setText(tr2i18n("Copy and paste:", nullptr));
        chkTextDragAndDrop->setText(tr2i18n("Move selected text when dragged", nullptr));
        chkSmartCopyCut->setText(tr2i18n("Copy/cut the current line if invoked without any text selected", nullptr));
        chkMousePasteAtCursorPosition->setText(tr2i18n("Don't move the text cursor when pasting by mouse", nullptr));
        lblClipboardHistoryEntries->setText(tr2i18n("Max Clipboard History Entries:", nullptr));
#if QT_CONFIG(whatsthis)
        sbClipboardHistoryEntries->setWhatsThis(tr2i18n("This determines the number of entries to keep in the clipboard history", nullptr));
#endif // QT_CONFIG(whatsthis)
        lblBracketHelp->setText(tr2i18n("When you type these characters while text is selected, they will surround the selected text instead of replacing it.", nullptr));
        chkAccessibility->setText(tr2i18n("Enable accessibility notifications", nullptr));
        label_3->setText(tr2i18n("Accessibility:", nullptr));
        (void)EditConfigWidget;
    } // retranslateUi

};

namespace Ui {
    class EditConfigWidget: public Ui_EditConfigWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // EDITCONFIGWIDGET_H

