/****************************************************************************
** Meta object code from reading C++ file 'view.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../ktexteditor-6.25.0/src/include/ktexteditor/view.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'view.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11KTextEditor4ViewE_t {};
} // unnamed namespace

template <> constexpr inline auto KTextEditor::View::qt_create_metaobjectdata<qt_meta_tag_ZN11KTextEditor4ViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KTextEditor::View",
        "focusIn",
        "",
        "KTextEditor::View*",
        "view",
        "focusOut",
        "viewModeChanged",
        "KTextEditor::View::ViewMode",
        "mode",
        "viewInputModeChanged",
        "KTextEditor::View::InputMode",
        "textInserted",
        "KTextEditor::Cursor",
        "position",
        "text",
        "contextMenuAboutToShow",
        "QMenu*",
        "menu",
        "cursorPositionChanged",
        "newPosition",
        "verticalScrollPositionChanged",
        "newPos",
        "horizontalScrollPositionChanged",
        "mousePositionChanged",
        "selectionChanged",
        "displayRangeChanged",
        "statusBarEnabledChanged",
        "enabled",
        "configChanged",
        "annotationContextMenuAboutToShow",
        "line",
        "annotationActivated",
        "annotationBorderVisibilityChanged",
        "visible"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'focusIn'
        QtMocHelpers::SignalData<void(KTextEditor::View *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'focusOut'
        QtMocHelpers::SignalData<void(KTextEditor::View *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'viewModeChanged'
        QtMocHelpers::SignalData<void(KTextEditor::View *, KTextEditor::View::ViewMode)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 7, 8 },
        }}),
        // Signal 'viewInputModeChanged'
        QtMocHelpers::SignalData<void(KTextEditor::View *, KTextEditor::View::InputMode)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 10, 8 },
        }}),
        // Signal 'textInserted'
        QtMocHelpers::SignalData<void(KTextEditor::View *, KTextEditor::Cursor, const QString &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 12, 13 }, { QMetaType::QString, 14 },
        }}),
        // Signal 'contextMenuAboutToShow'
        QtMocHelpers::SignalData<void(KTextEditor::View *, QMenu *)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 16, 17 },
        }}),
        // Signal 'cursorPositionChanged'
        QtMocHelpers::SignalData<void(KTextEditor::View *, KTextEditor::Cursor)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 12, 19 },
        }}),
        // Signal 'verticalScrollPositionChanged'
        QtMocHelpers::SignalData<void(KTextEditor::View *, KTextEditor::Cursor)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 12, 21 },
        }}),
        // Signal 'horizontalScrollPositionChanged'
        QtMocHelpers::SignalData<void(KTextEditor::View *)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'mousePositionChanged'
        QtMocHelpers::SignalData<void(KTextEditor::View *, KTextEditor::Cursor)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 12, 19 },
        }}),
        // Signal 'selectionChanged'
        QtMocHelpers::SignalData<void(KTextEditor::View *)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'displayRangeChanged'
        QtMocHelpers::SignalData<void(KTextEditor::View *)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'statusBarEnabledChanged'
        QtMocHelpers::SignalData<void(KTextEditor::View *, bool)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Bool, 27 },
        }}),
        // Signal 'configChanged'
        QtMocHelpers::SignalData<void(KTextEditor::View *)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'annotationContextMenuAboutToShow'
        QtMocHelpers::SignalData<void(KTextEditor::View *, QMenu *, int)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 16, 17 }, { QMetaType::Int, 30 },
        }}),
        // Signal 'annotationActivated'
        QtMocHelpers::SignalData<void(KTextEditor::View *, int)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Int, 30 },
        }}),
        // Signal 'annotationBorderVisibilityChanged'
        QtMocHelpers::SignalData<void(KTextEditor::View *, bool)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Bool, 33 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<View, qt_meta_tag_ZN11KTextEditor4ViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KTextEditor::View::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11KTextEditor4ViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11KTextEditor4ViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11KTextEditor4ViewE_t>.metaTypes,
    nullptr
} };

void KTextEditor::View::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<View *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->focusIn((*reinterpret_cast<std::add_pointer_t<KTextEditor::View*>>(_a[1]))); break;
        case 1: _t->focusOut((*reinterpret_cast<std::add_pointer_t<KTextEditor::View*>>(_a[1]))); break;
        case 2: _t->viewModeChanged((*reinterpret_cast<std::add_pointer_t<KTextEditor::View*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KTextEditor::View::ViewMode>>(_a[2]))); break;
        case 3: _t->viewInputModeChanged((*reinterpret_cast<std::add_pointer_t<KTextEditor::View*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KTextEditor::View::InputMode>>(_a[2]))); break;
        case 4: _t->textInserted((*reinterpret_cast<std::add_pointer_t<KTextEditor::View*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KTextEditor::Cursor>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 5: _t->contextMenuAboutToShow((*reinterpret_cast<std::add_pointer_t<KTextEditor::View*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QMenu*>>(_a[2]))); break;
        case 6: _t->cursorPositionChanged((*reinterpret_cast<std::add_pointer_t<KTextEditor::View*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KTextEditor::Cursor>>(_a[2]))); break;
        case 7: _t->verticalScrollPositionChanged((*reinterpret_cast<std::add_pointer_t<KTextEditor::View*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KTextEditor::Cursor>>(_a[2]))); break;
        case 8: _t->horizontalScrollPositionChanged((*reinterpret_cast<std::add_pointer_t<KTextEditor::View*>>(_a[1]))); break;
        case 9: _t->mousePositionChanged((*reinterpret_cast<std::add_pointer_t<KTextEditor::View*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KTextEditor::Cursor>>(_a[2]))); break;
        case 10: _t->selectionChanged((*reinterpret_cast<std::add_pointer_t<KTextEditor::View*>>(_a[1]))); break;
        case 11: _t->displayRangeChanged((*reinterpret_cast<std::add_pointer_t<KTextEditor::View*>>(_a[1]))); break;
        case 12: _t->statusBarEnabledChanged((*reinterpret_cast<std::add_pointer_t<KTextEditor::View*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 13: _t->configChanged((*reinterpret_cast<std::add_pointer_t<KTextEditor::View*>>(_a[1]))); break;
        case 14: _t->annotationContextMenuAboutToShow((*reinterpret_cast<std::add_pointer_t<KTextEditor::View*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QMenu*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 15: _t->annotationActivated((*reinterpret_cast<std::add_pointer_t<KTextEditor::View*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 16: _t->annotationBorderVisibilityChanged((*reinterpret_cast<std::add_pointer_t<KTextEditor::View*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KTextEditor::View* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KTextEditor::View* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KTextEditor::View* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KTextEditor::View* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KTextEditor::View* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KTextEditor::View* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KTextEditor::View* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KTextEditor::View* >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KTextEditor::View* >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KTextEditor::View* >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KTextEditor::View* >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KTextEditor::View* >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KTextEditor::View* >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KTextEditor::View* >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KTextEditor::View* >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KTextEditor::View* >(); break;
            }
            break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KTextEditor::View* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (View::*)(KTextEditor::View * )>(_a, &View::focusIn, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (View::*)(KTextEditor::View * )>(_a, &View::focusOut, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (View::*)(KTextEditor::View * , KTextEditor::View::ViewMode )>(_a, &View::viewModeChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (View::*)(KTextEditor::View * , KTextEditor::View::InputMode )>(_a, &View::viewInputModeChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (View::*)(KTextEditor::View * , KTextEditor::Cursor , const QString & )>(_a, &View::textInserted, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (View::*)(KTextEditor::View * , QMenu * )>(_a, &View::contextMenuAboutToShow, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (View::*)(KTextEditor::View * , KTextEditor::Cursor )>(_a, &View::cursorPositionChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (View::*)(KTextEditor::View * , KTextEditor::Cursor )>(_a, &View::verticalScrollPositionChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (View::*)(KTextEditor::View * )>(_a, &View::horizontalScrollPositionChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (View::*)(KTextEditor::View * , KTextEditor::Cursor )>(_a, &View::mousePositionChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (View::*)(KTextEditor::View * )>(_a, &View::selectionChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (View::*)(KTextEditor::View * )>(_a, &View::displayRangeChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (View::*)(KTextEditor::View * , bool )>(_a, &View::statusBarEnabledChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (View::*)(KTextEditor::View * )>(_a, &View::configChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (View::*)(KTextEditor::View * , QMenu * , int )>(_a, &View::annotationContextMenuAboutToShow, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (View::*)(KTextEditor::View * , int )>(_a, &View::annotationActivated, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (View::*)(KTextEditor::View * , bool )>(_a, &View::annotationBorderVisibilityChanged, 16))
            return;
    }
}

const QMetaObject *KTextEditor::View::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KTextEditor::View::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11KTextEditor4ViewE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "KXMLGUIClient"))
        return static_cast< KXMLGUIClient*>(this);
    return QWidget::qt_metacast(_clname);
}

int KTextEditor::View::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    return _id;
}

// SIGNAL 0
void KTextEditor::View::focusIn(KTextEditor::View * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KTextEditor::View::focusOut(KTextEditor::View * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void KTextEditor::View::viewModeChanged(KTextEditor::View * _t1, KTextEditor::View::ViewMode _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void KTextEditor::View::viewInputModeChanged(KTextEditor::View * _t1, KTextEditor::View::InputMode _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void KTextEditor::View::textInserted(KTextEditor::View * _t1, KTextEditor::Cursor _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2, _t3);
}

// SIGNAL 5
void KTextEditor::View::contextMenuAboutToShow(KTextEditor::View * _t1, QMenu * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void KTextEditor::View::cursorPositionChanged(KTextEditor::View * _t1, KTextEditor::Cursor _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void KTextEditor::View::verticalScrollPositionChanged(KTextEditor::View * _t1, KTextEditor::Cursor _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2);
}

// SIGNAL 8
void KTextEditor::View::horizontalScrollPositionChanged(KTextEditor::View * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void KTextEditor::View::mousePositionChanged(KTextEditor::View * _t1, KTextEditor::Cursor _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1, _t2);
}

// SIGNAL 10
void KTextEditor::View::selectionChanged(KTextEditor::View * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void KTextEditor::View::displayRangeChanged(KTextEditor::View * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void KTextEditor::View::statusBarEnabledChanged(KTextEditor::View * _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1, _t2);
}

// SIGNAL 13
void KTextEditor::View::configChanged(KTextEditor::View * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void KTextEditor::View::annotationContextMenuAboutToShow(KTextEditor::View * _t1, QMenu * _t2, int _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1, _t2, _t3);
}

// SIGNAL 15
void KTextEditor::View::annotationActivated(KTextEditor::View * _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1, _t2);
}

// SIGNAL 16
void KTextEditor::View::annotationBorderVisibilityChanged(KTextEditor::View * _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1, _t2);
}
QT_WARNING_POP
