/****************************************************************************
** Meta object code from reading C++ file 'katedocument.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../ktexteditor-6.25.0/src/document/katedocument.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'katedocument.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11KTextEditor15DocumentPrivateE_t {};
} // unnamed namespace

template <> constexpr inline auto KTextEditor::DocumentPrivate::qt_create_metaobjectdata<qt_meta_tag_ZN11KTextEditor15DocumentPrivateE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KTextEditor::DocumentPrivate",
        "charactersSemiInteractivelyInserted",
        "",
        "KTextEditor::Cursor",
        "position",
        "text",
        "textInsertedRange",
        "KTextEditor::Document*",
        "document",
        "KTextEditor::Range",
        "range",
        "textRemoved",
        "oldText",
        "editLineWrapped",
        "line",
        "col",
        "len",
        "editLineUnWrapped",
        "annotationModelChanged",
        "KTextEditor::AnnotationModel*",
        "aboutToRemoveText",
        "dictionaryRangesPresent",
        "yesNo",
        "defaultDictionaryChanged",
        "KTextEditor::DocumentPrivate*",
        "loaded",
        "setText",
        "clear",
        "insertText",
        "s",
        "block",
        "insertLine",
        "insertLines",
        "removeText",
        "removeLine",
        "replaceText",
        "r",
        "l",
        "b",
        "undo",
        "redo",
        "clearEditingPosStack",
        "saveEditingPositions",
        "cursor",
        "setMark",
        "markType",
        "clearMark",
        "addMark",
        "removeMark",
        "clearMarks",
        "requestMarkTooltip",
        "QPoint",
        "handleMarkClick",
        "handleMarkContextMenu",
        "setMarkDescription",
        "Document::MarkTypes",
        "setEditableMarks",
        "markMask",
        "setMarkIcon",
        "QIcon",
        "icon",
        "print",
        "printPreview",
        "autoReloadToggled",
        "tagLines",
        "KTextEditor::LineRange",
        "lineRange",
        "tagLine",
        "internalHlChanged",
        "slotModifiedOnDisk",
        "KTextEditor::View*",
        "v",
        "documentReload",
        "documentSave",
        "documentSaveAs",
        "documentSaveAsWithEncoding",
        "encoding",
        "documentSaveCopyAs",
        "save",
        "onModOnHdSaveAs",
        "onModOnHdClose",
        "onModOnHdReload",
        "onModOnHdAutoReload",
        "onModOnHdIgnore",
        "setWordWrap",
        "on",
        "setWordWrapAt",
        "setPageUpDownMovesCursor",
        "slotModOnHdDirty",
        "path",
        "slotModOnHdCreated",
        "slotModOnHdDeleted",
        "slotDelayedHandleModOnHd",
        "slotQueryClose_save",
        "bool*",
        "handled",
        "abortClosing",
        "messageDestroyed",
        "KTextEditor::Message*",
        "message",
        "clearDictionaryRanges",
        "setDictionary",
        "dict",
        "blockmode",
        "setDefaultDictionary",
        "onTheFlySpellCheckingEnabled",
        "enable",
        "refreshOnTheFlyCheck",
        "slotStarted",
        "KIO::Job*",
        "job",
        "slotCompleted",
        "slotCanceled",
        "slotTriggerLoadingMessage",
        "slotAbortLoading",
        "slotUrlChanged",
        "QUrl",
        "url",
        "openWithLineLengthLimitOverride",
        "checkCursorForAutobrace",
        "view",
        "newPos"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'charactersSemiInteractivelyInserted'
        QtMocHelpers::SignalData<void(KTextEditor::Cursor, const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 5 },
        }}),
        // Signal 'textInsertedRange'
        QtMocHelpers::SignalData<void(KTextEditor::Document *, KTextEditor::Range)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { 0x80000000 | 9, 10 },
        }}),
        // Signal 'textRemoved'
        QtMocHelpers::SignalData<void(KTextEditor::Document *, KTextEditor::Range, const QString &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { 0x80000000 | 9, 10 }, { QMetaType::QString, 12 },
        }}),
        // Signal 'editLineWrapped'
        QtMocHelpers::SignalData<void(int, int, int)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 14 }, { QMetaType::Int, 15 }, { QMetaType::Int, 16 },
        }}),
        // Signal 'editLineUnWrapped'
        QtMocHelpers::SignalData<void(int, int)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 14 }, { QMetaType::Int, 15 },
        }}),
        // Signal 'annotationModelChanged'
        QtMocHelpers::SignalData<void(KTextEditor::AnnotationModel *, KTextEditor::AnnotationModel *)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 2 }, { 0x80000000 | 19, 2 },
        }}),
        // Signal 'aboutToRemoveText'
        QtMocHelpers::SignalData<void(KTextEditor::Range)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 2 },
        }}),
        // Signal 'dictionaryRangesPresent'
        QtMocHelpers::SignalData<void(bool)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 22 },
        }}),
        // Signal 'defaultDictionaryChanged'
        QtMocHelpers::SignalData<void(KTextEditor::DocumentPrivate *)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 24, 8 },
        }}),
        // Signal 'loaded'
        QtMocHelpers::SignalData<void(KTextEditor::DocumentPrivate *)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 24, 8 },
        }}),
        // Slot 'setText'
        QtMocHelpers::SlotData<bool(const QString &)>(26, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'setText'
        QtMocHelpers::SlotData<bool(const QStringList &)>(26, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QStringList, 5 },
        }}),
        // Slot 'clear'
        QtMocHelpers::SlotData<bool()>(27, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'insertText'
        QtMocHelpers::SlotData<bool(KTextEditor::Cursor, const QString &, bool)>(28, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 29 }, { QMetaType::Bool, 30 },
        }}),
        // Slot 'insertText'
        QtMocHelpers::SlotData<bool(KTextEditor::Cursor, const QString &)>(28, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 29 },
        }}),
        // Slot 'insertText'
        QtMocHelpers::SlotData<bool(KTextEditor::Cursor, const QStringList &, bool)>(28, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QStringList, 5 }, { QMetaType::Bool, 30 },
        }}),
        // Slot 'insertText'
        QtMocHelpers::SlotData<bool(KTextEditor::Cursor, const QStringList &)>(28, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QStringList, 5 },
        }}),
        // Slot 'insertLine'
        QtMocHelpers::SlotData<bool(int, const QString &)>(31, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 14 }, { QMetaType::QString, 29 },
        }}),
        // Slot 'insertLines'
        QtMocHelpers::SlotData<bool(int, const QStringList &)>(32, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 14 }, { QMetaType::QStringList, 29 },
        }}),
        // Slot 'removeText'
        QtMocHelpers::SlotData<bool(KTextEditor::Range, bool)>(33, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 9, 10 }, { QMetaType::Bool, 30 },
        }}),
        // Slot 'removeText'
        QtMocHelpers::SlotData<bool(KTextEditor::Range)>(33, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'removeLine'
        QtMocHelpers::SlotData<bool(int)>(34, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 14 },
        }}),
        // Slot 'replaceText'
        QtMocHelpers::SlotData<bool(KTextEditor::Range, const QString &, bool)>(35, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 9, 10 }, { QMetaType::QString, 29 }, { QMetaType::Bool, 30 },
        }}),
        // Slot 'replaceText'
        QtMocHelpers::SlotData<bool(KTextEditor::Range, const QString &)>(35, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { 0x80000000 | 9, 10 }, { QMetaType::QString, 29 },
        }}),
        // Slot 'replaceText'
        QtMocHelpers::SlotData<bool(KTextEditor::Range, const QStringList &, bool)>(35, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 9, 36 }, { QMetaType::QStringList, 37 }, { QMetaType::Bool, 38 },
        }}),
        // Slot 'undo'
        QtMocHelpers::SlotData<void()>(39, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'redo'
        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'clearEditingPosStack'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'saveEditingPositions'
        QtMocHelpers::SlotData<void(const KTextEditor::Cursor)>(42, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 43 },
        }}),
        // Slot 'setMark'
        QtMocHelpers::SlotData<void(int, uint)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 14 }, { QMetaType::UInt, 45 },
        }}),
        // Slot 'clearMark'
        QtMocHelpers::SlotData<void(int)>(46, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 14 },
        }}),
        // Slot 'addMark'
        QtMocHelpers::SlotData<void(int, uint)>(47, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 14 }, { QMetaType::UInt, 45 },
        }}),
        // Slot 'removeMark'
        QtMocHelpers::SlotData<void(int, uint)>(48, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 14 }, { QMetaType::UInt, 45 },
        }}),
        // Slot 'clearMarks'
        QtMocHelpers::SlotData<void()>(49, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'requestMarkTooltip'
        QtMocHelpers::SlotData<void(int, QPoint)>(50, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 14 }, { 0x80000000 | 51, 4 },
        }}),
        // Slot 'handleMarkClick'
        QtMocHelpers::SlotData<bool(int)>(52, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 14 },
        }}),
        // Slot 'handleMarkContextMenu'
        QtMocHelpers::SlotData<bool(int, QPoint)>(53, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 14 }, { 0x80000000 | 51, 4 },
        }}),
        // Slot 'setMarkDescription'
        QtMocHelpers::SlotData<void(Document::MarkTypes, const QString &)>(54, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 55, 2 }, { QMetaType::QString, 2 },
        }}),
        // Slot 'setEditableMarks'
        QtMocHelpers::SlotData<void(uint)>(56, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 57 },
        }}),
        // Slot 'setMarkIcon'
        QtMocHelpers::SlotData<void(Document::MarkTypes, const QIcon &)>(58, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 55, 45 }, { 0x80000000 | 59, 60 },
        }}),
        // Slot 'print'
        QtMocHelpers::SlotData<bool()>(61, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'printPreview'
        QtMocHelpers::SlotData<void()>(62, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'autoReloadToggled'
        QtMocHelpers::SlotData<void(bool)>(63, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 38 },
        }}),
        // Slot 'tagLines'
        QtMocHelpers::SlotData<void(KTextEditor::LineRange)>(64, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 65, 66 },
        }}),
        // Slot 'tagLine'
        QtMocHelpers::SlotData<void(int)>(67, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 14 },
        }}),
        // Slot 'internalHlChanged'
        QtMocHelpers::SlotData<void()>(68, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotModifiedOnDisk'
        QtMocHelpers::SlotData<void(KTextEditor::View *)>(69, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 70, 71 },
        }}),
        // Slot 'slotModifiedOnDisk'
        QtMocHelpers::SlotData<void()>(69, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'documentReload'
        QtMocHelpers::SlotData<bool()>(72, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'documentSave'
        QtMocHelpers::SlotData<bool()>(73, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'documentSaveAs'
        QtMocHelpers::SlotData<bool()>(74, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'documentSaveAsWithEncoding'
        QtMocHelpers::SlotData<bool(const QString &)>(75, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 76 },
        }}),
        // Slot 'documentSaveCopyAs'
        QtMocHelpers::SlotData<void()>(77, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'save'
        QtMocHelpers::SlotData<bool()>(78, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'onModOnHdSaveAs'
        QtMocHelpers::SlotData<void()>(79, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onModOnHdClose'
        QtMocHelpers::SlotData<void()>(80, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onModOnHdReload'
        QtMocHelpers::SlotData<void()>(81, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onModOnHdAutoReload'
        QtMocHelpers::SlotData<void()>(82, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onModOnHdIgnore'
        QtMocHelpers::SlotData<void()>(83, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setWordWrap'
        QtMocHelpers::SlotData<void(bool)>(84, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 85 },
        }}),
        // Slot 'setWordWrapAt'
        QtMocHelpers::SlotData<void(uint)>(86, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 15 },
        }}),
        // Slot 'setPageUpDownMovesCursor'
        QtMocHelpers::SlotData<void(bool)>(87, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 85 },
        }}),
        // Slot 'slotModOnHdDirty'
        QtMocHelpers::SlotData<void(const QString &)>(88, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 89 },
        }}),
        // Slot 'slotModOnHdCreated'
        QtMocHelpers::SlotData<void(const QString &)>(90, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 89 },
        }}),
        // Slot 'slotModOnHdDeleted'
        QtMocHelpers::SlotData<void(const QString &)>(91, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 89 },
        }}),
        // Slot 'slotDelayedHandleModOnHd'
        QtMocHelpers::SlotData<void()>(92, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotQueryClose_save'
        QtMocHelpers::SlotData<void(bool *, bool *)>(93, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 94, 95 }, { 0x80000000 | 94, 96 },
        }}),
        // Slot 'messageDestroyed'
        QtMocHelpers::SlotData<void(KTextEditor::Message *)>(97, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 98, 99 },
        }}),
        // Slot 'clearDictionaryRanges'
        QtMocHelpers::SlotData<void()>(100, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setDictionary'
        QtMocHelpers::SlotData<void(const QString &, KTextEditor::Range, bool)>(101, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 102 }, { 0x80000000 | 9, 10 }, { QMetaType::Bool, 103 },
        }}),
        // Slot 'setDictionary'
        QtMocHelpers::SlotData<void(const QString &, KTextEditor::Range)>(101, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 102 }, { 0x80000000 | 9, 10 },
        }}),
        // Slot 'setDefaultDictionary'
        QtMocHelpers::SlotData<void(const QString &)>(104, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 102 },
        }}),
        // Slot 'onTheFlySpellCheckingEnabled'
        QtMocHelpers::SlotData<void(bool)>(105, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 106 },
        }}),
        // Slot 'refreshOnTheFlyCheck'
        QtMocHelpers::SlotData<void(KTextEditor::Range)>(107, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'refreshOnTheFlyCheck'
        QtMocHelpers::SlotData<void()>(107, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'slotStarted'
        QtMocHelpers::SlotData<void(KIO::Job *)>(108, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 109, 110 },
        }}),
        // Slot 'slotCompleted'
        QtMocHelpers::SlotData<void()>(111, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCanceled'
        QtMocHelpers::SlotData<void()>(112, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotTriggerLoadingMessage'
        QtMocHelpers::SlotData<void()>(113, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAbortLoading'
        QtMocHelpers::SlotData<void()>(114, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotUrlChanged'
        QtMocHelpers::SlotData<void(const QUrl &)>(115, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 116, 117 },
        }}),
        // Slot 'openWithLineLengthLimitOverride'
        QtMocHelpers::SlotData<void()>(118, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'checkCursorForAutobrace'
        QtMocHelpers::SlotData<void(KTextEditor::View *, const KTextEditor::Cursor)>(119, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 70, 120 }, { 0x80000000 | 3, 121 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DocumentPrivate, qt_meta_tag_ZN11KTextEditor15DocumentPrivateE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KTextEditor::DocumentPrivate::staticMetaObject = { {
    QMetaObject::SuperData::link<KTextEditor::Document::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11KTextEditor15DocumentPrivateE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11KTextEditor15DocumentPrivateE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11KTextEditor15DocumentPrivateE_t>.metaTypes,
    nullptr
} };

void KTextEditor::DocumentPrivate::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DocumentPrivate *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->charactersSemiInteractivelyInserted((*reinterpret_cast<std::add_pointer_t<KTextEditor::Cursor>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 1: _t->textInsertedRange((*reinterpret_cast<std::add_pointer_t<KTextEditor::Document*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KTextEditor::Range>>(_a[2]))); break;
        case 2: _t->textRemoved((*reinterpret_cast<std::add_pointer_t<KTextEditor::Document*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KTextEditor::Range>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 3: _t->editLineWrapped((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 4: _t->editLineUnWrapped((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 5: _t->annotationModelChanged((*reinterpret_cast<std::add_pointer_t<KTextEditor::AnnotationModel*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KTextEditor::AnnotationModel*>>(_a[2]))); break;
        case 6: _t->aboutToRemoveText((*reinterpret_cast<std::add_pointer_t<KTextEditor::Range>>(_a[1]))); break;
        case 7: _t->dictionaryRangesPresent((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->defaultDictionaryChanged((*reinterpret_cast<std::add_pointer_t<KTextEditor::DocumentPrivate*>>(_a[1]))); break;
        case 9: _t->loaded((*reinterpret_cast<std::add_pointer_t<KTextEditor::DocumentPrivate*>>(_a[1]))); break;
        case 10: { bool _r = _t->setText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 11: { bool _r = _t->setText((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 12: { bool _r = _t->clear();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 13: { bool _r = _t->insertText((*reinterpret_cast<std::add_pointer_t<KTextEditor::Cursor>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 14: { bool _r = _t->insertText((*reinterpret_cast<std::add_pointer_t<KTextEditor::Cursor>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 15: { bool _r = _t->insertText((*reinterpret_cast<std::add_pointer_t<KTextEditor::Cursor>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 16: { bool _r = _t->insertText((*reinterpret_cast<std::add_pointer_t<KTextEditor::Cursor>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 17: { bool _r = _t->insertLine((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 18: { bool _r = _t->insertLines((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 19: { bool _r = _t->removeText((*reinterpret_cast<std::add_pointer_t<KTextEditor::Range>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 20: { bool _r = _t->removeText((*reinterpret_cast<std::add_pointer_t<KTextEditor::Range>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 21: { bool _r = _t->removeLine((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 22: { bool _r = _t->replaceText((*reinterpret_cast<std::add_pointer_t<KTextEditor::Range>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 23: { bool _r = _t->replaceText((*reinterpret_cast<std::add_pointer_t<KTextEditor::Range>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 24: { bool _r = _t->replaceText((*reinterpret_cast<std::add_pointer_t<KTextEditor::Range>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 25: _t->undo(); break;
        case 26: _t->redo(); break;
        case 27: _t->clearEditingPosStack(); break;
        case 28: _t->saveEditingPositions((*reinterpret_cast<std::add_pointer_t<KTextEditor::Cursor>>(_a[1]))); break;
        case 29: _t->setMark((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2]))); break;
        case 30: _t->clearMark((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 31: _t->addMark((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2]))); break;
        case 32: _t->removeMark((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2]))); break;
        case 33: _t->clearMarks(); break;
        case 34: _t->requestMarkTooltip((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2]))); break;
        case 35: { bool _r = _t->handleMarkClick((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 36: { bool _r = _t->handleMarkContextMenu((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 37: _t->setMarkDescription((*reinterpret_cast<std::add_pointer_t<Document::MarkTypes>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 38: _t->setEditableMarks((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 39: _t->setMarkIcon((*reinterpret_cast<std::add_pointer_t<Document::MarkTypes>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QIcon>>(_a[2]))); break;
        case 40: { bool _r = _t->print();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 41: _t->printPreview(); break;
        case 42: _t->autoReloadToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 43: _t->tagLines((*reinterpret_cast<std::add_pointer_t<KTextEditor::LineRange>>(_a[1]))); break;
        case 44: _t->tagLine((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 45: _t->internalHlChanged(); break;
        case 46: _t->slotModifiedOnDisk((*reinterpret_cast<std::add_pointer_t<KTextEditor::View*>>(_a[1]))); break;
        case 47: _t->slotModifiedOnDisk(); break;
        case 48: { bool _r = _t->documentReload();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 49: { bool _r = _t->documentSave();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 50: { bool _r = _t->documentSaveAs();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 51: { bool _r = _t->documentSaveAsWithEncoding((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 52: _t->documentSaveCopyAs(); break;
        case 53: { bool _r = _t->save();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 54: _t->onModOnHdSaveAs(); break;
        case 55: _t->onModOnHdClose(); break;
        case 56: _t->onModOnHdReload(); break;
        case 57: _t->onModOnHdAutoReload(); break;
        case 58: _t->onModOnHdIgnore(); break;
        case 59: _t->setWordWrap((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 60: _t->setWordWrapAt((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 61: _t->setPageUpDownMovesCursor((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 62: _t->slotModOnHdDirty((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 63: _t->slotModOnHdCreated((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 64: _t->slotModOnHdDeleted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 65: _t->slotDelayedHandleModOnHd(); break;
        case 66: _t->slotQueryClose_save((*reinterpret_cast<std::add_pointer_t<bool*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool*>>(_a[2]))); break;
        case 67: _t->messageDestroyed((*reinterpret_cast<std::add_pointer_t<KTextEditor::Message*>>(_a[1]))); break;
        case 68: _t->clearDictionaryRanges(); break;
        case 69: _t->setDictionary((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KTextEditor::Range>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 70: _t->setDictionary((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KTextEditor::Range>>(_a[2]))); break;
        case 71: _t->setDefaultDictionary((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 72: _t->onTheFlySpellCheckingEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 73: _t->refreshOnTheFlyCheck((*reinterpret_cast<std::add_pointer_t<KTextEditor::Range>>(_a[1]))); break;
        case 74: _t->refreshOnTheFlyCheck(); break;
        case 75: _t->slotStarted((*reinterpret_cast<std::add_pointer_t<KIO::Job*>>(_a[1]))); break;
        case 76: _t->slotCompleted(); break;
        case 77: _t->slotCanceled(); break;
        case 78: _t->slotTriggerLoadingMessage(); break;
        case 79: _t->slotAbortLoading(); break;
        case 80: _t->slotUrlChanged((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 81: _t->openWithLineLengthLimitOverride(); break;
        case 82: _t->checkCursorForAutobrace((*reinterpret_cast<std::add_pointer_t<KTextEditor::View*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KTextEditor::Cursor>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KTextEditor::Document* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KTextEditor::Document* >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KTextEditor::DocumentPrivate* >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KTextEditor::DocumentPrivate* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DocumentPrivate::*)(KTextEditor::Cursor , const QString & )>(_a, &DocumentPrivate::charactersSemiInteractivelyInserted, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentPrivate::*)(KTextEditor::Document * , KTextEditor::Range )>(_a, &DocumentPrivate::textInsertedRange, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentPrivate::*)(KTextEditor::Document * , KTextEditor::Range , const QString & )>(_a, &DocumentPrivate::textRemoved, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentPrivate::*)(int , int , int )>(_a, &DocumentPrivate::editLineWrapped, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentPrivate::*)(int , int )>(_a, &DocumentPrivate::editLineUnWrapped, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentPrivate::*)(KTextEditor::AnnotationModel * , KTextEditor::AnnotationModel * )>(_a, &DocumentPrivate::annotationModelChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentPrivate::*)(KTextEditor::Range )>(_a, &DocumentPrivate::aboutToRemoveText, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentPrivate::*)(bool )>(_a, &DocumentPrivate::dictionaryRangesPresent, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentPrivate::*)(KTextEditor::DocumentPrivate * )>(_a, &DocumentPrivate::defaultDictionaryChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentPrivate::*)(KTextEditor::DocumentPrivate * )>(_a, &DocumentPrivate::loaded, 9))
            return;
    }
}

const QMetaObject *KTextEditor::DocumentPrivate::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KTextEditor::DocumentPrivate::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11KTextEditor15DocumentPrivateE_t>.strings))
        return static_cast<void*>(this);
    return KTextEditor::Document::qt_metacast(_clname);
}

int KTextEditor::DocumentPrivate::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KTextEditor::Document::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 83)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 83;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 83)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 83;
    }
    return _id;
}

// SIGNAL 0
void KTextEditor::DocumentPrivate::charactersSemiInteractivelyInserted(KTextEditor::Cursor _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void KTextEditor::DocumentPrivate::textInsertedRange(KTextEditor::Document * _t1, KTextEditor::Range _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void KTextEditor::DocumentPrivate::textRemoved(KTextEditor::Document * _t1, KTextEditor::Range _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3);
}

// SIGNAL 3
void KTextEditor::DocumentPrivate::editLineWrapped(int _t1, int _t2, int _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2, _t3);
}

// SIGNAL 4
void KTextEditor::DocumentPrivate::editLineUnWrapped(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void KTextEditor::DocumentPrivate::annotationModelChanged(KTextEditor::AnnotationModel * _t1, KTextEditor::AnnotationModel * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void KTextEditor::DocumentPrivate::aboutToRemoveText(KTextEditor::Range _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void KTextEditor::DocumentPrivate::dictionaryRangesPresent(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void KTextEditor::DocumentPrivate::defaultDictionaryChanged(KTextEditor::DocumentPrivate * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void KTextEditor::DocumentPrivate::loaded(KTextEditor::DocumentPrivate * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}
QT_WARNING_POP
