/****************************************************************************
** Meta object code from reading C++ file 'katescriptview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../ktexteditor-6.25.0/src/script/katescriptview.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'katescriptview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14KateScriptViewE_t {};
} // unnamed namespace

template <> constexpr inline auto KateScriptView::qt_create_metaobjectdata<qt_meta_tag_ZN14KateScriptViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KateScriptView",
        "copy",
        "",
        "cut",
        "paste",
        "cursorPosition",
        "QJSValue",
        "cursorPositions",
        "setCursorPosition",
        "line",
        "column",
        "cursor",
        "setCursorPositions",
        "cursors",
        "virtualCursorPosition",
        "setVirtualCursorPosition",
        "selectedText",
        "hasSelection",
        "selection",
        "selections",
        "setSelection",
        "range",
        "setSelections",
        "ranges",
        "removeSelectedText",
        "selectAll",
        "clearSelection",
        "setBlockSelection",
        "on",
        "blockSelection",
        "align",
        "alignOn",
        "jsrange",
        "pattern",
        "searchText",
        "backwards",
        "executeCommand",
        "command",
        "args"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'copy'
        QtMocHelpers::MethodData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'cut'
        QtMocHelpers::MethodData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'paste'
        QtMocHelpers::MethodData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'cursorPosition'
        QtMocHelpers::MethodData<QJSValue()>(5, 2, QMC::AccessPublic, 0x80000000 | 6),
        // Method 'cursorPositions'
        QtMocHelpers::MethodData<QJSValue()>(7, 2, QMC::AccessPublic, 0x80000000 | 6),
        // Method 'setCursorPosition'
        QtMocHelpers::MethodData<void(int, int)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 9 }, { QMetaType::Int, 10 },
        }}),
        // Method 'setCursorPosition'
        QtMocHelpers::MethodData<void(const QJSValue &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 11 },
        }}),
        // Method 'setCursorPositions'
        QtMocHelpers::MethodData<void(const QJSValue &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 13 },
        }}),
        // Method 'virtualCursorPosition'
        QtMocHelpers::MethodData<QJSValue()>(14, 2, QMC::AccessPublic, 0x80000000 | 6),
        // Method 'setVirtualCursorPosition'
        QtMocHelpers::MethodData<void(int, int)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 9 }, { QMetaType::Int, 10 },
        }}),
        // Method 'setVirtualCursorPosition'
        QtMocHelpers::MethodData<void(const QJSValue &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 11 },
        }}),
        // Method 'selectedText'
        QtMocHelpers::MethodData<QString()>(16, 2, QMC::AccessPublic, QMetaType::QString),
        // Method 'hasSelection'
        QtMocHelpers::MethodData<bool()>(17, 2, QMC::AccessPublic, QMetaType::Bool),
        // Method 'selection'
        QtMocHelpers::MethodData<QJSValue()>(18, 2, QMC::AccessPublic, 0x80000000 | 6),
        // Method 'selections'
        QtMocHelpers::MethodData<QJSValue()>(19, 2, QMC::AccessPublic, 0x80000000 | 6),
        // Method 'setSelection'
        QtMocHelpers::MethodData<void(const QJSValue &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 21 },
        }}),
        // Method 'setSelections'
        QtMocHelpers::MethodData<void(const QJSValue &)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 23 },
        }}),
        // Method 'removeSelectedText'
        QtMocHelpers::MethodData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'selectAll'
        QtMocHelpers::MethodData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'clearSelection'
        QtMocHelpers::MethodData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'setBlockSelection'
        QtMocHelpers::MethodData<void(bool)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 28 },
        }}),
        // Method 'blockSelection'
        QtMocHelpers::MethodData<bool()>(29, 2, QMC::AccessPublic, QMetaType::Bool),
        // Method 'align'
        QtMocHelpers::MethodData<void(const QJSValue &)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 21 },
        }}),
        // Method 'alignOn'
        QtMocHelpers::MethodData<void(const QJSValue &, const QJSValue &)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 32 }, { 0x80000000 | 6, 33 },
        }}),
        // Method 'alignOn'
        QtMocHelpers::MethodData<void(const QJSValue &)>(31, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 6, 32 },
        }}),
        // Method 'searchText'
        QtMocHelpers::MethodData<QJSValue(const QJSValue &, const QString &, bool)>(34, 2, QMC::AccessPublic, 0x80000000 | 6, {{
            { 0x80000000 | 6, 21 }, { QMetaType::QString, 33 }, { QMetaType::Bool, 35 },
        }}),
        // Method 'searchText'
        QtMocHelpers::MethodData<QJSValue(const QJSValue &, const QString &)>(34, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 6, {{
            { 0x80000000 | 6, 21 }, { QMetaType::QString, 33 },
        }}),
        // Method 'executeCommand'
        QtMocHelpers::MethodData<QJSValue(const QString &, const QString &, const QJSValue &)>(36, 2, QMC::AccessPublic, 0x80000000 | 6, {{
            { QMetaType::QString, 37 }, { QMetaType::QString, 38 }, { 0x80000000 | 6, 32 },
        }}),
        // Method 'executeCommand'
        QtMocHelpers::MethodData<QJSValue(const QString &, const QString &)>(36, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 6, {{
            { QMetaType::QString, 37 }, { QMetaType::QString, 38 },
        }}),
        // Method 'executeCommand'
        QtMocHelpers::MethodData<QJSValue(const QString &)>(36, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 6, {{
            { QMetaType::QString, 37 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KateScriptView, qt_meta_tag_ZN14KateScriptViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KateScriptView::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14KateScriptViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14KateScriptViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14KateScriptViewE_t>.metaTypes,
    nullptr
} };

void KateScriptView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KateScriptView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->copy(); break;
        case 1: _t->cut(); break;
        case 2: _t->paste(); break;
        case 3: { QJSValue _r = _t->cursorPosition();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 4: { QJSValue _r = _t->cursorPositions();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 5: _t->setCursorPosition((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 6: _t->setCursorPosition((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1]))); break;
        case 7: _t->setCursorPositions((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1]))); break;
        case 8: { QJSValue _r = _t->virtualCursorPosition();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 9: _t->setVirtualCursorPosition((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 10: _t->setVirtualCursorPosition((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1]))); break;
        case 11: { QString _r = _t->selectedText();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 12: { bool _r = _t->hasSelection();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 13: { QJSValue _r = _t->selection();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 14: { QJSValue _r = _t->selections();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 15: _t->setSelection((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1]))); break;
        case 16: _t->setSelections((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1]))); break;
        case 17: _t->removeSelectedText(); break;
        case 18: _t->selectAll(); break;
        case 19: _t->clearSelection(); break;
        case 20: _t->setBlockSelection((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 21: { bool _r = _t->blockSelection();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 22: _t->align((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1]))); break;
        case 23: _t->alignOn((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[2]))); break;
        case 24: _t->alignOn((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1]))); break;
        case 25: { QJSValue _r = _t->searchText((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 26: { QJSValue _r = _t->searchText((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 27: { QJSValue _r = _t->executeCommand((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 28: { QJSValue _r = _t->executeCommand((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 29: { QJSValue _r = _t->executeCommand((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 22:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 23:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 24:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 25:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 26:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 27:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        }
    }
}

const QMetaObject *KateScriptView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateScriptView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14KateScriptViewE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KateScriptView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 30)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 30;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 30)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 30;
    }
    return _id;
}
QT_WARNING_POP
