/********************************************************************************
** Form generated from reading UI file 'completionconfigtab.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_COMPLETIONCONFIGTAB_H
#define UI_COMPLETIONCONFIGTAB_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_CompletionConfigTab
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *gbGeneral;
    QVBoxLayout *vboxLayout;
    QCheckBox *chkAutoCompletionEnabled;
    QCheckBox *chkAutoSelectFirstEntry;
    QCheckBox *chkTabCompletion;
    QCheckBox *chkEnterCompletion;
    QGroupBox *gbWordCompletion;
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QSpinBox *minimalWordLength;
    QSpacerItem *horizontalSpacer;
    QCheckBox *removeTail;
    QLabel *label_4;
    QGroupBox *gbKeywordCompletion;
    QVBoxLayout *verticalLayout_3;
    QLabel *label_2;
    QGroupBox *gbShowDoc;
    QVBoxLayout *verticalLayout_4;
    QLabel *label_3;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *CompletionConfigTab)
    {
        if (CompletionConfigTab->objectName().isEmpty())
            CompletionConfigTab->setObjectName("CompletionConfigTab");
        CompletionConfigTab->resize(489, 492);
        verticalLayout = new QVBoxLayout(CompletionConfigTab);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        gbGeneral = new QGroupBox(CompletionConfigTab);
        gbGeneral->setObjectName("gbGeneral");
        vboxLayout = new QVBoxLayout(gbGeneral);
        vboxLayout->setObjectName("vboxLayout");
        chkAutoCompletionEnabled = new QCheckBox(gbGeneral);
        chkAutoCompletionEnabled->setObjectName("chkAutoCompletionEnabled");

        vboxLayout->addWidget(chkAutoCompletionEnabled);

        chkAutoSelectFirstEntry = new QCheckBox(gbGeneral);
        chkAutoSelectFirstEntry->setObjectName("chkAutoSelectFirstEntry");

        vboxLayout->addWidget(chkAutoSelectFirstEntry);

        chkTabCompletion = new QCheckBox(gbGeneral);
        chkTabCompletion->setObjectName("chkTabCompletion");

        vboxLayout->addWidget(chkTabCompletion);

        chkEnterCompletion = new QCheckBox(gbGeneral);
        chkEnterCompletion->setObjectName("chkEnterCompletion");

        vboxLayout->addWidget(chkEnterCompletion);


        verticalLayout->addWidget(gbGeneral);

        gbWordCompletion = new QGroupBox(CompletionConfigTab);
        gbWordCompletion->setObjectName("gbWordCompletion");
        gbWordCompletion->setCheckable(true);
        gbWordCompletion->setChecked(false);
        verticalLayout_2 = new QVBoxLayout(gbWordCompletion);
        verticalLayout_2->setObjectName("verticalLayout_2");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(gbWordCompletion);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        minimalWordLength = new QSpinBox(gbWordCompletion);
        minimalWordLength->setObjectName("minimalWordLength");

        horizontalLayout->addWidget(minimalWordLength);

        horizontalSpacer = new QSpacerItem(1, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout_2->addLayout(horizontalLayout);

        removeTail = new QCheckBox(gbWordCompletion);
        removeTail->setObjectName("removeTail");

        verticalLayout_2->addWidget(removeTail);

        label_4 = new QLabel(gbWordCompletion);
        label_4->setObjectName("label_4");
        label_4->setWordWrap(true);

        verticalLayout_2->addWidget(label_4);


        verticalLayout->addWidget(gbWordCompletion);

        gbKeywordCompletion = new QGroupBox(CompletionConfigTab);
        gbKeywordCompletion->setObjectName("gbKeywordCompletion");
        gbKeywordCompletion->setCheckable(true);
        verticalLayout_3 = new QVBoxLayout(gbKeywordCompletion);
        verticalLayout_3->setObjectName("verticalLayout_3");
        label_2 = new QLabel(gbKeywordCompletion);
        label_2->setObjectName("label_2");
        label_2->setWordWrap(true);

        verticalLayout_3->addWidget(label_2);


        verticalLayout->addWidget(gbKeywordCompletion);

        gbShowDoc = new QGroupBox(CompletionConfigTab);
        gbShowDoc->setObjectName("gbShowDoc");
        gbShowDoc->setCheckable(true);
        verticalLayout_4 = new QVBoxLayout(gbShowDoc);
        verticalLayout_4->setObjectName("verticalLayout_4");
        label_3 = new QLabel(gbShowDoc);
        label_3->setObjectName("label_3");
        label_3->setWordWrap(true);

        verticalLayout_4->addWidget(label_3);


        verticalLayout->addWidget(gbShowDoc);

        verticalSpacer = new QSpacerItem(0, 1, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

#if QT_CONFIG(shortcut)
        label->setBuddy(minimalWordLength);
#endif // QT_CONFIG(shortcut)

        retranslateUi(CompletionConfigTab);

        QMetaObject::connectSlotsByName(CompletionConfigTab);
    } // setupUi

    void retranslateUi(QWidget *CompletionConfigTab)
    {
        gbGeneral->setTitle(tr2i18n("General", nullptr));
        chkAutoCompletionEnabled->setText(tr2i18n("Enable &auto completion", nullptr));
        chkAutoSelectFirstEntry->setText(tr2i18n("Auto select &first completion entry", nullptr));
        chkTabCompletion->setText(tr2i18n("Cycle through the list of completions using Tab / Shift+Tab", nullptr));
#if QT_CONFIG(tooltip)
        chkEnterCompletion->setToolTip(tr2i18n("Pressing enter will insert the text of selected completion item into the editor. If disabled, Tab key or double-click can still be used to trigger completion.", nullptr));
#endif // QT_CONFIG(tooltip)
        chkEnterCompletion->setText(tr2i18n("Use Enter key to insert selected completion", nullptr));
        gbWordCompletion->setTitle(tr2i18n("A&uto word completion", nullptr));
        label->setText(tr2i18n("Minimal word length to complete:", nullptr));
#if QT_CONFIG(tooltip)
        removeTail->setToolTip(tr2i18n("Remove tail of a previous word when completion item chosen from a list", nullptr));
#endif // QT_CONFIG(tooltip)
        removeTail->setText(tr2i18n("Remove tail on complete", nullptr));
        label_4->setText(tr2i18n("Word completion provides suggestions based on the words found in the document", nullptr));
        gbKeywordCompletion->setTitle(tr2i18n("&Keyword completion", nullptr));
        label_2->setText(tr2i18n("Keyword completion provides suggestions based on the keywords which exist in the document's language.", nullptr));
        gbShowDoc->setTitle(tr2i18n("Documentation with completion", nullptr));
        label_3->setText(tr2i18n("Show documentation beside completion box. If disabled, documentation can be shown by pressing Alt key.", nullptr));
        (void)CompletionConfigTab;
    } // retranslateUi

};

namespace Ui {
    class CompletionConfigTab: public Ui_CompletionConfigTab {};
} // namespace Ui

QT_END_NAMESPACE

#endif // COMPLETIONCONFIGTAB_H

