/********************************************************************************
** Form generated from reading UI file 'bordersappearanceconfigwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BORDERSAPPEARANCECONFIGWIDGET_H
#define UI_BORDERSAPPEARANCECONFIGWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_BordersAppearanceConfigWidget
{
public:
    QVBoxLayout *verticalLayout;
    QFormLayout *formLayout;
    QLabel *label;
    QCheckBox *chkShowFoldingMarkers;
    QCheckBox *chkShowFoldingPreview;
    QLabel *label_6;
    QComboBox *cmbFoldingArrowVisiblity;
    QSpacerItem *verticalSpacer_2;
    QLabel *label_2;
    QCheckBox *chkIconBorder;
    QCheckBox *chkLineNumbers;
    QCheckBox *chkShowLineModification;
    QSpacerItem *verticalSpacer_3;
    QLabel *label_3;
    QCheckBox *chkScrollbarMarks;
    QCheckBox *chkScrollbarPreview;
    QLabel *lblShowScrollbars;
    QComboBox *cmbShowScrollbars;
    QSpacerItem *verticalSpacer_4;
    QLabel *label_4;
    QCheckBox *chkScrollbarMiniMap;
    QSpinBox *spBoxMiniMapWidth;
    QLabel *labelMiniMapWidth;
    QCheckBox *chkScrollbarMiniMapAll;
    QRadioButton *rbSortBookmarksByCreation;
    QRadioButton *rbSortBookmarksByPosition;
    QLabel *label_5;
    QSpacerItem *verticalSpacer_5;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *BordersAppearanceConfigWidget)
    {
        if (BordersAppearanceConfigWidget->objectName().isEmpty())
            BordersAppearanceConfigWidget->setObjectName("BordersAppearanceConfigWidget");
        BordersAppearanceConfigWidget->resize(652, 677);
        verticalLayout = new QVBoxLayout(BordersAppearanceConfigWidget);
        verticalLayout->setObjectName("verticalLayout");
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        formLayout->setFormAlignment(Qt::AlignHCenter|Qt::AlignTop);
        formLayout->setContentsMargins(-1, 10, -1, -1);
        label = new QLabel(BordersAppearanceConfigWidget);
        label->setObjectName("label");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        chkShowFoldingMarkers = new QCheckBox(BordersAppearanceConfigWidget);
        chkShowFoldingMarkers->setObjectName("chkShowFoldingMarkers");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, chkShowFoldingMarkers);

        chkShowFoldingPreview = new QCheckBox(BordersAppearanceConfigWidget);
        chkShowFoldingPreview->setObjectName("chkShowFoldingPreview");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, chkShowFoldingPreview);

        label_6 = new QLabel(BordersAppearanceConfigWidget);
        label_6->setObjectName("label_6");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label_6);

        cmbFoldingArrowVisiblity = new QComboBox(BordersAppearanceConfigWidget);
        cmbFoldingArrowVisiblity->addItem(QString());
        cmbFoldingArrowVisiblity->addItem(QString());
        cmbFoldingArrowVisiblity->setObjectName("cmbFoldingArrowVisiblity");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, cmbFoldingArrowVisiblity);

        verticalSpacer_2 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        formLayout->setItem(4, QFormLayout::ItemRole::FieldRole, verticalSpacer_2);

        label_2 = new QLabel(BordersAppearanceConfigWidget);
        label_2->setObjectName("label_2");

        formLayout->setWidget(6, QFormLayout::ItemRole::LabelRole, label_2);

        chkIconBorder = new QCheckBox(BordersAppearanceConfigWidget);
        chkIconBorder->setObjectName("chkIconBorder");

        formLayout->setWidget(6, QFormLayout::ItemRole::FieldRole, chkIconBorder);

        chkLineNumbers = new QCheckBox(BordersAppearanceConfigWidget);
        chkLineNumbers->setObjectName("chkLineNumbers");

        formLayout->setWidget(7, QFormLayout::ItemRole::FieldRole, chkLineNumbers);

        chkShowLineModification = new QCheckBox(BordersAppearanceConfigWidget);
        chkShowLineModification->setObjectName("chkShowLineModification");

        formLayout->setWidget(8, QFormLayout::ItemRole::FieldRole, chkShowLineModification);

        verticalSpacer_3 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        formLayout->setItem(9, QFormLayout::ItemRole::FieldRole, verticalSpacer_3);

        label_3 = new QLabel(BordersAppearanceConfigWidget);
        label_3->setObjectName("label_3");

        formLayout->setWidget(10, QFormLayout::ItemRole::LabelRole, label_3);

        chkScrollbarMarks = new QCheckBox(BordersAppearanceConfigWidget);
        chkScrollbarMarks->setObjectName("chkScrollbarMarks");

        formLayout->setWidget(10, QFormLayout::ItemRole::FieldRole, chkScrollbarMarks);

        chkScrollbarPreview = new QCheckBox(BordersAppearanceConfigWidget);
        chkScrollbarPreview->setObjectName("chkScrollbarPreview");

        formLayout->setWidget(11, QFormLayout::ItemRole::FieldRole, chkScrollbarPreview);

        lblShowScrollbars = new QLabel(BordersAppearanceConfigWidget);
        lblShowScrollbars->setObjectName("lblShowScrollbars");

        formLayout->setWidget(12, QFormLayout::ItemRole::LabelRole, lblShowScrollbars);

        cmbShowScrollbars = new QComboBox(BordersAppearanceConfigWidget);
        cmbShowScrollbars->addItem(QString());
        cmbShowScrollbars->addItem(QString());
        cmbShowScrollbars->addItem(QString());
        cmbShowScrollbars->setObjectName("cmbShowScrollbars");

        formLayout->setWidget(12, QFormLayout::ItemRole::FieldRole, cmbShowScrollbars);

        verticalSpacer_4 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        formLayout->setItem(13, QFormLayout::ItemRole::FieldRole, verticalSpacer_4);

        label_4 = new QLabel(BordersAppearanceConfigWidget);
        label_4->setObjectName("label_4");

        formLayout->setWidget(14, QFormLayout::ItemRole::LabelRole, label_4);

        chkScrollbarMiniMap = new QCheckBox(BordersAppearanceConfigWidget);
        chkScrollbarMiniMap->setObjectName("chkScrollbarMiniMap");

        formLayout->setWidget(14, QFormLayout::ItemRole::FieldRole, chkScrollbarMiniMap);

        spBoxMiniMapWidth = new QSpinBox(BordersAppearanceConfigWidget);
        spBoxMiniMapWidth->setObjectName("spBoxMiniMapWidth");
        spBoxMiniMapWidth->setMinimum(40);
        spBoxMiniMapWidth->setMaximum(100);
        spBoxMiniMapWidth->setSingleStep(5);
        spBoxMiniMapWidth->setValue(60);

        formLayout->setWidget(15, QFormLayout::ItemRole::FieldRole, spBoxMiniMapWidth);

        labelMiniMapWidth = new QLabel(BordersAppearanceConfigWidget);
        labelMiniMapWidth->setObjectName("labelMiniMapWidth");

        formLayout->setWidget(15, QFormLayout::ItemRole::LabelRole, labelMiniMapWidth);

        chkScrollbarMiniMapAll = new QCheckBox(BordersAppearanceConfigWidget);
        chkScrollbarMiniMapAll->setObjectName("chkScrollbarMiniMapAll");
        chkScrollbarMiniMapAll->setEnabled(false);
        chkScrollbarMiniMapAll->setChecked(true);

        formLayout->setWidget(16, QFormLayout::ItemRole::FieldRole, chkScrollbarMiniMapAll);

        rbSortBookmarksByCreation = new QRadioButton(BordersAppearanceConfigWidget);
        rbSortBookmarksByCreation->setObjectName("rbSortBookmarksByCreation");

        formLayout->setWidget(18, QFormLayout::ItemRole::FieldRole, rbSortBookmarksByCreation);

        rbSortBookmarksByPosition = new QRadioButton(BordersAppearanceConfigWidget);
        rbSortBookmarksByPosition->setObjectName("rbSortBookmarksByPosition");

        formLayout->setWidget(19, QFormLayout::ItemRole::FieldRole, rbSortBookmarksByPosition);

        label_5 = new QLabel(BordersAppearanceConfigWidget);
        label_5->setObjectName("label_5");

        formLayout->setWidget(18, QFormLayout::ItemRole::LabelRole, label_5);

        verticalSpacer_5 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        formLayout->setItem(17, QFormLayout::ItemRole::FieldRole, verticalSpacer_5);


        verticalLayout->addLayout(formLayout);

        verticalSpacer = new QSpacerItem(20, 31, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

#if QT_CONFIG(shortcut)
        label_6->setBuddy(cmbFoldingArrowVisiblity);
        lblShowScrollbars->setBuddy(cmbShowScrollbars);
        labelMiniMapWidth->setBuddy(spBoxMiniMapWidth);
#endif // QT_CONFIG(shortcut)

        retranslateUi(BordersAppearanceConfigWidget);

        QMetaObject::connectSlotsByName(BordersAppearanceConfigWidget);
    } // setupUi

    void retranslateUi(QWidget *BordersAppearanceConfigWidget)
    {
        label->setText(tr2i18n("Code block folding:", nullptr));
#if QT_CONFIG(whatsthis)
        chkShowFoldingMarkers->setWhatsThis(tr2i18n("If this option is checked, every new view will display marks for folding.", nullptr));
#endif // QT_CONFIG(whatsthis)
        chkShowFoldingMarkers->setText(tr2i18n("Show arrows to collapse code blocks", nullptr));
#if QT_CONFIG(whatsthis)
        chkShowFoldingPreview->setWhatsThis(tr2i18n("If checked, hovering over a folded region shows a preview of the folded text in a popup.", nullptr));
#endif // QT_CONFIG(whatsthis)
        chkShowFoldingPreview->setText(tr2i18n("Show preview of folded blocks on hover", nullptr));
        label_6->setText(tr2i18n("Folding arrows visibility:", nullptr));
        cmbFoldingArrowVisiblity->setItemText(0, tr2i18n("Show on Hover", nullptr));
        cmbFoldingArrowVisiblity->setItemText(1, tr2i18n("Show Always", nullptr));

        label_2->setText(tr2i18n("Left side:", nullptr));
#if QT_CONFIG(whatsthis)
        chkIconBorder->setWhatsThis(tr2i18n("<p>If this option is checked, every new view will display an icon border on the left hand side.</p><p>The icon border shows bookmark signs, for instance.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        chkIconBorder->setText(tr2i18n("Show marks", nullptr));
#if QT_CONFIG(whatsthis)
        chkLineNumbers->setWhatsThis(tr2i18n("If this option is checked, every new view will display line numbers on the left hand side.", nullptr));
#endif // QT_CONFIG(whatsthis)
        chkLineNumbers->setText(tr2i18n("Show &line numbers", nullptr));
#if QT_CONFIG(whatsthis)
        chkShowLineModification->setWhatsThis(tr2i18n("If this option is checked, a small indicator for modified and saved lines is shown on the left hand side.", nullptr));
#endif // QT_CONFIG(whatsthis)
        chkShowLineModification->setText(tr2i18n("Highlight changed and unsaved lines", nullptr));
        label_3->setText(tr2i18n("Scrollbars:", nullptr));
#if QT_CONFIG(whatsthis)
        chkScrollbarMarks->setWhatsThis(tr2i18n("<p>If this option is checked, every new view will show marks on the vertical scrollbar.</p><p>These marks will show bookmarks, for instance.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        chkScrollbarMarks->setText(tr2i18n("Show marks", nullptr));
#if QT_CONFIG(whatsthis)
        chkScrollbarPreview->setWhatsThis(tr2i18n("<p>If this option is checked, hovering over the vertical scrollbar will show a preview of the text.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        chkScrollbarPreview->setText(tr2i18n("Show preview when hovering over scrollbar", nullptr));
        lblShowScrollbars->setText(tr2i18n("Scro&llbars visibility:", nullptr));
        cmbShowScrollbars->setItemText(0, tr2i18n("Always On", nullptr));
        cmbShowScrollbars->setItemText(1, tr2i18n("Show When Needed", nullptr));
        cmbShowScrollbars->setItemText(2, tr2i18n("Always Off", nullptr));

        label_4->setText(tr2i18n("Minimap:", nullptr));
#if QT_CONFIG(whatsthis)
        chkScrollbarMiniMap->setWhatsThis(tr2i18n("If this option is checked, every new view will show a mini map on the vertical scrollbar.", nullptr));
#endif // QT_CONFIG(whatsthis)
        chkScrollbarMiniMap->setText(tr2i18n("Show minimap", nullptr));
        labelMiniMapWidth->setText(tr2i18n("Minim&ap width:", nullptr));
#if QT_CONFIG(whatsthis)
        chkScrollbarMiniMapAll->setWhatsThis(tr2i18n("If this option is checked, every new view will show a mini map of the whole document on the vertical scrollbar.", nullptr));
#endif // QT_CONFIG(whatsthis)
        chkScrollbarMiniMapAll->setText(tr2i18n("Map the whole document", nullptr));
#if QT_CONFIG(whatsthis)
        rbSortBookmarksByCreation->setWhatsThis(tr2i18n("Each new bookmark will be added to the bottom, independently from where it is placed in the document.", nullptr));
#endif // QT_CONFIG(whatsthis)
        rbSortBookmarksByCreation->setText(tr2i18n("By date created", nullptr));
#if QT_CONFIG(whatsthis)
        rbSortBookmarksByPosition->setWhatsThis(tr2i18n("The bookmarks will be ordered by the line numbers they are placed at.", nullptr));
#endif // QT_CONFIG(whatsthis)
        rbSortBookmarksByPosition->setText(tr2i18n("By line number", nullptr));
        label_5->setText(tr2i18n("Sort bookmarks menu:", nullptr));
        (void)BordersAppearanceConfigWidget;
    } // retranslateUi

};

namespace Ui {
    class BordersAppearanceConfigWidget: public Ui_BordersAppearanceConfigWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // BORDERSAPPEARANCECONFIGWIDGET_H

