/********************************************************************************
** Form generated from reading UI file 'spellcheckconfigwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SPELLCHECKCONFIGWIDGET_H
#define UI_SPELLCHECKCONFIGWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_SpellCheckConfigWidget
{
public:
    QVBoxLayout *vboxLayout;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *SpellCheckConfigWidget)
    {
        if (SpellCheckConfigWidget->objectName().isEmpty())
            SpellCheckConfigWidget->setObjectName("SpellCheckConfigWidget");
        vboxLayout = new QVBoxLayout(SpellCheckConfigWidget);
        vboxLayout->setContentsMargins(0, 0, 0, 0);
        vboxLayout->setObjectName("vboxLayout");
        spacerItem = new QSpacerItem(0, 1, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);

        vboxLayout->addItem(spacerItem);


        retranslateUi(SpellCheckConfigWidget);

        QMetaObject::connectSlotsByName(SpellCheckConfigWidget);
    } // setupUi

    void retranslateUi(QWidget *SpellCheckConfigWidget)
    {
        (void)SpellCheckConfigWidget;
    } // retranslateUi

};

namespace Ui {
    class SpellCheckConfigWidget: public Ui_SpellCheckConfigWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SPELLCHECKCONFIGWIDGET_H

