/****************************************************************************
** Meta object code from reading C++ file 'kateundomanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../ktexteditor-6.25.0/src/undo/kateundomanager.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kateundomanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15KateUndoManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto KateUndoManager::qt_create_metaobjectdata<qt_meta_tag_ZN15KateUndoManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KateUndoManager",
        "undoChanged",
        "",
        "undoStart",
        "KTextEditor::Document*",
        "undoEnd",
        "redoStart",
        "redoEnd",
        "isActiveChanged",
        "enabled",
        "undo",
        "redo",
        "clearUndo",
        "clearRedo",
        "editStart",
        "editEnd",
        "startUndo",
        "endUndo",
        "inputMethodStart",
        "inputMethodEnd",
        "slotTextInserted",
        "line",
        "col",
        "s",
        "Kate::TextLine",
        "tl",
        "slotTextRemoved",
        "slotMarkLineAutoWrapped",
        "autowrapped",
        "slotLineWrapped",
        "length",
        "newLine",
        "slotLineUnWrapped",
        "lineRemoved",
        "nextLine",
        "slotLineInserted",
        "slotLineRemoved",
        "addUndoItem",
        "UndoItem",
        "setActive",
        "active",
        "updateModified",
        "undoCancel",
        "viewCreated",
        "KTextEditor::View*",
        "newView"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'undoChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'undoStart'
        QtMocHelpers::SignalData<void(KTextEditor::Document *)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 2 },
        }}),
        // Signal 'undoEnd'
        QtMocHelpers::SignalData<void(KTextEditor::Document *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 2 },
        }}),
        // Signal 'redoStart'
        QtMocHelpers::SignalData<void(KTextEditor::Document *)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 2 },
        }}),
        // Signal 'redoEnd'
        QtMocHelpers::SignalData<void(KTextEditor::Document *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 2 },
        }}),
        // Signal 'isActiveChanged'
        QtMocHelpers::SignalData<void(bool)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 9 },
        }}),
        // Slot 'undo'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'redo'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'clearUndo'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'clearRedo'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'editStart'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'editEnd'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'startUndo'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'endUndo'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'inputMethodStart'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'inputMethodEnd'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotTextInserted'
        QtMocHelpers::SlotData<void(int, int, const QString &, const Kate::TextLine &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 21 }, { QMetaType::Int, 22 }, { QMetaType::QString, 23 }, { 0x80000000 | 24, 25 },
        }}),
        // Slot 'slotTextRemoved'
        QtMocHelpers::SlotData<void(int, int, const QString &, const Kate::TextLine &)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 21 }, { QMetaType::Int, 22 }, { QMetaType::QString, 23 }, { 0x80000000 | 24, 25 },
        }}),
        // Slot 'slotMarkLineAutoWrapped'
        QtMocHelpers::SlotData<void(int, bool)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 21 }, { QMetaType::Bool, 28 },
        }}),
        // Slot 'slotLineWrapped'
        QtMocHelpers::SlotData<void(int, int, int, bool, const Kate::TextLine &)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 21 }, { QMetaType::Int, 22 }, { QMetaType::Int, 30 }, { QMetaType::Bool, 31 },
            { 0x80000000 | 24, 25 },
        }}),
        // Slot 'slotLineUnWrapped'
        QtMocHelpers::SlotData<void(int, int, int, bool, const Kate::TextLine &, const Kate::TextLine &)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 21 }, { QMetaType::Int, 22 }, { QMetaType::Int, 30 }, { QMetaType::Bool, 33 },
            { 0x80000000 | 24, 25 }, { 0x80000000 | 24, 34 },
        }}),
        // Slot 'slotLineInserted'
        QtMocHelpers::SlotData<void(int, const QString &)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 21 }, { QMetaType::QString, 23 },
        }}),
        // Slot 'slotLineRemoved'
        QtMocHelpers::SlotData<void(int, const QString &, const Kate::TextLine &)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 21 }, { QMetaType::QString, 23 }, { 0x80000000 | 24, 25 },
        }}),
        // Slot 'addUndoItem'
        QtMocHelpers::SlotData<void(UndoItem)>(37, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 38, 10 },
        }}),
        // Slot 'setActive'
        QtMocHelpers::SlotData<void(bool)>(39, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 40 },
        }}),
        // Slot 'updateModified'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'undoCancel'
        QtMocHelpers::SlotData<void()>(42, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'viewCreated'
        QtMocHelpers::SlotData<void(KTextEditor::Document *, KTextEditor::View *) const>(43, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 4, 2 }, { 0x80000000 | 44, 45 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KateUndoManager, qt_meta_tag_ZN15KateUndoManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KateUndoManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15KateUndoManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15KateUndoManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15KateUndoManagerE_t>.metaTypes,
    nullptr
} };

void KateUndoManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KateUndoManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->undoChanged(); break;
        case 1: _t->undoStart((*reinterpret_cast<std::add_pointer_t<KTextEditor::Document*>>(_a[1]))); break;
        case 2: _t->undoEnd((*reinterpret_cast<std::add_pointer_t<KTextEditor::Document*>>(_a[1]))); break;
        case 3: _t->redoStart((*reinterpret_cast<std::add_pointer_t<KTextEditor::Document*>>(_a[1]))); break;
        case 4: _t->redoEnd((*reinterpret_cast<std::add_pointer_t<KTextEditor::Document*>>(_a[1]))); break;
        case 5: _t->isActiveChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->undo(); break;
        case 7: _t->redo(); break;
        case 8: _t->clearUndo(); break;
        case 9: _t->clearRedo(); break;
        case 10: _t->editStart(); break;
        case 11: _t->editEnd(); break;
        case 12: _t->startUndo(); break;
        case 13: _t->endUndo(); break;
        case 14: _t->inputMethodStart(); break;
        case 15: _t->inputMethodEnd(); break;
        case 16: _t->slotTextInserted((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<Kate::TextLine>>(_a[4]))); break;
        case 17: _t->slotTextRemoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<Kate::TextLine>>(_a[4]))); break;
        case 18: _t->slotMarkLineAutoWrapped((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 19: _t->slotLineWrapped((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<Kate::TextLine>>(_a[5]))); break;
        case 20: _t->slotLineUnWrapped((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<Kate::TextLine>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<Kate::TextLine>>(_a[6]))); break;
        case 21: _t->slotLineInserted((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 22: _t->slotLineRemoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Kate::TextLine>>(_a[3]))); break;
        case 23: _t->addUndoItem((*reinterpret_cast<std::add_pointer_t<UndoItem>>(_a[1]))); break;
        case 24: _t->setActive((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 25: _t->updateModified(); break;
        case 26: _t->undoCancel(); break;
        case 27: _t->viewCreated((*reinterpret_cast<std::add_pointer_t<KTextEditor::Document*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KTextEditor::View*>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 27:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KTextEditor::View* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KateUndoManager::*)()>(_a, &KateUndoManager::undoChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KateUndoManager::*)(KTextEditor::Document * )>(_a, &KateUndoManager::undoStart, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KateUndoManager::*)(KTextEditor::Document * )>(_a, &KateUndoManager::undoEnd, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KateUndoManager::*)(KTextEditor::Document * )>(_a, &KateUndoManager::redoStart, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KateUndoManager::*)(KTextEditor::Document * )>(_a, &KateUndoManager::redoEnd, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (KateUndoManager::*)(bool )>(_a, &KateUndoManager::isActiveChanged, 5))
            return;
    }
}

const QMetaObject *KateUndoManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateUndoManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15KateUndoManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KateUndoManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 28)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 28;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 28)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 28;
    }
    return _id;
}

// SIGNAL 0
void KateUndoManager::undoChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KateUndoManager::undoStart(KTextEditor::Document * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void KateUndoManager::undoEnd(KTextEditor::Document * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void KateUndoManager::redoStart(KTextEditor::Document * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void KateUndoManager::redoEnd(KTextEditor::Document * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void KateUndoManager::isActiveChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}
QT_WARNING_POP
