/****************************************************************************
** Meta object code from reading C++ file 'document.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../ktexteditor-6.25.0/src/include/ktexteditor/document.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'document.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11KTextEditor8DocumentE_t {};
} // unnamed namespace

template <> constexpr inline auto KTextEditor::Document::qt_create_metaobjectdata<qt_meta_tag_ZN11KTextEditor8DocumentE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KTextEditor::Document",
        "viewCreated",
        "",
        "KTextEditor::Document*",
        "document",
        "KTextEditor::View*",
        "view",
        "documentNameChanged",
        "documentUrlChanged",
        "modifiedChanged",
        "readWriteChanged",
        "documentSavedOrUploaded",
        "saveAs",
        "aboutToClose",
        "aboutToReload",
        "reloaded",
        "aboutToSave",
        "editingStarted",
        "editingFinished",
        "lineWrapped",
        "KTextEditor::Cursor",
        "position",
        "lineUnwrapped",
        "line",
        "textInserted",
        "text",
        "textRemoved",
        "KTextEditor::Range",
        "range",
        "textChanged",
        "modeChanged",
        "highlightingModeChanged",
        "configChanged",
        "aboutToDeleteMovingInterfaceContent",
        "aboutToInvalidateMovingInterfaceContent",
        "modifiedOnDisk",
        "isModified",
        "KTextEditor::Document::ModifiedOnDiskReason",
        "reason",
        "marksChanged",
        "markChanged",
        "KTextEditor::Mark",
        "mark",
        "KTextEditor::Document::MarkChangeAction",
        "action",
        "markToolTipRequested",
        "QPoint",
        "bool&",
        "handled",
        "markContextMenuRequested",
        "pos",
        "markClicked"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'viewCreated'
        QtMocHelpers::SignalData<void(KTextEditor::Document *, KTextEditor::View *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Signal 'documentNameChanged'
        QtMocHelpers::SignalData<void(KTextEditor::Document *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'documentUrlChanged'
        QtMocHelpers::SignalData<void(KTextEditor::Document *)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'modifiedChanged'
        QtMocHelpers::SignalData<void(KTextEditor::Document *)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'readWriteChanged'
        QtMocHelpers::SignalData<void(KTextEditor::Document *)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'documentSavedOrUploaded'
        QtMocHelpers::SignalData<void(KTextEditor::Document *, bool)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Bool, 12 },
        }}),
        // Signal 'aboutToClose'
        QtMocHelpers::SignalData<void(KTextEditor::Document *)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'aboutToReload'
        QtMocHelpers::SignalData<void(KTextEditor::Document *)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'reloaded'
        QtMocHelpers::SignalData<void(KTextEditor::Document *)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'aboutToSave'
        QtMocHelpers::SignalData<void(KTextEditor::Document *)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'editingStarted'
        QtMocHelpers::SignalData<void(KTextEditor::Document *)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'editingFinished'
        QtMocHelpers::SignalData<void(KTextEditor::Document *)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'lineWrapped'
        QtMocHelpers::SignalData<void(KTextEditor::Document *, KTextEditor::Cursor)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 20, 21 },
        }}),
        // Signal 'lineUnwrapped'
        QtMocHelpers::SignalData<void(KTextEditor::Document *, int)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Int, 23 },
        }}),
        // Signal 'textInserted'
        QtMocHelpers::SignalData<void(KTextEditor::Document *, KTextEditor::Cursor, const QString &)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 20, 21 }, { QMetaType::QString, 25 },
        }}),
        // Signal 'textRemoved'
        QtMocHelpers::SignalData<void(KTextEditor::Document *, KTextEditor::Range, const QString &)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 27, 28 }, { QMetaType::QString, 25 },
        }}),
        // Signal 'textChanged'
        QtMocHelpers::SignalData<void(KTextEditor::Document *)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'modeChanged'
        QtMocHelpers::SignalData<void(KTextEditor::Document *)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'highlightingModeChanged'
        QtMocHelpers::SignalData<void(KTextEditor::Document *)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'configChanged'
        QtMocHelpers::SignalData<void(KTextEditor::Document *)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'aboutToDeleteMovingInterfaceContent'
        QtMocHelpers::SignalData<void(KTextEditor::Document *)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'aboutToInvalidateMovingInterfaceContent'
        QtMocHelpers::SignalData<void(KTextEditor::Document *)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'modifiedOnDisk'
        QtMocHelpers::SignalData<void(KTextEditor::Document *, bool, KTextEditor::Document::ModifiedOnDiskReason)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Bool, 36 }, { 0x80000000 | 37, 38 },
        }}),
        // Signal 'marksChanged'
        QtMocHelpers::SignalData<void(KTextEditor::Document *)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'markChanged'
        QtMocHelpers::SignalData<void(KTextEditor::Document *, KTextEditor::Mark, KTextEditor::Document::MarkChangeAction)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 41, 42 }, { 0x80000000 | 43, 44 },
        }}),
        // Signal 'markToolTipRequested'
        QtMocHelpers::SignalData<void(KTextEditor::Document *, KTextEditor::Mark, QPoint, bool &)>(45, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 41, 42 }, { 0x80000000 | 46, 21 }, { 0x80000000 | 47, 48 },
        }}),
        // Signal 'markContextMenuRequested'
        QtMocHelpers::SignalData<void(KTextEditor::Document *, KTextEditor::Mark, QPoint, bool &)>(49, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 41, 42 }, { 0x80000000 | 46, 50 }, { 0x80000000 | 47, 48 },
        }}),
        // Signal 'markClicked'
        QtMocHelpers::SignalData<void(KTextEditor::Document *, KTextEditor::Mark, bool &)>(51, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 41, 42 }, { 0x80000000 | 47, 48 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Document, qt_meta_tag_ZN11KTextEditor8DocumentE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KTextEditor::Document::staticMetaObject = { {
    QMetaObject::SuperData::link<KParts::ReadWritePart::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11KTextEditor8DocumentE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11KTextEditor8DocumentE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11KTextEditor8DocumentE_t>.metaTypes,
    nullptr
} };

void KTextEditor::Document::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Document *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->viewCreated((*reinterpret_cast<std::add_pointer_t<KTextEditor::Document*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KTextEditor::View*>>(_a[2]))); break;
        case 1: _t->documentNameChanged((*reinterpret_cast<std::add_pointer_t<KTextEditor::Document*>>(_a[1]))); break;
        case 2: _t->documentUrlChanged((*reinterpret_cast<std::add_pointer_t<KTextEditor::Document*>>(_a[1]))); break;
        case 3: _t->modifiedChanged((*reinterpret_cast<std::add_pointer_t<KTextEditor::Document*>>(_a[1]))); break;
        case 4: _t->readWriteChanged((*reinterpret_cast<std::add_pointer_t<KTextEditor::Document*>>(_a[1]))); break;
        case 5: _t->documentSavedOrUploaded((*reinterpret_cast<std::add_pointer_t<KTextEditor::Document*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 6: _t->aboutToClose((*reinterpret_cast<std::add_pointer_t<KTextEditor::Document*>>(_a[1]))); break;
        case 7: _t->aboutToReload((*reinterpret_cast<std::add_pointer_t<KTextEditor::Document*>>(_a[1]))); break;
        case 8: _t->reloaded((*reinterpret_cast<std::add_pointer_t<KTextEditor::Document*>>(_a[1]))); break;
        case 9: _t->aboutToSave((*reinterpret_cast<std::add_pointer_t<KTextEditor::Document*>>(_a[1]))); break;
        case 10: _t->editingStarted((*reinterpret_cast<std::add_pointer_t<KTextEditor::Document*>>(_a[1]))); break;
        case 11: _t->editingFinished((*reinterpret_cast<std::add_pointer_t<KTextEditor::Document*>>(_a[1]))); break;
        case 12: _t->lineWrapped((*reinterpret_cast<std::add_pointer_t<KTextEditor::Document*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KTextEditor::Cursor>>(_a[2]))); break;
        case 13: _t->lineUnwrapped((*reinterpret_cast<std::add_pointer_t<KTextEditor::Document*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 14: _t->textInserted((*reinterpret_cast<std::add_pointer_t<KTextEditor::Document*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KTextEditor::Cursor>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 15: _t->textRemoved((*reinterpret_cast<std::add_pointer_t<KTextEditor::Document*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KTextEditor::Range>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 16: _t->textChanged((*reinterpret_cast<std::add_pointer_t<KTextEditor::Document*>>(_a[1]))); break;
        case 17: _t->modeChanged((*reinterpret_cast<std::add_pointer_t<KTextEditor::Document*>>(_a[1]))); break;
        case 18: _t->highlightingModeChanged((*reinterpret_cast<std::add_pointer_t<KTextEditor::Document*>>(_a[1]))); break;
        case 19: _t->configChanged((*reinterpret_cast<std::add_pointer_t<KTextEditor::Document*>>(_a[1]))); break;
        case 20: _t->aboutToDeleteMovingInterfaceContent((*reinterpret_cast<std::add_pointer_t<KTextEditor::Document*>>(_a[1]))); break;
        case 21: _t->aboutToInvalidateMovingInterfaceContent((*reinterpret_cast<std::add_pointer_t<KTextEditor::Document*>>(_a[1]))); break;
        case 22: _t->modifiedOnDisk((*reinterpret_cast<std::add_pointer_t<KTextEditor::Document*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<KTextEditor::Document::ModifiedOnDiskReason>>(_a[3]))); break;
        case 23: _t->marksChanged((*reinterpret_cast<std::add_pointer_t<KTextEditor::Document*>>(_a[1]))); break;
        case 24: _t->markChanged((*reinterpret_cast<std::add_pointer_t<KTextEditor::Document*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KTextEditor::Mark>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<KTextEditor::Document::MarkChangeAction>>(_a[3]))); break;
        case 25: _t->markToolTipRequested((*reinterpret_cast<std::add_pointer_t<KTextEditor::Document*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KTextEditor::Mark>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool&>>(_a[4]))); break;
        case 26: _t->markContextMenuRequested((*reinterpret_cast<std::add_pointer_t<KTextEditor::Document*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KTextEditor::Mark>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool&>>(_a[4]))); break;
        case 27: _t->markClicked((*reinterpret_cast<std::add_pointer_t<KTextEditor::Document*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KTextEditor::Mark>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool&>>(_a[3]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KTextEditor::Document* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KTextEditor::Document* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KTextEditor::Document* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KTextEditor::Document* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KTextEditor::Document* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KTextEditor::Document* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KTextEditor::Document* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KTextEditor::Document* >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KTextEditor::Document* >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KTextEditor::Document* >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KTextEditor::Document* >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KTextEditor::Document* >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KTextEditor::Document* >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KTextEditor::Document* >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KTextEditor::Document* >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KTextEditor::Document* >(); break;
            }
            break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KTextEditor::Document* >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KTextEditor::Document* >(); break;
            }
            break;
        case 18:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KTextEditor::Document* >(); break;
            }
            break;
        case 19:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KTextEditor::Document* >(); break;
            }
            break;
        case 20:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KTextEditor::Document* >(); break;
            }
            break;
        case 21:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KTextEditor::Document* >(); break;
            }
            break;
        case 22:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KTextEditor::Document* >(); break;
            }
            break;
        case 23:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KTextEditor::Document* >(); break;
            }
            break;
        case 24:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KTextEditor::Document* >(); break;
            }
            break;
        case 25:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KTextEditor::Document* >(); break;
            }
            break;
        case 26:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KTextEditor::Document* >(); break;
            }
            break;
        case 27:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KTextEditor::Document* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Document::*)(KTextEditor::Document * , KTextEditor::View * )>(_a, &Document::viewCreated, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Document::*)(KTextEditor::Document * )>(_a, &Document::documentNameChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Document::*)(KTextEditor::Document * )>(_a, &Document::documentUrlChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Document::*)(KTextEditor::Document * )>(_a, &Document::modifiedChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Document::*)(KTextEditor::Document * )>(_a, &Document::readWriteChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Document::*)(KTextEditor::Document * , bool )>(_a, &Document::documentSavedOrUploaded, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Document::*)(KTextEditor::Document * )>(_a, &Document::aboutToClose, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Document::*)(KTextEditor::Document * )>(_a, &Document::aboutToReload, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Document::*)(KTextEditor::Document * )>(_a, &Document::reloaded, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Document::*)(KTextEditor::Document * )>(_a, &Document::aboutToSave, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Document::*)(KTextEditor::Document * )>(_a, &Document::editingStarted, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Document::*)(KTextEditor::Document * )>(_a, &Document::editingFinished, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (Document::*)(KTextEditor::Document * , KTextEditor::Cursor )>(_a, &Document::lineWrapped, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (Document::*)(KTextEditor::Document * , int )>(_a, &Document::lineUnwrapped, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (Document::*)(KTextEditor::Document * , KTextEditor::Cursor , const QString & )>(_a, &Document::textInserted, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (Document::*)(KTextEditor::Document * , KTextEditor::Range , const QString & )>(_a, &Document::textRemoved, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (Document::*)(KTextEditor::Document * )>(_a, &Document::textChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (Document::*)(KTextEditor::Document * )>(_a, &Document::modeChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (Document::*)(KTextEditor::Document * )>(_a, &Document::highlightingModeChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (Document::*)(KTextEditor::Document * )>(_a, &Document::configChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (Document::*)(KTextEditor::Document * )>(_a, &Document::aboutToDeleteMovingInterfaceContent, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (Document::*)(KTextEditor::Document * )>(_a, &Document::aboutToInvalidateMovingInterfaceContent, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (Document::*)(KTextEditor::Document * , bool , KTextEditor::Document::ModifiedOnDiskReason )>(_a, &Document::modifiedOnDisk, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (Document::*)(KTextEditor::Document * )>(_a, &Document::marksChanged, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (Document::*)(KTextEditor::Document * , KTextEditor::Mark , KTextEditor::Document::MarkChangeAction )>(_a, &Document::markChanged, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (Document::*)(KTextEditor::Document * , KTextEditor::Mark , QPoint , bool & )>(_a, &Document::markToolTipRequested, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (Document::*)(KTextEditor::Document * , KTextEditor::Mark , QPoint , bool & )>(_a, &Document::markContextMenuRequested, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (Document::*)(KTextEditor::Document * , KTextEditor::Mark , bool & )>(_a, &Document::markClicked, 27))
            return;
    }
}

const QMetaObject *KTextEditor::Document::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KTextEditor::Document::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11KTextEditor8DocumentE_t>.strings))
        return static_cast<void*>(this);
    return KParts::ReadWritePart::qt_metacast(_clname);
}

int KTextEditor::Document::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KParts::ReadWritePart::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 28)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 28;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 28)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 28;
    }
    return _id;
}

// SIGNAL 0
void KTextEditor::Document::viewCreated(KTextEditor::Document * _t1, KTextEditor::View * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void KTextEditor::Document::documentNameChanged(KTextEditor::Document * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void KTextEditor::Document::documentUrlChanged(KTextEditor::Document * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void KTextEditor::Document::modifiedChanged(KTextEditor::Document * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void KTextEditor::Document::readWriteChanged(KTextEditor::Document * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void KTextEditor::Document::documentSavedOrUploaded(KTextEditor::Document * _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void KTextEditor::Document::aboutToClose(KTextEditor::Document * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void KTextEditor::Document::aboutToReload(KTextEditor::Document * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void KTextEditor::Document::reloaded(KTextEditor::Document * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void KTextEditor::Document::aboutToSave(KTextEditor::Document * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void KTextEditor::Document::editingStarted(KTextEditor::Document * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void KTextEditor::Document::editingFinished(KTextEditor::Document * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void KTextEditor::Document::lineWrapped(KTextEditor::Document * _t1, KTextEditor::Cursor _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1, _t2);
}

// SIGNAL 13
void KTextEditor::Document::lineUnwrapped(KTextEditor::Document * _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1, _t2);
}

// SIGNAL 14
void KTextEditor::Document::textInserted(KTextEditor::Document * _t1, KTextEditor::Cursor _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1, _t2, _t3);
}

// SIGNAL 15
void KTextEditor::Document::textRemoved(KTextEditor::Document * _t1, KTextEditor::Range _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1, _t2, _t3);
}

// SIGNAL 16
void KTextEditor::Document::textChanged(KTextEditor::Document * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void KTextEditor::Document::modeChanged(KTextEditor::Document * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void KTextEditor::Document::highlightingModeChanged(KTextEditor::Document * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void KTextEditor::Document::configChanged(KTextEditor::Document * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1);
}

// SIGNAL 20
void KTextEditor::Document::aboutToDeleteMovingInterfaceContent(KTextEditor::Document * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 20, nullptr, _t1);
}

// SIGNAL 21
void KTextEditor::Document::aboutToInvalidateMovingInterfaceContent(KTextEditor::Document * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 21, nullptr, _t1);
}

// SIGNAL 22
void KTextEditor::Document::modifiedOnDisk(KTextEditor::Document * _t1, bool _t2, KTextEditor::Document::ModifiedOnDiskReason _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 22, nullptr, _t1, _t2, _t3);
}

// SIGNAL 23
void KTextEditor::Document::marksChanged(KTextEditor::Document * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 23, nullptr, _t1);
}

// SIGNAL 24
void KTextEditor::Document::markChanged(KTextEditor::Document * _t1, KTextEditor::Mark _t2, KTextEditor::Document::MarkChangeAction _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 24, nullptr, _t1, _t2, _t3);
}

// SIGNAL 25
void KTextEditor::Document::markToolTipRequested(KTextEditor::Document * _t1, KTextEditor::Mark _t2, QPoint _t3, bool & _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 25, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 26
void KTextEditor::Document::markContextMenuRequested(KTextEditor::Document * _t1, KTextEditor::Mark _t2, QPoint _t3, bool & _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 26, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 27
void KTextEditor::Document::markClicked(KTextEditor::Document * _t1, KTextEditor::Mark _t2, bool & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 27, nullptr, _t1, _t2, _t3);
}
QT_WARNING_POP
