/****************************************************************************
** Meta object code from reading C++ file 'katescriptdocument.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../ktexteditor-6.25.0/src/script/katescriptdocument.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'katescriptdocument.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18KateScriptDocumentE_t {};
} // unnamed namespace

template <> constexpr inline auto KateScriptDocument::qt_create_metaobjectdata<qt_meta_tag_ZN18KateScriptDocumentE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KateScriptDocument",
        "fileName",
        "",
        "url",
        "mimeType",
        "encoding",
        "highlightingMode",
        "embeddedHighlightingModes",
        "highlightingModeAt",
        "QJSValue",
        "pos",
        "isModified",
        "text",
        "fromLine",
        "fromColumn",
        "toLine",
        "toColumn",
        "jsfrom",
        "jsto",
        "jsrange",
        "line",
        "wordAt",
        "column",
        "jscursor",
        "wordRangeAt",
        "charAt",
        "firstChar",
        "lastChar",
        "isSpace",
        "matchesAt",
        "s",
        "cursor",
        "setText",
        "clear",
        "truncate",
        "insertText",
        "removeText",
        "range",
        "insertLine",
        "removeLine",
        "wrapLine",
        "joinLines",
        "startLine",
        "endLine",
        "lines",
        "isLineModified",
        "isLineSaved",
        "isLineTouched",
        "findTouchedLine",
        "down",
        "length",
        "lineLength",
        "editBegin",
        "editEnd",
        "firstColumn",
        "lastColumn",
        "prevNonSpaceColumn",
        "nextNonSpaceColumn",
        "prevNonEmptyLine",
        "nextNonEmptyLine",
        "isInWord",
        "character",
        "attribute",
        "canBreakAt",
        "canComment",
        "startAttribute",
        "endAttribute",
        "commentMarker",
        "commentStart",
        "commentEnd",
        "documentRange",
        "documentEnd",
        "isValidTextPosition",
        "isAttribute",
        "attr",
        "attributeName",
        "isAttributeName",
        "name",
        "variable",
        "setVariable",
        "v",
        "firstVirtualColumn",
        "lastVirtualColumn",
        "toVirtualColumn",
        "toVirtualCursor",
        "fromVirtualColumn",
        "virtualColumn",
        "fromVirtualCursor",
        "anchor",
        "rfind",
        "defStyleNum",
        "isCode",
        "isComment",
        "isString",
        "isRegionMarker",
        "isChar",
        "isOthers",
        "startsWith",
        "pattern",
        "skipWhiteSpaces",
        "endsWith",
        "indent",
        "change"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'fileName'
        QtMocHelpers::MethodData<QString()>(1, 2, QMC::AccessPublic, QMetaType::QString),
        // Method 'url'
        QtMocHelpers::MethodData<QString()>(3, 2, QMC::AccessPublic, QMetaType::QString),
        // Method 'mimeType'
        QtMocHelpers::MethodData<QString()>(4, 2, QMC::AccessPublic, QMetaType::QString),
        // Method 'encoding'
        QtMocHelpers::MethodData<QString()>(5, 2, QMC::AccessPublic, QMetaType::QString),
        // Method 'highlightingMode'
        QtMocHelpers::MethodData<QString()>(6, 2, QMC::AccessPublic, QMetaType::QString),
        // Method 'embeddedHighlightingModes'
        QtMocHelpers::MethodData<QStringList()>(7, 2, QMC::AccessPublic, QMetaType::QStringList),
        // Method 'highlightingModeAt'
        QtMocHelpers::MethodData<QString(const QJSValue &)>(8, 2, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Method 'isModified'
        QtMocHelpers::MethodData<bool()>(11, 2, QMC::AccessPublic, QMetaType::Bool),
        // Method 'text'
        QtMocHelpers::MethodData<QString()>(12, 2, QMC::AccessPublic, QMetaType::QString),
        // Method 'text'
        QtMocHelpers::MethodData<QString(int, int, int, int)>(12, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 13 }, { QMetaType::Int, 14 }, { QMetaType::Int, 15 }, { QMetaType::Int, 16 },
        }}),
        // Method 'text'
        QtMocHelpers::MethodData<QString(const QJSValue &, const QJSValue &)>(12, 2, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 9, 17 }, { 0x80000000 | 9, 18 },
        }}),
        // Method 'text'
        QtMocHelpers::MethodData<QString(const QJSValue &)>(12, 2, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 9, 19 },
        }}),
        // Method 'line'
        QtMocHelpers::MethodData<QString(int)>(20, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 20 },
        }}),
        // Method 'wordAt'
        QtMocHelpers::MethodData<QString(int, int)>(21, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 20 }, { QMetaType::Int, 22 },
        }}),
        // Method 'wordAt'
        QtMocHelpers::MethodData<QString(const QJSValue &)>(21, 2, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 9, 23 },
        }}),
        // Method 'wordRangeAt'
        QtMocHelpers::MethodData<QJSValue(int, int)>(24, 2, QMC::AccessPublic, 0x80000000 | 9, {{
            { QMetaType::Int, 20 }, { QMetaType::Int, 22 },
        }}),
        // Method 'wordRangeAt'
        QtMocHelpers::MethodData<QJSValue(const QJSValue &)>(24, 2, QMC::AccessPublic, 0x80000000 | 9, {{
            { 0x80000000 | 9, 23 },
        }}),
        // Method 'charAt'
        QtMocHelpers::MethodData<QString(int, int)>(25, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 20 }, { QMetaType::Int, 22 },
        }}),
        // Method 'charAt'
        QtMocHelpers::MethodData<QString(const QJSValue &)>(25, 2, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 9, 23 },
        }}),
        // Method 'firstChar'
        QtMocHelpers::MethodData<QString(int)>(26, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 20 },
        }}),
        // Method 'lastChar'
        QtMocHelpers::MethodData<QString(int)>(27, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 20 },
        }}),
        // Method 'isSpace'
        QtMocHelpers::MethodData<bool(int, int)>(28, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 20 }, { QMetaType::Int, 22 },
        }}),
        // Method 'isSpace'
        QtMocHelpers::MethodData<bool(const QJSValue &)>(28, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 9, 23 },
        }}),
        // Method 'matchesAt'
        QtMocHelpers::MethodData<bool(int, int, const QString &)>(29, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 20 }, { QMetaType::Int, 22 }, { QMetaType::QString, 30 },
        }}),
        // Method 'matchesAt'
        QtMocHelpers::MethodData<bool(const QJSValue &, const QString &)>(29, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 9, 31 }, { QMetaType::QString, 30 },
        }}),
        // Method 'setText'
        QtMocHelpers::MethodData<bool(const QString &)>(32, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 30 },
        }}),
        // Method 'clear'
        QtMocHelpers::MethodData<bool()>(33, 2, QMC::AccessPublic, QMetaType::Bool),
        // Method 'truncate'
        QtMocHelpers::MethodData<bool(int, int)>(34, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 20 }, { QMetaType::Int, 22 },
        }}),
        // Method 'truncate'
        QtMocHelpers::MethodData<bool(const QJSValue &)>(34, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 9, 23 },
        }}),
        // Method 'insertText'
        QtMocHelpers::MethodData<bool(int, int, const QString &)>(35, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 20 }, { QMetaType::Int, 22 }, { QMetaType::QString, 30 },
        }}),
        // Method 'insertText'
        QtMocHelpers::MethodData<bool(const QJSValue &, const QString &)>(35, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 9, 23 }, { QMetaType::QString, 30 },
        }}),
        // Method 'removeText'
        QtMocHelpers::MethodData<bool(int, int, int, int)>(36, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 13 }, { QMetaType::Int, 14 }, { QMetaType::Int, 15 }, { QMetaType::Int, 16 },
        }}),
        // Method 'removeText'
        QtMocHelpers::MethodData<bool(const QJSValue &)>(36, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 9, 37 },
        }}),
        // Method 'removeText'
        QtMocHelpers::MethodData<bool(const QJSValue &, const QJSValue &)>(36, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 9, 17 }, { 0x80000000 | 9, 18 },
        }}),
        // Method 'insertLine'
        QtMocHelpers::MethodData<bool(int, const QString &)>(38, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 20 }, { QMetaType::QString, 30 },
        }}),
        // Method 'removeLine'
        QtMocHelpers::MethodData<bool(int)>(39, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 20 },
        }}),
        // Method 'wrapLine'
        QtMocHelpers::MethodData<bool(int, int)>(40, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 20 }, { QMetaType::Int, 22 },
        }}),
        // Method 'wrapLine'
        QtMocHelpers::MethodData<bool(const QJSValue &)>(40, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 9, 31 },
        }}),
        // Method 'joinLines'
        QtMocHelpers::MethodData<void(int, int)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 42 }, { QMetaType::Int, 43 },
        }}),
        // Method 'lines'
        QtMocHelpers::MethodData<int()>(44, 2, QMC::AccessPublic, QMetaType::Int),
        // Method 'isLineModified'
        QtMocHelpers::MethodData<bool(int)>(45, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 20 },
        }}),
        // Method 'isLineSaved'
        QtMocHelpers::MethodData<bool(int)>(46, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 20 },
        }}),
        // Method 'isLineTouched'
        QtMocHelpers::MethodData<bool(int)>(47, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 20 },
        }}),
        // Method 'findTouchedLine'
        QtMocHelpers::MethodData<int(int, bool)>(48, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 42 }, { QMetaType::Bool, 49 },
        }}),
        // Method 'length'
        QtMocHelpers::MethodData<int()>(50, 2, QMC::AccessPublic, QMetaType::Int),
        // Method 'lineLength'
        QtMocHelpers::MethodData<int(int)>(51, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 20 },
        }}),
        // Method 'editBegin'
        QtMocHelpers::MethodData<void()>(52, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'editEnd'
        QtMocHelpers::MethodData<void()>(53, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'firstColumn'
        QtMocHelpers::MethodData<int(int)>(54, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 20 },
        }}),
        // Method 'lastColumn'
        QtMocHelpers::MethodData<int(int)>(55, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 20 },
        }}),
        // Method 'prevNonSpaceColumn'
        QtMocHelpers::MethodData<int(int, int)>(56, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 20 }, { QMetaType::Int, 22 },
        }}),
        // Method 'prevNonSpaceColumn'
        QtMocHelpers::MethodData<int(const QJSValue &)>(56, 2, QMC::AccessPublic, QMetaType::Int, {{
            { 0x80000000 | 9, 23 },
        }}),
        // Method 'nextNonSpaceColumn'
        QtMocHelpers::MethodData<int(int, int)>(57, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 20 }, { QMetaType::Int, 22 },
        }}),
        // Method 'nextNonSpaceColumn'
        QtMocHelpers::MethodData<int(const QJSValue &)>(57, 2, QMC::AccessPublic, QMetaType::Int, {{
            { 0x80000000 | 9, 23 },
        }}),
        // Method 'prevNonEmptyLine'
        QtMocHelpers::MethodData<int(int)>(58, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 20 },
        }}),
        // Method 'nextNonEmptyLine'
        QtMocHelpers::MethodData<int(int)>(59, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 20 },
        }}),
        // Method 'isInWord'
        QtMocHelpers::MethodData<bool(const QString &, int)>(60, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 61 }, { QMetaType::Int, 62 },
        }}),
        // Method 'canBreakAt'
        QtMocHelpers::MethodData<bool(const QString &, int)>(63, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 61 }, { QMetaType::Int, 62 },
        }}),
        // Method 'canComment'
        QtMocHelpers::MethodData<bool(int, int)>(64, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 65 }, { QMetaType::Int, 66 },
        }}),
        // Method 'commentMarker'
        QtMocHelpers::MethodData<QString(int)>(67, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 62 },
        }}),
        // Method 'commentStart'
        QtMocHelpers::MethodData<QString(int)>(68, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 62 },
        }}),
        // Method 'commentEnd'
        QtMocHelpers::MethodData<QString(int)>(69, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 62 },
        }}),
        // Method 'documentRange'
        QtMocHelpers::MethodData<QJSValue()>(70, 2, QMC::AccessPublic, 0x80000000 | 9),
        // Method 'documentEnd'
        QtMocHelpers::MethodData<QJSValue()>(71, 2, QMC::AccessPublic, 0x80000000 | 9),
        // Method 'isValidTextPosition'
        QtMocHelpers::MethodData<bool(int, int)>(72, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 20 }, { QMetaType::Int, 22 },
        }}),
        // Method 'isValidTextPosition'
        QtMocHelpers::MethodData<bool(const QJSValue &)>(72, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 9, 31 },
        }}),
        // Method 'attribute'
        QtMocHelpers::MethodData<int(int, int)>(62, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 20 }, { QMetaType::Int, 22 },
        }}),
        // Method 'attribute'
        QtMocHelpers::MethodData<int(const QJSValue &)>(62, 2, QMC::AccessPublic, QMetaType::Int, {{
            { 0x80000000 | 9, 23 },
        }}),
        // Method 'isAttribute'
        QtMocHelpers::MethodData<bool(int, int, int)>(73, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 20 }, { QMetaType::Int, 22 }, { QMetaType::Int, 74 },
        }}),
        // Method 'isAttribute'
        QtMocHelpers::MethodData<bool(const QJSValue &, int)>(73, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 9, 23 }, { QMetaType::Int, 74 },
        }}),
        // Method 'attributeName'
        QtMocHelpers::MethodData<QString(int, int)>(75, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 20 }, { QMetaType::Int, 22 },
        }}),
        // Method 'attributeName'
        QtMocHelpers::MethodData<QString(const QJSValue &)>(75, 2, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 9, 23 },
        }}),
        // Method 'isAttributeName'
        QtMocHelpers::MethodData<bool(int, int, const QString &)>(76, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 20 }, { QMetaType::Int, 22 }, { QMetaType::QString, 77 },
        }}),
        // Method 'isAttributeName'
        QtMocHelpers::MethodData<bool(const QJSValue &, const QString &)>(76, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 9, 31 }, { QMetaType::QString, 77 },
        }}),
        // Method 'variable'
        QtMocHelpers::MethodData<QString(const QString &)>(78, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 30 },
        }}),
        // Method 'setVariable'
        QtMocHelpers::MethodData<void(const QString &, const QString &)>(79, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 30 }, { QMetaType::QString, 80 },
        }}),
        // Method 'firstVirtualColumn'
        QtMocHelpers::MethodData<int(int)>(81, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 20 },
        }}),
        // Method 'lastVirtualColumn'
        QtMocHelpers::MethodData<int(int)>(82, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 20 },
        }}),
        // Method 'toVirtualColumn'
        QtMocHelpers::MethodData<int(int, int)>(83, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 20 }, { QMetaType::Int, 22 },
        }}),
        // Method 'toVirtualColumn'
        QtMocHelpers::MethodData<int(const QJSValue &)>(83, 2, QMC::AccessPublic, QMetaType::Int, {{
            { 0x80000000 | 9, 31 },
        }}),
        // Method 'toVirtualCursor'
        QtMocHelpers::MethodData<QJSValue(int, int)>(84, 2, QMC::AccessPublic, 0x80000000 | 9, {{
            { QMetaType::Int, 20 }, { QMetaType::Int, 22 },
        }}),
        // Method 'toVirtualCursor'
        QtMocHelpers::MethodData<QJSValue(const QJSValue &)>(84, 2, QMC::AccessPublic, 0x80000000 | 9, {{
            { 0x80000000 | 9, 23 },
        }}),
        // Method 'fromVirtualColumn'
        QtMocHelpers::MethodData<int(int, int)>(85, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 20 }, { QMetaType::Int, 86 },
        }}),
        // Method 'fromVirtualColumn'
        QtMocHelpers::MethodData<int(const QJSValue &)>(85, 2, QMC::AccessPublic, QMetaType::Int, {{
            { 0x80000000 | 9, 23 },
        }}),
        // Method 'fromVirtualCursor'
        QtMocHelpers::MethodData<QJSValue(int, int)>(87, 2, QMC::AccessPublic, 0x80000000 | 9, {{
            { QMetaType::Int, 20 }, { QMetaType::Int, 22 },
        }}),
        // Method 'fromVirtualCursor'
        QtMocHelpers::MethodData<QJSValue(const QJSValue &)>(87, 2, QMC::AccessPublic, 0x80000000 | 9, {{
            { 0x80000000 | 9, 23 },
        }}),
        // Method 'anchor'
        QtMocHelpers::MethodData<QJSValue(int, int, QChar)>(88, 2, QMC::AccessPublic, 0x80000000 | 9, {{
            { QMetaType::Int, 20 }, { QMetaType::Int, 22 }, { QMetaType::QChar, 61 },
        }}),
        // Method 'anchor'
        QtMocHelpers::MethodData<QJSValue(const QJSValue &, QChar)>(88, 2, QMC::AccessPublic, 0x80000000 | 9, {{
            { 0x80000000 | 9, 31 }, { QMetaType::QChar, 61 },
        }}),
        // Method 'rfind'
        QtMocHelpers::MethodData<QJSValue(int, int, const QString &, int)>(89, 2, QMC::AccessPublic, 0x80000000 | 9, {{
            { QMetaType::Int, 20 }, { QMetaType::Int, 22 }, { QMetaType::QString, 12 }, { QMetaType::Int, 62 },
        }}),
        // Method 'rfind'
        QtMocHelpers::MethodData<QJSValue(int, int, const QString &)>(89, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 9, {{
            { QMetaType::Int, 20 }, { QMetaType::Int, 22 }, { QMetaType::QString, 12 },
        }}),
        // Method 'rfind'
        QtMocHelpers::MethodData<QJSValue(const QJSValue &, const QString &, int)>(89, 2, QMC::AccessPublic, 0x80000000 | 9, {{
            { 0x80000000 | 9, 31 }, { QMetaType::QString, 12 }, { QMetaType::Int, 62 },
        }}),
        // Method 'rfind'
        QtMocHelpers::MethodData<QJSValue(const QJSValue &, const QString &)>(89, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 9, {{
            { 0x80000000 | 9, 31 }, { QMetaType::QString, 12 },
        }}),
        // Method 'defStyleNum'
        QtMocHelpers::MethodData<int(int, int)>(90, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 20 }, { QMetaType::Int, 22 },
        }}),
        // Method 'defStyleNum'
        QtMocHelpers::MethodData<int(const QJSValue &)>(90, 2, QMC::AccessPublic, QMetaType::Int, {{
            { 0x80000000 | 9, 31 },
        }}),
        // Method 'isCode'
        QtMocHelpers::MethodData<bool(int, int)>(91, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 20 }, { QMetaType::Int, 22 },
        }}),
        // Method 'isCode'
        QtMocHelpers::MethodData<bool(const QJSValue &)>(91, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 9, 31 },
        }}),
        // Method 'isComment'
        QtMocHelpers::MethodData<bool(int, int)>(92, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 20 }, { QMetaType::Int, 22 },
        }}),
        // Method 'isComment'
        QtMocHelpers::MethodData<bool(const QJSValue &)>(92, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 9, 31 },
        }}),
        // Method 'isString'
        QtMocHelpers::MethodData<bool(int, int)>(93, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 20 }, { QMetaType::Int, 22 },
        }}),
        // Method 'isString'
        QtMocHelpers::MethodData<bool(const QJSValue &)>(93, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 9, 31 },
        }}),
        // Method 'isRegionMarker'
        QtMocHelpers::MethodData<bool(int, int)>(94, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 20 }, { QMetaType::Int, 22 },
        }}),
        // Method 'isRegionMarker'
        QtMocHelpers::MethodData<bool(const QJSValue &)>(94, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 9, 31 },
        }}),
        // Method 'isChar'
        QtMocHelpers::MethodData<bool(int, int)>(95, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 20 }, { QMetaType::Int, 22 },
        }}),
        // Method 'isChar'
        QtMocHelpers::MethodData<bool(const QJSValue &)>(95, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 9, 31 },
        }}),
        // Method 'isOthers'
        QtMocHelpers::MethodData<bool(int, int)>(96, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 20 }, { QMetaType::Int, 22 },
        }}),
        // Method 'isOthers'
        QtMocHelpers::MethodData<bool(const QJSValue &)>(96, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 9, 31 },
        }}),
        // Method 'startsWith'
        QtMocHelpers::MethodData<bool(int, const QString &, bool)>(97, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 20 }, { QMetaType::QString, 98 }, { QMetaType::Bool, 99 },
        }}),
        // Method 'endsWith'
        QtMocHelpers::MethodData<bool(int, const QString &, bool)>(100, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 20 }, { QMetaType::QString, 98 }, { QMetaType::Bool, 99 },
        }}),
        // Method 'indent'
        QtMocHelpers::MethodData<void(const QJSValue &, int)>(101, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 19 }, { QMetaType::Int, 102 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KateScriptDocument, qt_meta_tag_ZN18KateScriptDocumentE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KateScriptDocument::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18KateScriptDocumentE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18KateScriptDocumentE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18KateScriptDocumentE_t>.metaTypes,
    nullptr
} };

void KateScriptDocument::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KateScriptDocument *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QString _r = _t->fileName();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 1: { QString _r = _t->url();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 2: { QString _r = _t->mimeType();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 3: { QString _r = _t->encoding();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 4: { QString _r = _t->highlightingMode();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 5: { QStringList _r = _t->embeddedHighlightingModes();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 6: { QString _r = _t->highlightingModeAt((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 7: { bool _r = _t->isModified();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 8: { QString _r = _t->text();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 9: { QString _r = _t->text((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 10: { QString _r = _t->text((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 11: { QString _r = _t->text((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 12: { QString _r = _t->line((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 13: { QString _r = _t->wordAt((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 14: { QString _r = _t->wordAt((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 15: { QJSValue _r = _t->wordRangeAt((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 16: { QJSValue _r = _t->wordRangeAt((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 17: { QString _r = _t->charAt((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 18: { QString _r = _t->charAt((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 19: { QString _r = _t->firstChar((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 20: { QString _r = _t->lastChar((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 21: { bool _r = _t->isSpace((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 22: { bool _r = _t->isSpace((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 23: { bool _r = _t->matchesAt((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 24: { bool _r = _t->matchesAt((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 25: { bool _r = _t->setText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 26: { bool _r = _t->clear();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 27: { bool _r = _t->truncate((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 28: { bool _r = _t->truncate((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 29: { bool _r = _t->insertText((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 30: { bool _r = _t->insertText((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 31: { bool _r = _t->removeText((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 32: { bool _r = _t->removeText((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 33: { bool _r = _t->removeText((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 34: { bool _r = _t->insertLine((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 35: { bool _r = _t->removeLine((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 36: { bool _r = _t->wrapLine((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 37: { bool _r = _t->wrapLine((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 38: _t->joinLines((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 39: { int _r = _t->lines();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 40: { bool _r = _t->isLineModified((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 41: { bool _r = _t->isLineSaved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 42: { bool _r = _t->isLineTouched((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 43: { int _r = _t->findTouchedLine((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 44: { int _r = _t->length();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 45: { int _r = _t->lineLength((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 46: _t->editBegin(); break;
        case 47: _t->editEnd(); break;
        case 48: { int _r = _t->firstColumn((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 49: { int _r = _t->lastColumn((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 50: { int _r = _t->prevNonSpaceColumn((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 51: { int _r = _t->prevNonSpaceColumn((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 52: { int _r = _t->nextNonSpaceColumn((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 53: { int _r = _t->nextNonSpaceColumn((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 54: { int _r = _t->prevNonEmptyLine((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 55: { int _r = _t->nextNonEmptyLine((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 56: { bool _r = _t->isInWord((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 57: { bool _r = _t->canBreakAt((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 58: { bool _r = _t->canComment((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 59: { QString _r = _t->commentMarker((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 60: { QString _r = _t->commentStart((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 61: { QString _r = _t->commentEnd((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 62: { QJSValue _r = _t->documentRange();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 63: { QJSValue _r = _t->documentEnd();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 64: { bool _r = _t->isValidTextPosition((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 65: { bool _r = _t->isValidTextPosition((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 66: { int _r = _t->attribute((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 67: { int _r = _t->attribute((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 68: { bool _r = _t->isAttribute((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 69: { bool _r = _t->isAttribute((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 70: { QString _r = _t->attributeName((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 71: { QString _r = _t->attributeName((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 72: { bool _r = _t->isAttributeName((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 73: { bool _r = _t->isAttributeName((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 74: { QString _r = _t->variable((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 75: _t->setVariable((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 76: { int _r = _t->firstVirtualColumn((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 77: { int _r = _t->lastVirtualColumn((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 78: { int _r = _t->toVirtualColumn((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 79: { int _r = _t->toVirtualColumn((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 80: { QJSValue _r = _t->toVirtualCursor((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 81: { QJSValue _r = _t->toVirtualCursor((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 82: { int _r = _t->fromVirtualColumn((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 83: { int _r = _t->fromVirtualColumn((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 84: { QJSValue _r = _t->fromVirtualCursor((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 85: { QJSValue _r = _t->fromVirtualCursor((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 86: { QJSValue _r = _t->anchor((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QChar>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 87: { QJSValue _r = _t->anchor((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QChar>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 88: { QJSValue _r = _t->rfind((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 89: { QJSValue _r = _t->rfind((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 90: { QJSValue _r = _t->rfind((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 91: { QJSValue _r = _t->rfind((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 92: { int _r = _t->defStyleNum((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 93: { int _r = _t->defStyleNum((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 94: { bool _r = _t->isCode((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 95: { bool _r = _t->isCode((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 96: { bool _r = _t->isComment((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 97: { bool _r = _t->isComment((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 98: { bool _r = _t->isString((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 99: { bool _r = _t->isString((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 100: { bool _r = _t->isRegionMarker((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 101: { bool _r = _t->isRegionMarker((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 102: { bool _r = _t->isChar((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 103: { bool _r = _t->isChar((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 104: { bool _r = _t->isOthers((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 105: { bool _r = _t->isOthers((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 106: { bool _r = _t->startsWith((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 107: { bool _r = _t->endsWith((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 108: _t->indent((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 18:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 22:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 24:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 28:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 30:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 32:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 33:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 37:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 51:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 53:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 65:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 67:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 69:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 71:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 73:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 79:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 81:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 83:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 85:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 87:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 90:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 91:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 93:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 95:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 97:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 99:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 101:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 103:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 105:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 108:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        }
    }
}

const QMetaObject *KateScriptDocument::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateScriptDocument::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18KateScriptDocumentE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KateScriptDocument::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 109)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 109;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 109)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 109;
    }
    return _id;
}
QT_WARNING_POP
