/********************************************************************************
** Form generated from reading UI file 'searchbarincremental.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SEARCHBARINCREMENTAL_H
#define UI_SEARCHBARINCREMENTAL_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "ksqueezedtextlabel.h"

QT_BEGIN_NAMESPACE

class Ui_IncrementalSearchBar
{
public:
    QGridLayout *gridLayout;
    QHBoxLayout *hboxLayout;
    QLabel *label;
    QComboBox *pattern;
    QToolButton *next;
    QToolButton *prev;
    QToolButton *matchCase;
    KSqueezedTextLabel *status;
    QToolButton *mutate;

    void setupUi(QWidget *IncrementalSearchBar)
    {
        if (IncrementalSearchBar->objectName().isEmpty())
            IncrementalSearchBar->setObjectName("IncrementalSearchBar");
        IncrementalSearchBar->resize(446, 34);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(IncrementalSearchBar->sizePolicy().hasHeightForWidth());
        IncrementalSearchBar->setSizePolicy(sizePolicy);
        gridLayout = new QGridLayout(IncrementalSearchBar);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        label = new QLabel(IncrementalSearchBar);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        hboxLayout->addWidget(label);

        pattern = new QComboBox(IncrementalSearchBar);
        pattern->setObjectName("pattern");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(pattern->sizePolicy().hasHeightForWidth());
        pattern->setSizePolicy(sizePolicy1);
        pattern->setMouseTracking(false);
        pattern->setFocusPolicy(Qt::StrongFocus);
        pattern->setAcceptDrops(true);
        pattern->setEditable(true);
        pattern->setSizeAdjustPolicy(QComboBox::AdjustToMinimumContentsLengthWithIcon);

        hboxLayout->addWidget(pattern);

        next = new QToolButton(IncrementalSearchBar);
        next->setObjectName("next");
        next->setAutoRaise(true);

        hboxLayout->addWidget(next);

        prev = new QToolButton(IncrementalSearchBar);
        prev->setObjectName("prev");
        prev->setAutoRaise(true);

        hboxLayout->addWidget(prev);

        matchCase = new QToolButton(IncrementalSearchBar);
        matchCase->setObjectName("matchCase");
        matchCase->setCheckable(true);
        matchCase->setAutoRaise(true);

        hboxLayout->addWidget(matchCase);

        status = new KSqueezedTextLabel(IncrementalSearchBar);
        status->setObjectName("status");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(status->sizePolicy().hasHeightForWidth());
        status->setSizePolicy(sizePolicy2);
        status->setMinimumSize(QSize(0, 0));
        status->setAlignment(Qt::AlignCenter);
        status->setWordWrap(false);

        hboxLayout->addWidget(status);

        mutate = new QToolButton(IncrementalSearchBar);
        mutate->setObjectName("mutate");
        mutate->setAutoRaise(true);
        mutate->setCheckable(true);

        hboxLayout->addWidget(mutate);


        gridLayout->addLayout(hboxLayout, 0, 0, 1, 1);

#if QT_CONFIG(shortcut)
        label->setBuddy(pattern);
#endif // QT_CONFIG(shortcut)

        retranslateUi(IncrementalSearchBar);

        QMetaObject::connectSlotsByName(IncrementalSearchBar);
    } // setupUi

    void retranslateUi(QWidget *IncrementalSearchBar)
    {
        label->setText(tr2i18n("F&ind:", nullptr));
#if QT_CONFIG(tooltip)
        pattern->setToolTip(tr2i18n("Text to search for", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        next->setToolTip(tr2i18n("Jump to next match", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        prev->setToolTip(tr2i18n("Jump to previous match", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        matchCase->setToolTip(tr2i18n("Match case sensitive", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        mutate->setToolTip(tr2i18n("Switch to power search and replace bar", nullptr));
#endif // QT_CONFIG(tooltip)
        mutate->setText(QString());
        (void)IncrementalSearchBar;
    } // retranslateUi

};

namespace Ui {
    class IncrementalSearchBar: public Ui_IncrementalSearchBar {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SEARCHBARINCREMENTAL_H

