/****************************************************************************
** Meta object code from reading C++ file 'katesearchbar.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../ktexteditor-6.25.0/src/search/katesearchbar.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'katesearchbar.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13KateSearchBarE_t {};
} // unnamed namespace

template <> constexpr inline auto KateSearchBar::qt_create_metaobjectdata<qt_meta_tag_ZN13KateSearchBarE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KateSearchBar",
        "findOrReplaceAllFinished",
        "",
        "setSearchPattern",
        "searchPattern",
        "setReplacementPattern",
        "replacementPattern",
        "setSearchMode",
        "SearchMode",
        "mode",
        "setSelectionOnly",
        "selectionOnly",
        "setMatchCase",
        "matchCase",
        "findNext",
        "findPrevious",
        "findAll",
        "replaceNext",
        "replaceAll",
        "enterPowerMode",
        "enterIncrementalMode",
        "clearHighlights",
        "updateHighlightColors",
        "slotReadWriteChanged",
        "onIncPatternChanged",
        "pattern",
        "onMatchCaseToggled",
        "onReturnPressed",
        "updateSelectionOnly",
        "updateIncInitCursor",
        "onContextMenuRequest",
        "QPoint",
        "onPowerPatternChanged",
        "onPowerModeChanged",
        "index",
        "onPowerPatternContextMenuRequest",
        "onPowerReplacmentContextMenuRequest",
        "onPowerCancelFindOrReplace",
        "findOrReplaceAll",
        "endFindOrReplaceAll"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'findOrReplaceAllFinished'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setSearchPattern'
        QtMocHelpers::SlotData<void(const QString &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Slot 'setReplacementPattern'
        QtMocHelpers::SlotData<void(const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'setSearchMode'
        QtMocHelpers::SlotData<void(enum SearchMode)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'setSelectionOnly'
        QtMocHelpers::SlotData<void(bool)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Slot 'setMatchCase'
        QtMocHelpers::SlotData<void(bool)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 13 },
        }}),
        // Slot 'findNext'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'findPrevious'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'findAll'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'replaceNext'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'replaceAll'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'enterPowerMode'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'enterIncrementalMode'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'clearHighlights'
        QtMocHelpers::SlotData<bool()>(21, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'updateHighlightColors'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotReadWriteChanged'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onIncPatternChanged'
        QtMocHelpers::SlotData<void(const QString &)>(24, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 25 },
        }}),
        // Slot 'onMatchCaseToggled'
        QtMocHelpers::SlotData<void(bool)>(26, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 13 },
        }}),
        // Slot 'onReturnPressed'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateSelectionOnly'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateIncInitCursor'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onContextMenuRequest'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onContextMenuRequest'
        QtMocHelpers::SlotData<void(const QPoint &)>(30, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 31, 2 },
        }}),
        // Slot 'onPowerPatternChanged'
        QtMocHelpers::SlotData<void(const QString &)>(32, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 25 },
        }}),
        // Slot 'onPowerModeChanged'
        QtMocHelpers::SlotData<void(int)>(33, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 34 },
        }}),
        // Slot 'onPowerPatternContextMenuRequest'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onPowerPatternContextMenuRequest'
        QtMocHelpers::SlotData<void(const QPoint &)>(35, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 31, 2 },
        }}),
        // Slot 'onPowerReplacmentContextMenuRequest'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onPowerReplacmentContextMenuRequest'
        QtMocHelpers::SlotData<void(const QPoint &)>(36, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 31, 2 },
        }}),
        // Slot 'onPowerCancelFindOrReplace'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'findOrReplaceAll'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'endFindOrReplaceAll'
        QtMocHelpers::SlotData<void()>(39, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KateSearchBar, qt_meta_tag_ZN13KateSearchBarE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KateSearchBar::staticMetaObject = { {
    QMetaObject::SuperData::link<KateViewBarWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KateSearchBarE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KateSearchBarE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13KateSearchBarE_t>.metaTypes,
    nullptr
} };

void KateSearchBar::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KateSearchBar *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->findOrReplaceAllFinished(); break;
        case 1: _t->setSearchPattern((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->setReplacementPattern((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->setSearchMode((*reinterpret_cast<std::add_pointer_t<enum SearchMode>>(_a[1]))); break;
        case 4: _t->setSelectionOnly((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->setMatchCase((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->findNext(); break;
        case 7: _t->findPrevious(); break;
        case 8: _t->findAll(); break;
        case 9: _t->replaceNext(); break;
        case 10: _t->replaceAll(); break;
        case 11: _t->enterPowerMode(); break;
        case 12: _t->enterIncrementalMode(); break;
        case 13: { bool _r = _t->clearHighlights();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 14: _t->updateHighlightColors(); break;
        case 15: _t->slotReadWriteChanged(); break;
        case 16: _t->onIncPatternChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 17: _t->onMatchCaseToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 18: _t->onReturnPressed(); break;
        case 19: _t->updateSelectionOnly(); break;
        case 20: _t->updateIncInitCursor(); break;
        case 21: _t->onContextMenuRequest(); break;
        case 22: _t->onContextMenuRequest((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 23: _t->onPowerPatternChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 24: _t->onPowerModeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 25: _t->onPowerPatternContextMenuRequest(); break;
        case 26: _t->onPowerPatternContextMenuRequest((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 27: _t->onPowerReplacmentContextMenuRequest(); break;
        case 28: _t->onPowerReplacmentContextMenuRequest((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 29: _t->onPowerCancelFindOrReplace(); break;
        case 30: _t->findOrReplaceAll(); break;
        case 31: _t->endFindOrReplaceAll(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KateSearchBar::*)()>(_a, &KateSearchBar::findOrReplaceAllFinished, 0))
            return;
    }
}

const QMetaObject *KateSearchBar::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateSearchBar::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KateSearchBarE_t>.strings))
        return static_cast<void*>(this);
    return KateViewBarWidget::qt_metacast(_clname);
}

int KateSearchBar::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KateViewBarWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 32)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 32;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 32)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 32;
    }
    return _id;
}

// SIGNAL 0
void KateSearchBar::findOrReplaceAllFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
